import { DependencyContainer } from "tsyringe";

import { ConfigServer } from "@spt-aki/servers/ConfigServer";
import { ConfigTypes } from "@spt-aki/models/enums/ConfigTypes";
import { DatabaseServer } from "@spt-aki/servers/DatabaseServer";
import { IPostDBLoadMod } from "@spt-aki/models/external/IPostDBLoadMod";


class GigaChad implements IPostDBLoadMod {

    postDBLoad(container: DependencyContainer): void {
        const logger = container.resolve<ILogger>("WinstonLogger");
        const databaseServer = container.resolve<DatabaseServer>("DatabaseServer");
        const configServer = container.resolve<ConfigServer>("ConfigServer");

        const tables = databaseServer.getTables();
        const profiles = tables.templates.profiles;
        const traders = tables.traders;

		// unlock all quest-locked items
		for (let tid in traders) {
			let trader = traders[tid];
			if (trader.questassort!=null) {
				trader.questassort.success = {};
			}
		}

		profiles["GigaChad"] = {
        "bear": {
            "character": {
                "_id": "__REPLACEME__",
                "aid": "__REPLACEME__",
                "savage": "__REPLACEME__",
                "Info": {
                    "Nickname": "__REPLACEME__",
                    "LowerNickname": "__REPLACEME__",
                    "Side": "Bear",
                    "Voice": "__REPLACEME__",
                    "Level": 50,
                    "Experience": 5000000,
                    "RegistrationDate": "__REPLACEME__",
                    "GameVersion": "edge_of_darkness",
                    "AccountType": 0,
                    "MemberCategory": 0,
                    "lockedMoveCommands": false,
                    "SavageLockTime": 0,
                    "LastTimePlayedAsSavage": 0,
                    "Settings": {
                        "Role": "assault",
                        "BotDifficulty": "easy",
                        "Experience": -1
                    },
                    "NicknameChangeDate": 0,
                    "IsStreamerModeAvailable": false,
                    "Bans": [],
                    "BannedState": false,
                    "BannedUntil": 0
                },
                "Customization": {
                    "Head": "__REPLACEME__",
                    "Body": "5cc0858d14c02e000c6bea66",
                    "Feet": "5cc085bb14c02e000e67a5c5",
                    "Hands": "5cc0876314c02e000c6bea6b"
                },
                "Health": {
                    "Hydration": {
                        "Current": 100,
                        "Maximum": 100
                    },
                    "Energy": {
                        "Current": 100,
                        "Maximum": 100
                    },
                    "Temperature": {
                        "Current": 36.6,
                        "Maximum": 40
                    },
                    "BodyParts": {
                        "Head": {
                            "Health": {
                                "Current": 35,
                                "Maximum": 35
                            }
                        },
                        "Chest": {
                            "Health": {
                                "Current": 85,
                                "Maximum": 85
                            }
                        },
                        "Stomach": {
                            "Health": {
                                "Current": 70,
                                "Maximum": 70
                            }
                        },
                        "LeftArm": {
                            "Health": {
                                "Current": 60,
                                "Maximum": 60
                            }
                        },
                        "RightArm": {
                            "Health": {
                                "Current": 60,
                                "Maximum": 60
                            }
                        },
                        "LeftLeg": {
                            "Health": {
                                "Current": 65,
                                "Maximum": 65
                            }
                        },
                        "RightLeg": {
                            "Health": {
                                "Current": 65,
                                "Maximum": 65
                            }
                        }
                    },
                    "UpdateTime": 1608815684
                },
				"Inventory": {
					"items": [
						{
							"_id": "5fe49444ae6628187a2e77b8",
							"_tpl": "55d7217a4bdc2d86028b456d"
						},
						{
							"_id": "4762bc96ec1eb296c80c9766",
							"_tpl": "5857a8bc2459772bad15db29",
							"parentId": "5fe49444ae6628187a2e77b8",
							"slotId": "SecuredContainer"
						},
						{
							"_id": "be2c737eca1dd8acf5bc9e1d",
							"_tpl": "627a4e6b255f7527fb05a0f6",
							"parentId": "5fe49444ae6628187a2e77b8",
							"slotId": "Pockets"
						},
						{
							"_id": "5fe49444ae6628187a2e78b8",
							"_tpl": "5811ce772459770e9e5f9532"
						},
						{
							"_id": "5fe49444ae6628187a2e78ba",
							"_tpl": "5963866b86f7747bfa1c4462"
						},
						{
							"_id": "5fe49444ae6628187a2e78b9",
							"_tpl": "5963866286f7747bf429b572"
						},
						{
							"_id": "60dca3da42ad9b706b369aca",
							"_tpl": "602543c13fee350cd564d032"
						},
						{
							"_id": "c5437eefa45f91432f8a7f0f",
							"_tpl": "569668774bdc2da2298b4568",
							"parentId": "aa181c6bc697085eb24a8387",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 50000
							}
						},
						{
							"_id": "58dcea09dd2598ffa01fb904",
							"_tpl": "59fb016586f7746d0d4b423a",
							"parentId": "5fe49444ae6628187a2e78b8",
							"slotId": "hideout",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Vertical",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "ad6a118bc008509fbcc42221",
							"_tpl": "5d235bb686f77443f4331278",
							"parentId": "I0923172355114862980Xjmy",
							"slotId": "2",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"Tag": {
									"Color": 0,
									"Name": "Reserve"
								}
							}
						},
						{
							"_id": "c28701e285917a5f1aba97d9",
							"_tpl": "59fb042886f7746c5005a7b2",
							"parentId": "5fe49444ae6628187a2e78b8",
							"slotId": "hideout",
							"location": {
								"x": 4,
								"y": 19,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"Tag": {
									"Color": 0,
									"Name": ""
								}
							}
						},
						{
							"_id": "48264f7f5b79eab8634caad3",
							"_tpl": "619cbf7d23893217ec30b689",
							"parentId": "4762bc96ec1eb296c80c9766",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "6e979f224a755a582140dc0b",
							"_tpl": "59fb042886f7746c5005a7b2",
							"parentId": "5fe49444ae6628187a2e78b8",
							"slotId": "hideout",
							"location": {
								"x": 0,
								"y": 19,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"Tag": {
									"Color": 0,
									"Name": "Head gear"
								}
							}
						},
						{
							"_id": "6ea94462e857b6bc08a98c77",
							"_tpl": "5aafbcd986f7745e590fff23",
							"parentId": "5fe49444ae6628187a2e78b8",
							"slotId": "hideout",
							"location": {
								"x": 7,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "3dddf0476f5ecbb16e42e815",
							"_tpl": "5c093db286f7740a1b2617e3",
							"parentId": "5fe49444ae6628187a2e78b8",
							"slotId": "hideout",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "4ee998775174fb58923f0e60",
							"_tpl": "5c0fa877d174af02a012e1cf",
							"parentId": "3dddf0476f5ecbb16e42e815",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "44493b178072c83ac6e5bf28",
							"_tpl": "5c0fa877d174af02a012e1cf",
							"parentId": "3dddf0476f5ecbb16e42e815",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "8f409532668769d248ff8ec8",
							"_tpl": "5c0fa877d174af02a012e1cf",
							"parentId": "3dddf0476f5ecbb16e42e815",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "66b7f884b954e399e9b8c53f",
							"_tpl": "5c0fa877d174af02a012e1cf",
							"parentId": "3dddf0476f5ecbb16e42e815",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "df58315c9d3943c030cc8ef7",
							"_tpl": "5c0fa877d174af02a012e1cf",
							"parentId": "3dddf0476f5ecbb16e42e815",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "7d3524b30264d991400854af",
							"_tpl": "5c0fa877d174af02a012e1cf",
							"parentId": "3dddf0476f5ecbb16e42e815",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "41fb5820773cb651d407acd0",
							"_tpl": "590c5f0d86f77413997acfab",
							"parentId": "45f0c10affb653b9c69f81ac",
							"slotId": "main",
							"location": {
								"x": 7,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "32547cf5efd36b8de1438a83",
							"_tpl": "590c5f0d86f77413997acfab",
							"parentId": "45f0c10affb653b9c69f81ac",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "db5029a12c02d8d85f7b438b",
							"_tpl": "590c5f0d86f77413997acfab",
							"parentId": "45f0c10affb653b9c69f81ac",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "6caf452aa653eaec39fecb10",
							"_tpl": "590c5f0d86f77413997acfab",
							"parentId": "45f0c10affb653b9c69f81ac",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "20da3021d8b3e95373bd3638",
							"_tpl": "590c5f0d86f77413997acfab",
							"parentId": "45f0c10affb653b9c69f81ac",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "36f56b9c50bc79c5757939e5",
							"_tpl": "590c5f0d86f77413997acfab",
							"parentId": "45f0c10affb653b9c69f81ac",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "a1f57ad64fcc35a88f6f547a",
							"_tpl": "590c5f0d86f77413997acfab",
							"parentId": "45f0c10affb653b9c69f81ac",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "05bf6fd2b8fb4c1e2d9354d7",
							"_tpl": "590c5f0d86f77413997acfab",
							"parentId": "45f0c10affb653b9c69f81ac",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "22ce701caafbfa1e89240a61",
							"_tpl": "5c0fa877d174af02a012e1cf",
							"parentId": "3dddf0476f5ecbb16e42e815",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "b7bdc5967f39db5aa502e642",
							"_tpl": "5c0fa877d174af02a012e1cf",
							"parentId": "3dddf0476f5ecbb16e42e815",
							"slotId": "main",
							"location": {
								"x": 7,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "226bf8e909fab8f41534221f",
							"_tpl": "544fb45d4bdc2dee738b4568",
							"parentId": "6ea94462e857b6bc08a98c77",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 6,
								"r": "Vertical",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"MedKit": {
									"HpResource": 334
								}
							}
						},
						{
							"_id": "062d7e89ebe520275e909b06",
							"_tpl": "544fb45d4bdc2dee738b4568",
							"parentId": "6ea94462e857b6bc08a98c77",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 5,
								"r": "Vertical",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"MedKit": {
									"HpResource": 400
								}
							}
						},
						{
							"_id": "d3c6a8e97edd98efb722e4d0",
							"_tpl": "544fb45d4bdc2dee738b4568",
							"parentId": "6ea94462e857b6bc08a98c77",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 4,
								"r": "Vertical",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"MedKit": {
									"HpResource": 400
								}
							}
						},
						{
							"_id": "6b26c05c01ae290d54af2adb",
							"_tpl": "544fb45d4bdc2dee738b4568",
							"parentId": "6ea94462e857b6bc08a98c77",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 3,
								"r": "Vertical",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"MedKit": {
									"HpResource": 400
								}
							}
						},
						{
							"_id": "e18d42cc676f9ed76e200c42",
							"_tpl": "5d02797c86f774203f38e30a",
							"parentId": "6ea94462e857b6bc08a98c77",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"MedKit": {
									"HpResource": 15
								}
							}
						},
						{
							"_id": "e262c9173855bc984fc552e1",
							"_tpl": "5d02797c86f774203f38e30a",
							"parentId": "6ea94462e857b6bc08a98c77",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"MedKit": {
									"HpResource": 15
								}
							}
						},
						{
							"_id": "c82b9e60dcc88cabb8b3b1f2",
							"_tpl": "5d02797c86f774203f38e30a",
							"parentId": "4762bc96ec1eb296c80c9766",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"MedKit": {
									"HpResource": 15
								}
							}
						},
						{
							"_id": "6df74ab62b30c361ec342ca7",
							"_tpl": "5d02797c86f774203f38e30a",
							"parentId": "6ea94462e857b6bc08a98c77",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"MedKit": {
									"HpResource": 15
								}
							}
						},
						{
							"_id": "fdf59b599f369db65131cb4d",
							"_tpl": "5d02797c86f774203f38e30a",
							"parentId": "6ea94462e857b6bc08a98c77",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"MedKit": {
									"HpResource": 15
								}
							}
						},
						{
							"_id": "876349c6644fb7d383956a71",
							"_tpl": "5d02797c86f774203f38e30a",
							"parentId": "6ea94462e857b6bc08a98c77",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"MedKit": {
									"HpResource": 15
								}
							}
						},
						{
							"_id": "082038786b3ad4223108599f",
							"_tpl": "5d02797c86f774203f38e30a",
							"parentId": "6ea94462e857b6bc08a98c77",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"MedKit": {
									"HpResource": 15
								}
							}
						},
						{
							"_id": "30b50554931675cd041020ee",
							"_tpl": "544fb45d4bdc2dee738b4568",
							"parentId": "6ea94462e857b6bc08a98c77",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 2,
								"r": "Vertical",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"MedKit": {
									"HpResource": 400
								}
							}
						},
						{
							"_id": "6622c0b6cbf8b8ff7e5d479b",
							"_tpl": "544fb45d4bdc2dee738b4568",
							"parentId": "I09232006192496057943JEc",
							"slotId": "11",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"MedKit": {
									"HpResource": 400
								}
							}
						},
						{
							"_id": "I09231505117344600002ySF",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150511577884091hw32",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150511604947979ecoZ",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150511622225070YxQT",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231505245916849523wPm",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524976338992UCPV",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524704122323gs4S",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231505245660709872L9C",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524604662795FbKE",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524460820611ShQR",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231505242470217199fKN",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524459633618818U",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524153572886U0wA",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I092315052414233241342Zr",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524399097881GkFS",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524759681273qDzD",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524557209990vUM8",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524206610957mtbW",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524881649640mCEw",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524538194680p64v",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524803610957iSyW",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524573595903SEuw",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524669349074SA5O",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I092315052469016537434Nw",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231505243313616290wQI",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524988098607y2YT",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524857578061ZIhF",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524419482174yoLW",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524543746016rTvs",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524218649172jL81",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524732382854zz90",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524557298050upBc",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150524844321916rS4u",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150543203563293B3O4",
							"_tpl": "5c0126f40db834002a125382",
							"slotId": "Scabbard",
							"parentId": "5fe49444ae6628187a2e77b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150633238226641EKiv",
							"_tpl": "5ed51652f6c34d2cc26336a1",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "48264f7f5b79eab8634caad3",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150639374570244ygmK",
							"_tpl": "5c0e533786f7747fa23f4d47",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "48264f7f5b79eab8634caad3",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150639820821845KxVU",
							"_tpl": "5c0e533786f7747fa23f4d47",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "48264f7f5b79eab8634caad3",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150640387789765tsw6",
							"_tpl": "5c0e531d86f7747fa23f4d42",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "48264f7f5b79eab8634caad3",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150642143758271Grjp",
							"_tpl": "5c0e530286f7747fa1419862",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "48264f7f5b79eab8634caad3",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150644884663268J2O7",
							"_tpl": "544fb3f34bdc2d03748b456a",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "48264f7f5b79eab8634caad3",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150644981348911wTyM",
							"_tpl": "544fb3f34bdc2d03748b456a",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "48264f7f5b79eab8634caad3",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150706104419884GHtT",
							"_tpl": "628e4e576d783146b124c64d",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6e979f224a755a582140dc0b",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150706106231208lbts",
							"_tpl": "628e4e576d783146b124c64d",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6e979f224a755a582140dc0b",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150710382699887SLBY",
							"_tpl": "6033fa48ffd42c541047f728",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6e979f224a755a582140dc0b",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150710435455531Caa1",
							"_tpl": "6033fa48ffd42c541047f728",
							"slotId": "Earpiece",
							"parentId": "5fe49444ae6628187a2e77b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150710970067736ij4S",
							"_tpl": "6033fa48ffd42c541047f728",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6e979f224a755a582140dc0b",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I092315074175429401339GR",
							"_tpl": "5e00c1ad86f774747333222c",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6e979f224a755a582140dc0b",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150741731864861sGgR",
							"_tpl": "5e00c1ad86f774747333222c",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6e979f224a755a582140dc0b",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150741431012970LK9Z",
							"_tpl": "5e00c1ad86f774747333222c",
							"slotId": "Headwear",
							"parentId": "5fe49444ae6628187a2e77b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150750737252746dK0Z",
							"_tpl": "5ab8e79e86f7742d8b372e78",
							"slotId": "ArmorVest",
							"parentId": "5fe49444ae6628187a2e77b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923150750616426950p2m3",
							"_tpl": "5ab8e79e86f7742d8b372e78",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160612720132437iwRO",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I092315075037698297670LR",
							"_tpl": "5ab8e79e86f7742d8b372e78",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160612720132437iwRO",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "307fb5ac0ae0a6937a24e649",
							"_tpl": "5e2af55f86f7746d4159f07c",
							"parentId": "5fe49444ae6628187a2e78b8",
							"slotId": "hideout",
							"location": {
								"x": 3,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "e929c824b16963b3c1f24dd4",
							"_tpl": "5e340dcdcb6d5863cc5e5efb",
							"parentId": "be2c737eca1dd8acf5bc9e1d",
							"slotId": "pocket3",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "5494a182c5547f032d8152c2",
							"_tpl": "5e340dcdcb6d5863cc5e5efb",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "9c9fcda4b0f53a08aa415c7f",
							"_tpl": "5e340dcdcb6d5863cc5e5efb",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "7fb3ea7589b1c4381e755e86",
							"_tpl": "5e340dcdcb6d5863cc5e5efb",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "245c4dca97d479148c5bed05",
							"_tpl": "5e340dcdcb6d5863cc5e5efb",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 7,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "45ea7672a3cb869793156469",
							"_tpl": "5e340dcdcb6d5863cc5e5efb",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "c3f4d3ac344a96c4c8ae12ad",
							"_tpl": "5e340dcdcb6d5863cc5e5efb",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "247859fe71864ec5601c1738",
							"_tpl": "5e340dcdcb6d5863cc5e5efb",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "18f62c5fa8215b67f6d01ef3",
							"_tpl": "5e32f56fcb6d5863cc5e5ee4",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 7,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "e4ab05418cd9b3c371e9c675",
							"_tpl": "5e32f56fcb6d5863cc5e5ee4",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "e38d04b897fe43074b95f8ae",
							"_tpl": "5e32f56fcb6d5863cc5e5ee4",
							"parentId": "be2c737eca1dd8acf5bc9e1d",
							"slotId": "pocket4",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "526b5a23130d721986f3a5b8",
							"_tpl": "5e32f56fcb6d5863cc5e5ee4",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "f8a349af39c17dfae3e95e8a",
							"_tpl": "5e32f56fcb6d5863cc5e5ee4",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "35ff21edc5339cd33afdefa9",
							"_tpl": "5e32f56fcb6d5863cc5e5ee4",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "16e3bafe214130049de7613a",
							"_tpl": "5e32f56fcb6d5863cc5e5ee4",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "25a608792b4b727b3adc58e0",
							"_tpl": "5e32f56fcb6d5863cc5e5ee4",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "69c288ba282e86aea4add2b0",
							"_tpl": "58d3db5386f77426186285a0",
							"parentId": "be2c737eca1dd8acf5bc9e1d",
							"slotId": "pocket2",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "6d9ff9ddc4cc2ea3d111b2b8",
							"_tpl": "58d3db5386f77426186285a0",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "0a198e7d78eddf49f2c5d47c",
							"_tpl": "58d3db5386f77426186285a0",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "a391360d5b9fc02ab2611e17",
							"_tpl": "58d3db5386f77426186285a0",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "2f92e5ba2d704586e8c85bdc",
							"_tpl": "58d3db5386f77426186285a0",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "9b2a7d1321ab3605e5594088",
							"_tpl": "58d3db5386f77426186285a0",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 7,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "0eae732e676aef15d7af1cfe",
							"_tpl": "58d3db5386f77426186285a0",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "9339ec51fa6f3d7b200e4c40",
							"_tpl": "58d3db5386f77426186285a0",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "23f6f01d177dad0c4282261d",
							"_tpl": "5710c24ad2720bc3458b45a3",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 3,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "04fa3a02a5ce8b2d5fea4566",
							"_tpl": "5710c24ad2720bc3458b45a3",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 3,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "3d9f4cdcc72937507e84cadf",
							"_tpl": "5710c24ad2720bc3458b45a3",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 7,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 3,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "9464d703522f47fb51c361a1",
							"_tpl": "5710c24ad2720bc3458b45a3",
							"parentId": "be2c737eca1dd8acf5bc9e1d",
							"slotId": "pocket1",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "2f3ac210117fdcd99928527e",
							"_tpl": "5710c24ad2720bc3458b45a3",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "9aac8df8f5517ff35965fe96",
							"_tpl": "5710c24ad2720bc3458b45a3",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "57e01f9d8b59d09d0e0624b7",
							"_tpl": "5710c24ad2720bc3458b45a3",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "e7f86cc2cf29b21b3c2d6460",
							"_tpl": "5710c24ad2720bc3458b45a3",
							"parentId": "307fb5ac0ae0a6937a24e649",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "add3df75e8cfe05856413451",
							"_tpl": "5910968f86f77425cf569c32",
							"parentId": "5fe49444ae6628187a2e78b8",
							"slotId": "hideout",
							"location": {
								"x": 6,
								"y": 6,
								"r": "Vertical",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "39e2be2b5aa113223a13a542",
							"_tpl": "591094e086f7747caa7bb2ef",
							"parentId": "5fe49444ae6628187a2e78b8",
							"slotId": "hideout",
							"location": {
								"x": 8,
								"y": 6,
								"r": "Vertical",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "I09231605498212639068zTm",
							"_tpl": "5aafbde786f774389d0cbc0f",
							"slotId": "hideout",
							"location": {
								"x": 8,
								"y": 9,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "5fe49444ae6628187a2e78b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": "Other"
								}
							}
						},
						{
							"_id": "I0923160549838359074wGUG",
							"_tpl": "5aafbde786f774389d0cbc0f",
							"slotId": "hideout",
							"location": {
								"x": 2,
								"y": 9,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "5fe49444ae6628187a2e78b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": "762x39"
								}
							}
						},
						{
							"_id": "I0923160549738662111nnBi",
							"_tpl": "5aafbde786f774389d0cbc0f",
							"slotId": "hideout",
							"location": {
								"x": 6,
								"y": 9,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "5fe49444ae6628187a2e78b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": "762x51"
								}
							}
						},
						{
							"_id": "I0923160549508325839Y4hF",
							"_tpl": "5aafbde786f774389d0cbc0f",
							"slotId": "hideout",
							"location": {
								"x": 4,
								"y": 9,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "5fe49444ae6628187a2e78b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": "556x45"
								}
							}
						},
						{
							"_id": "I0923160549319243199X5JT",
							"_tpl": "5aafbde786f774389d0cbc0f",
							"slotId": "hideout",
							"location": {
								"x": 0,
								"y": 9,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "5fe49444ae6628187a2e78b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": ".45"
								}
							}
						},
						{
							"_id": "I0923160556890464248iIUm",
							"_tpl": "5b6d9ce188a4501afc1b2b25",
							"slotId": "hideout",
							"location": {
								"x": 0,
								"y": 14,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "5fe49444ae6628187a2e78b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": "Assault Rifles"
								}
							}
						},
						{
							"_id": "I0923160556623493093KHEX",
							"_tpl": "5b6d9ce188a4501afc1b2b25",
							"slotId": "hideout",
							"location": {
								"x": 5,
								"y": 14,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "5fe49444ae6628187a2e78b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": "Other"
								}
							}
						},
						{
							"_id": "I0923160602973905323w2QM",
							"_tpl": "5b7c710788a4506dec015957",
							"slotId": "hideout",
							"location": {
								"x": 0,
								"y": 23,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "5fe49444ae6628187a2e78b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923160602230159174A6DJ",
							"_tpl": "5b7c710788a4506dec015957",
							"slotId": "hideout",
							"location": {
								"x": 4,
								"y": 23,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "5fe49444ae6628187a2e78b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231606064060654146YQv",
							"_tpl": "5c093e3486f77430cb02e593",
							"slotId": "7",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923172355114862980Xjmy",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923160612720132437iwRO",
							"_tpl": "5c0a840b86f7742ffa4f2482",
							"slotId": "hideout",
							"location": {
								"x": 0,
								"y": 16,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "5fe49444ae6628187a2e78b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": "Armor & Rigs"
								}
							}
						},
						{
							"_id": "I0923160615894581733Jt9n",
							"_tpl": "5c127c4486f7745625356c13",
							"slotId": "hideout",
							"location": {
								"x": 8,
								"y": 11,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "5fe49444ae6628187a2e78b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": "Other"
								}
							}
						},
						{
							"_id": "I0923160615981914890Ew67",
							"_tpl": "5c127c4486f7745625356c13",
							"slotId": "hideout",
							"location": {
								"x": 2,
								"y": 11,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "5fe49444ae6628187a2e78b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": "762x39"
								}
							}
						},
						{
							"_id": "I0923160615616283334o6to",
							"_tpl": "5c127c4486f7745625356c13",
							"slotId": "hideout",
							"location": {
								"x": 4,
								"y": 11,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "5fe49444ae6628187a2e78b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": "556x45"
								}
							}
						},
						{
							"_id": "I0923160615143872800eMjk",
							"_tpl": "5c127c4486f7745625356c13",
							"slotId": "hideout",
							"location": {
								"x": 6,
								"y": 11,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "5fe49444ae6628187a2e78b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": "762x51"
								}
							}
						},
						{
							"_id": "I0923160615320067631vSra",
							"_tpl": "5c127c4486f7745625356c13",
							"slotId": "hideout",
							"location": {
								"x": 0,
								"y": 11,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "5fe49444ae6628187a2e78b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": ".45"
								}
							}
						},
						{
							"_id": "I092316064482387996028sP",
							"_tpl": "5696686a4bdc2da3298b456a",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "aa181c6bc697085eb24a8387",
							"upd": {
								"StackObjectsCount": 50000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923160655221997734MxjG",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923160655661579150cEGL",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923160655643467516U7nH",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923160655327196399dG2V",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923160655296024656bEy5",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923160655634899980j46z",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923160655543371561lxgt",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923160705321786202WWlY",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "c50bc17c282a20ad45cae2db",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"parentId": "I09231700262647132022eOS",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 400000
							}
						},
						{
							"_id": "I0923161619877040230EFdg",
							"_tpl": "5c0a840b86f7742ffa4f2482",
							"slotId": "hideout",
							"location": {
								"x": 5,
								"y": 16,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "5fe49444ae6628187a2e78b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": "Backpacks"
								}
							}
						},
						{
							"_id": "I0923161957499532300MIuG",
							"_tpl": "5a0dc45586f7742f6b0b73e3",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162004117531977qtrE",
							"_tpl": "5a0dc95c86f77452440fc675",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162016311997251vlxk",
							"_tpl": "5a0eb6ac86f7743124037a28",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162030258419121HkoX",
							"_tpl": "61a64428a8c6aa1b795f0ba1",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012629609398aM9C",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162037336030465R8G8",
							"_tpl": "5a0ea64786f7741707720468",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231620464257305228O25",
							"_tpl": "5a144dfd86f77445cb5a0982",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162110650095376Mvpg",
							"_tpl": "5a0ee30786f774023b6ee08f",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162119180063389XCPQ",
							"_tpl": "5a13eebd86f7746fd639aa93",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162138603509211jslO",
							"_tpl": "5a0f0f5886f7741c4e32a472",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162142920503796Uun7",
							"_tpl": "5a0f08bc86f77478f33b84c2",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162156877833751je6r",
							"_tpl": "5a144bdb86f7741d374bbde0",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162204956830228mR9J",
							"_tpl": "5a13f35286f77413ef1436b0",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162215958050277kfus",
							"_tpl": "5a0ee34586f774023b6ee092",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162222661457286E4cF",
							"_tpl": "5a13ef7e86f7741290491063",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162231287148888ARNs",
							"_tpl": "5a145d4786f7744cbb6f4a12",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162237896280952FJ5M",
							"_tpl": "5a0eec9686f77402ac5c39f2",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231622483010052846sqK",
							"_tpl": "5a13f46386f7741dd7384b04",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162256706080618No9V",
							"_tpl": "5a0eff2986f7741fd654e684",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162300970571332BC2u",
							"_tpl": "5a0eecf686f7740350630097",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162306431140881Gh4J",
							"_tpl": "5a145ebb86f77458f1796f05",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162404427441047y5Vh",
							"_tpl": "591382d986f774465a6413a7",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231700262647132022eOS",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162416969996398rMiG",
							"_tpl": "5780cf7f2459777de4559322",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231700262647132022eOS",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162426133200119wIAc",
							"_tpl": "59148c8a86f774197930e983",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231700262647132022eOS",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162456436558551eiKk",
							"_tpl": "5780d0652459777df90dcb74",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231700262647132022eOS",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162459378529940k8bo",
							"_tpl": "5913877a86f774432f15d444",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231700262647132022eOS",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162501364305248LAUW",
							"_tpl": "5a0f045e86f7745b0f0d0e42",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162507480192422obkE",
							"_tpl": "59387a4986f77401cc236e62",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231700262647132022eOS",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231625141257603694kU9",
							"_tpl": "5448ba0b4bdc2d02308b456c",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923170024829821580HKfP",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162522663576888MDa2",
							"_tpl": "5780cf942459777df90dcb72",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231700262647132022eOS",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162539187483313u7QC",
							"_tpl": "5ad5d7d286f77450166e0a89",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012800810394GhkG",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162541362146756xO4f",
							"_tpl": "5addaffe86f77470b455f900",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012800810394GhkG",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162607345330041cRjb",
							"_tpl": "5ad5cfbd86f7742c825d6104",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012800810394GhkG",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231626219343963429XjD",
							"_tpl": "5ad5db3786f7743568421cce",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012800810394GhkG",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162629472294635rp8F",
							"_tpl": "5ad7247386f7747487619dc3",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012800810394GhkG",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162651525564523woqA",
							"_tpl": "5ad5d64486f774079b080af8",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012800810394GhkG",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162704113897000ots6",
							"_tpl": "5c1d0f4986f7744bb01837fa",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012117881969lzoU",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162712641757458SFSX",
							"_tpl": "5c1d0c5f86f7744bb2683cf0",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012117881969lzoU",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162721452342744mSia",
							"_tpl": "5efde6b4f5448336730dbd61",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012117881969lzoU",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162726607067070OdtK",
							"_tpl": "5eff09cd30a7dc22fd1ddfed",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162735444669727Xx48",
							"_tpl": "5c1d0dc586f7744baf2e7b79",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012117881969lzoU",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162741105051133QsNf",
							"_tpl": "5c1d0efb86f7744baf2e7b7b",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012117881969lzoU",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162811840717750Qxcg",
							"_tpl": "5c1f79a086f7746ed066fb8f",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012117881969lzoU",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162813523579788gVxY",
							"_tpl": "5c1e2d1f86f77431e9280bee",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012117881969lzoU",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162815445924135I7f2",
							"_tpl": "5c1e2a1e86f77431ea0ea84c",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012117881969lzoU",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162822221409619dKAC",
							"_tpl": "5d80cb3886f77440556dbf09",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "ad6a118bc008509fbcc42221",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162828424670024HyL6",
							"_tpl": "5d95d6fa86f77424484aa5e9",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "ad6a118bc008509fbcc42221",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231628407451160469Y93",
							"_tpl": "5d80c62a86f7744036212b3f",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "ad6a118bc008509fbcc42221",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162846296380322baVX",
							"_tpl": "5d80c60f86f77440373c4ece",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "ad6a118bc008509fbcc42221",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923162859406734599Kxni",
							"_tpl": "5d8e0e0e86f774321140eb56",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "ad6a118bc008509fbcc42221",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231629545928477733l5j",
							"_tpl": "5d947d4e86f774447b415895",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "ad6a118bc008509fbcc42221",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923163004209038306c5ol",
							"_tpl": "5d80c6c586f77440351beef1",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "ad6a118bc008509fbcc42221",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231630133995671537jna",
							"_tpl": "5d80ccac86f77470841ff452",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "ad6a118bc008509fbcc42221",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923163014955364689U15y",
							"_tpl": "5d80ccdd86f77474f7575e02",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "ad6a118bc008509fbcc42221",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923163015234369493fnVz",
							"_tpl": "5d80cd1a86f77402aa362f42",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "ad6a118bc008509fbcc42221",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231630267120719986Qou",
							"_tpl": "5d947d3886f774447b415893",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "ad6a118bc008509fbcc42221",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231630366918020910U0M",
							"_tpl": "5d9f1fa686f774726974a992",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "ad6a118bc008509fbcc42221",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923163052676536479jVta",
							"_tpl": "591afe0186f77431bd616a11",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923170024829821580HKfP",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923163112566676080RcKi",
							"_tpl": "62987c658081af308d7558c6",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012629609398aM9C",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923163119233899003fmbh",
							"_tpl": "62987da96188c076bc0d8c51",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012629609398aM9C",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923163128337226353keAi",
							"_tpl": "62987dfc402c7f69bf010923",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012629609398aM9C",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923163354339051805B2Pq",
							"_tpl": "5448ba0b4bdc2d02308b456c",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231700262647132022eOS",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923164012629609398aM9C",
							"_tpl": "5d235bb686f77443f4331278",
							"slotId": "3",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923172355114862980Xjmy",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": "Lighthouse"
								}
							}
						},
						{
							"_id": "I0923164012481084680EZIJ",
							"_tpl": "5d235bb686f77443f4331278",
							"slotId": "1",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923172355114862980Xjmy",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": "Shoreline"
								}
							}
						},
						{
							"_id": "I0923164012800810394GhkG",
							"_tpl": "5d235bb686f77443f4331278",
							"slotId": "2",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923172355114862980Xjmy",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": "Interchange"
								}
							}
						},
						{
							"_id": "I0923164012117881969lzoU",
							"_tpl": "5d235bb686f77443f4331278",
							"slotId": "4",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923172355114862980Xjmy",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": "Labs"
								}
							}
						},
						{
							"_id": "I0923170023119291739gLwI",
							"_tpl": "5d235bb686f77443f4331278",
							"slotId": "6",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923172355114862980Xjmy",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923170024829821580HKfP",
							"_tpl": "5d235bb686f77443f4331278",
							"slotId": "5",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923172355114862980Xjmy",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": "Other"
								}
							}
						},
						{
							"_id": "I09231700262647132022eOS",
							"_tpl": "5d235bb686f77443f4331278",
							"slotId": "1",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923172355114862980Xjmy",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false,
								"Tag": {
									"Color": 0,
									"Name": "Customs"
								}
							}
						},
						{
							"_id": "I0923172355114862980Xjmy",
							"_tpl": "5e9db13186f7742f845ee9d3",
							"slotId": "hideout",
							"location": {
								"x": 0,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "5fe49444ae6628187a2e78b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "aa181c6bc697085eb24a8387",
							"_tpl": "59fb016586f7746d0d4b423a",
							"parentId": "5fe49444ae6628187a2e78b8",
							"slotId": "hideout",
							"location": {
								"x": 2,
								"y": 0,
								"r": 1
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "45f0c10affb653b9c69f81ac",
							"_tpl": "5c093db286f7740a1b2617e3",
							"parentId": "5fe49444ae6628187a2e78b8",
							"slotId": "hideout",
							"location": {
								"x": 4,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "f295eab439abccf8027ef460",
							"_tpl": "5aafbcd986f7745e590fff23",
							"parentId": "5fe49444ae6628187a2e78b8",
							"slotId": "hideout",
							"location": {
								"x": 7,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 1,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "8565a78d908561ebb2e20dfb",
							"_tpl": "59fb016586f7746d0d4b423a",
							"parentId": "5fe49444ae6628187a2e78b8",
							"slotId": "hideout",
							"location": {
								"x": 0,
								"y": 3,
								"r": "Vertical",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "7947a550219b0c20ec693be3",
							"_tpl": "59fb016586f7746d0d4b423a",
							"parentId": "5fe49444ae6628187a2e78b8",
							"slotId": "hideout",
							"location": {
								"x": 2,
								"y": 3,
								"r": "Vertical",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "a70e99fe1baba1af8f040baf",
							"_tpl": "59fb023c86f7746d0d4b423c",
							"parentId": "5fe49444ae6628187a2e78b8",
							"slotId": "hideout",
							"location": {
								"x": 8,
								"y": 19,
								"r": "Vertical",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "757d322eeab3640f9ed307a1",
							"_tpl": "59fb023c86f7746d0d4b423c",
							"parentId": "5fe49444ae6628187a2e78b8",
							"slotId": "hideout",
							"location": {
								"x": 8,
								"y": 24,
								"r": "Vertical",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "4a2e190061cb984ac698cd98",
							"_tpl": "5b0bbe4e5acfc40dc528a72d",
							"parentId": "I0923160556890464248iIUm",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 1,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "6b420d961b8b632cabaa9b57",
							"_tpl": "5b7bedd75acfc43d825283f9",
							"parentId": "4a2e190061cb984ac698cd98",
							"slotId": "mod_handguard",
							"upd": {
								"StackObjectsCount": 1,
								"Repairable": {
									"Durability": 100,
									"MaxDurability": 100
								}
							}
						},
						{
							"_id": "a3f2907f036f1b78d5f04af3",
							"_tpl": "5cf78720d7f00c06595bc93e",
							"parentId": "5d02a088606fe8f0e4f26d7c",
							"slotId": "mod_muzzle_001",
							"upd": {
								"StackObjectsCount": 1,
								"Repairable": {
									"Durability": 100,
									"MaxDurability": 100
								}
							}
						},
						{
							"_id": "8e1d7fe33914f8327838410e",
							"_tpl": "58491f3324597764bc48fa02",
							"parentId": "2a26b93bacc831eada432f99",
							"slotId": "mod_scope",
							"upd": {
								"StackObjectsCount": 1,
								"Repairable": {
									"Durability": 100,
									"MaxDurability": 100
								}
							}
						},
						{
							"_id": "80a6cb58f064779fcac7de79",
							"_tpl": "5b7d679f5acfc4001a5c4024",
							"parentId": "4a2e190061cb984ac698cd98",
							"slotId": "mod_pistol_grip",
							"upd": {
								"StackObjectsCount": 1,
								"Repairable": {
									"Durability": 100,
									"MaxDurability": 100
								}
							}
						},
						{
							"_id": "88dea6ff9b82f2ec0740c5d9",
							"_tpl": "5d2369418abbc306c62e0c80",
							"parentId": "599a826347b28ac2c679a93a",
							"slotId": "mod_tactical",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 4,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "5d02a088606fe8f0e4f26d7c",
							"_tpl": "5cf78496d7f00c065703d6ca",
							"parentId": "ab913eee8131b8eb4f7847d3",
							"slotId": "mod_muzzle",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 4,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "ab913eee8131b8eb4f7847d3",
							"_tpl": "5b7be1265acfc400161d0798",
							"parentId": "4a2e190061cb984ac698cd98",
							"slotId": "mod_barrel",
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "4be2adab0920aa06e05147e6",
							"_tpl": "5c878e9d2e2216000f201903",
							"parentId": "5d02a088606fe8f0e4f26d7c",
							"slotId": "mod_muzzle_000",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 4,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "2a26b93bacc831eada432f99",
							"_tpl": "5b099bb25acfc400186331e8",
							"parentId": "4a2e190061cb984ac698cd98",
							"slotId": "mod_reciever",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 4,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "599a826347b28ac2c679a93a",
							"_tpl": "5b7be4575acfc400161d0832",
							"parentId": "6b420d961b8b632cabaa9b57",
							"slotId": "mod_mount_001",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 8,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "a3bbee686d038c3ffa90028d",
							"_tpl": "5c1cd46f2e22164bef5cfedb",
							"parentId": "dc6466f62e17cc8c0bca9f34",
							"slotId": "mod_foregrip",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 3,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "dc6466f62e17cc8c0bca9f34",
							"_tpl": "5b7be46e5acfc400170e2dcf",
							"parentId": "6b420d961b8b632cabaa9b57",
							"slotId": "mod_mount_000",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 6,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "9561339044accc28f333a477",
							"_tpl": "5b7d37845acfc400170e2f87",
							"parentId": "4a2e190061cb984ac698cd98",
							"slotId": "mod_magazine",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 7,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "108b9966426dcdf821dd3d31",
							"_tpl": "5b099bf25acfc4001637e683",
							"parentId": "4a2e190061cb984ac698cd98",
							"slotId": "mod_stock",
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "5874ab8b3c06f827d0184339",
							"_tpl": "58d2947e86f77447aa070d53",
							"parentId": "9c39cbd7dd97ca27e54158f3",
							"slotId": "mod_stock_000",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 4,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "cf8969ab754ddad83817d145",
							"_tpl": "58d2912286f7744e27117493",
							"parentId": "5874ab8b3c06f827d0184339",
							"slotId": "mod_stock",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 5,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "9c39cbd7dd97ca27e54158f3",
							"_tpl": "5c793fb92e221644f31bfb64",
							"parentId": "108b9966426dcdf821dd3d31",
							"slotId": "mod_stock_000",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 5,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "f89562ad399a6e6f15a7e3b2",
							"_tpl": "58dd3ad986f77403051cba8f",
							"parentId": "9561339044accc28f333a477",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 29
							}
						},
						{
							"_id": "2376a60c9d6ffdee107b73b5",
							"_tpl": "58dd3ad986f77403051cba8f",
							"parentId": "4a2e190061cb984ac698cd98",
							"slotId": "patron_in_weapon",
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "46fe73c5bc10db3832a8c4aa",
							"_tpl": "5cadfbf7ae92152ac412eeef",
							"parentId": "5fe49444ae6628187a2e77b8",
							"slotId": "FirstPrimaryWeapon",
							"upd": {
								"StackObjectsCount": 1,
								"Repairable": {
									"Durability": 100,
									"MaxDurability": 100
								},
								"FireMode": {
									"FireMode": "single"
								}
							}
						},
						{
							"_id": "ddc91fbce6e06f7e2e0192e8",
							"_tpl": "5cdaa99dd7f00c002412d0b2",
							"parentId": "46fe73c5bc10db3832a8c4aa",
							"slotId": "mod_handguard",
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "28bb2da8f46d04c976c36b2b",
							"_tpl": "5b3b99475acfc432ff4dcbee",
							"parentId": "eede634970f78411f650ee06",
							"slotId": "mod_scope_000",
							"upd": {
								"StackObjectsCount": 1,
								"Repairable": {
									"Durability": 79,
									"MaxDurability": 100
								}
							}
						},
						{
							"_id": "eede634970f78411f650ee06",
							"_tpl": "6171407e50224f204c1da3c5",
							"parentId": "46fe73c5bc10db3832a8c4aa",
							"slotId": "mod_scope",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 3,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "49042674eb441cf353481d55",
							"_tpl": "577d141e24597739c5255e01",
							"parentId": "7cf5beee21558175c56fddc8",
							"slotId": "mod_scope",
							"upd": {
								"StackObjectsCount": 1,
								"Repairable": {
									"Durability": 67,
									"MaxDurability": 100
								}
							}
						},
						{
							"_id": "7cf5beee21558175c56fddc8",
							"_tpl": "577d128124597739d65d0e56",
							"parentId": "eede634970f78411f650ee06",
							"slotId": "mod_scope_001",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 5,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "eaf1aa6422c4cb1dfafb874e",
							"_tpl": "5d2369418abbc306c62e0c80",
							"parentId": "46fe73c5bc10db3832a8c4aa",
							"slotId": "mod_tactical_002",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 4,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "c66e42a993435bc3079ef815",
							"_tpl": "5caf1109ae9215753c44119f",
							"parentId": "46fe73c5bc10db3832a8c4aa",
							"slotId": "mod_magazine",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 5,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "142b303fa72f32c109fbf447",
							"_tpl": "5caf187cae92157c28402e43",
							"parentId": "46fe73c5bc10db3832a8c4aa",
							"slotId": "mod_muzzle",
							"upd": {
								"StackObjectsCount": 1,
								"Repairable": {
									"Durability": 83,
									"MaxDurability": 100
								}
							}
						},
						{
							"_id": "c5cb219fa42c9c2555cee62b",
							"_tpl": "5a7dbfc1159bd40016548fde",
							"parentId": "ddc91fbce6e06f7e2e0192e8",
							"slotId": "mod_foregrip",
							"upd": {
								"StackObjectsCount": 1,
								"Repairable": {
									"Durability": 75,
									"MaxDurability": 100
								}
							}
						},
						{
							"_id": "0ded896ea2eb62f7f247d23b",
							"_tpl": "5cadf6eeae921500134b2799",
							"parentId": "c66e42a993435bc3079ef815",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 20
							}
						},
						{
							"_id": "0225f70a4f8e661543d561fe",
							"_tpl": "5fc3e272f8b6a877a729eac5",
							"parentId": "I0923160556623493093KHEX",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"Foldable": {
									"Folded": false
								},
								"FireMode": {
									"FireMode": "single"
								},
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 7,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "4a8508c7972939ed02ca640a",
							"_tpl": "5fc3e466187fea44d52eda90",
							"parentId": "0225f70a4f8e661543d561fe",
							"slotId": "mod_magazine",
							"upd": {
								"Foldable": {
									"Folded": false
								},
								"FireMode": {
									"FireMode": "single"
								},
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 7,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "034cecbd0df49539a8b5036b",
							"_tpl": "5fc3e4ee7283c4046c5814af",
							"parentId": "0225f70a4f8e661543d561fe",
							"slotId": "mod_stock",
							"upd": {
								"Foldable": {
									"Folded": false
								},
								"FireMode": {
									"FireMode": "single"
								},
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 7,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "4d87e35a5c4bed9946defb16",
							"_tpl": "5fc3e4a27283c4046c5814ab",
							"parentId": "0225f70a4f8e661543d561fe",
							"slotId": "mod_barrel",
							"upd": {
								"Foldable": {
									"Folded": false
								},
								"FireMode": {
									"FireMode": "single"
								},
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 7,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "c9c461aaa8c78c7659a0d771",
							"_tpl": "5fc53954f8b6a877a729eaeb",
							"parentId": "0225f70a4f8e661543d561fe",
							"slotId": "mod_mount_000",
							"upd": {
								"Foldable": {
									"Folded": false
								},
								"FireMode": {
									"FireMode": "single"
								},
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 7,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "f4368002a8dc72cc594716a2",
							"_tpl": "5fc5396e900b1d5091531e72",
							"parentId": "0225f70a4f8e661543d561fe",
							"slotId": "mod_mount_001",
							"upd": {
								"Foldable": {
									"Folded": false
								},
								"FireMode": {
									"FireMode": "single"
								},
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 7,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "51c63a58985525cf5992e1a1",
							"_tpl": "5fc5396e900b1d5091531e72",
							"parentId": "0225f70a4f8e661543d561fe",
							"slotId": "mod_mount_002",
							"upd": {
								"Foldable": {
									"Folded": false
								},
								"FireMode": {
									"FireMode": "single"
								},
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 7,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "33ab3e860b29cacce0374f7a",
							"_tpl": "58491f3324597764bc48fa02",
							"parentId": "0225f70a4f8e661543d561fe",
							"slotId": "mod_scope",
							"upd": {
								"StackObjectsCount": 1,
								"Repairable": {
									"Durability": 100,
									"MaxDurability": 100
								}
							}
						},
						{
							"_id": "4a3e810db253c6b60b5a4d3e",
							"_tpl": "6130c4d51cb55961fa0fd49f",
							"parentId": "4d87e35a5c4bed9946defb16",
							"slotId": "mod_muzzle",
							"upd": {
								"StackObjectsCount": 1,
								"Repairable": {
									"Durability": 100,
									"MaxDurability": 100
								}
							}
						},
						{
							"_id": "995204aee4c53b48bd071bb9",
							"_tpl": "5fc3e466187fea44d52eda90",
							"parentId": "I0923160556623493093KHEX",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "a49a1232e354baca22d150ae",
							"_tpl": "59fc48e086f77463b1118392",
							"parentId": "c9c461aaa8c78c7659a0d771",
							"slotId": "mod_foregrip",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 4,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "d0f5390b8a4eabf3b57bf420",
							"_tpl": "5d2369418abbc306c62e0c80",
							"parentId": "51c63a58985525cf5992e1a1",
							"slotId": "mod_tactical",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 4,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "7713694f1a4494f07a9b84c4",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"parentId": "b359a35b901eba814a2703ac",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 30
							}
						},
						{
							"_id": "8efbd89d7817b2ba8452c04d",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"parentId": "4a8508c7972939ed02ca640a",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 25
							}
						},
						{
							"_id": "0311e4e0d26b7485023311a6",
							"_tpl": "6176aca650224f204c1da3fb",
							"parentId": "I0923160556890464248iIUm",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"FireMode": {
									"FireMode": "single"
								},
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 1,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "8712c59ed8d2c430746a623a",
							"_tpl": "617153016c780c1e710c9a2f",
							"parentId": "0311e4e0d26b7485023311a6",
							"slotId": "mod_stock",
							"upd": {
								"FireMode": {
									"FireMode": "single"
								},
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 1,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "8bf2d0156e716ffdf48dc546",
							"_tpl": "61713a8fd92c473c770214a4",
							"parentId": "0311e4e0d26b7485023311a6",
							"slotId": "mod_reciever",
							"upd": {
								"FireMode": {
									"FireMode": "single"
								},
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 1,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "71a9cac94df7812ad8ad0fec",
							"_tpl": "61702d8a67085e45ef140b24",
							"parentId": "0311e4e0d26b7485023311a6",
							"slotId": "mod_charge",
							"upd": {
								"FireMode": {
									"FireMode": "single"
								},
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 1,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "1c9f7033f2f23bd93d8cdd23",
							"_tpl": "617155ee50224f204c1da3cd",
							"parentId": "8712c59ed8d2c430746a623a",
							"slotId": "mod_stock_000",
							"upd": {
								"FireMode": {
									"FireMode": "single"
								},
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 1,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "31364d17adaee4b05ccb5b88",
							"_tpl": "61702be9faa1272e431522c3",
							"parentId": "8bf2d0156e716ffdf48dc546",
							"slotId": "mod_barrel",
							"upd": {
								"FireMode": {
									"FireMode": "single"
								},
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 1,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "dd65b123c410059df32f37b3",
							"_tpl": "61703001d92c473c77021497",
							"parentId": "8bf2d0156e716ffdf48dc546",
							"slotId": "mod_handguard",
							"upd": {
								"FireMode": {
									"FireMode": "single"
								},
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 1,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "9bf6d2f9c54c1041496f45bb",
							"_tpl": "61715e7e67085e45ef140b33",
							"parentId": "1c9f7033f2f23bd93d8cdd23",
							"slotId": "mod_stock_000",
							"upd": {
								"FireMode": {
									"FireMode": "single"
								},
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 1,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "4a05cd7d4795218fbff72783",
							"_tpl": "61702f1b67085e45ef140b26",
							"parentId": "31364d17adaee4b05ccb5b88",
							"slotId": "mod_gas_block",
							"upd": {
								"FireMode": {
									"FireMode": "single"
								},
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 1,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "210d15a84e86a961d076d9d1",
							"_tpl": "58491f3324597764bc48fa02",
							"parentId": "8bf2d0156e716ffdf48dc546",
							"slotId": "mod_scope",
							"upd": {
								"StackObjectsCount": 1,
								"Repairable": {
									"Durability": 100,
									"MaxDurability": 100
								}
							}
						},
						{
							"_id": "5eff291f32a238f4c0a07236",
							"_tpl": "617131a4568c120fdd29482d",
							"parentId": "0311e4e0d26b7485023311a6",
							"slotId": "mod_magazine",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 6,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "46674d66bf109d2812551d89",
							"_tpl": "5d2369418abbc306c62e0c80",
							"parentId": "dd65b123c410059df32f37b3",
							"slotId": "mod_tactical_002",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 4,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "56b7544dbc0f8061bbaa5752",
							"_tpl": "5a7dbfc1159bd40016548fde",
							"parentId": "dd65b123c410059df32f37b3",
							"slotId": "mod_foregrip",
							"upd": {
								"StackObjectsCount": 1,
								"Repairable": {
									"Durability": 100,
									"MaxDurability": 100
								}
							}
						},
						{
							"_id": "b3689102098be9c7a6c187cd",
							"_tpl": "5dfa3d2b0dee1b22f862eade",
							"parentId": "c0180e622e38d68c0abf2340",
							"slotId": "mod_muzzle",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 2,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "c0180e622e38d68c0abf2340",
							"_tpl": "5dfa3cd1b33c0951220c079b",
							"parentId": "31364d17adaee4b05ccb5b88",
							"slotId": "mod_muzzle",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 3,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "1fdfc85885f260600bf98d81",
							"_tpl": "5d025cc1d7ad1a53845279ef",
							"parentId": "0311e4e0d26b7485023311a6",
							"slotId": "mod_pistol_grip",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 4,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "037d58fcd23fa79679db50a9",
							"_tpl": "58dd3ad986f77403051cba8f",
							"parentId": "5eff291f32a238f4c0a07236",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 20
							}
						},
						{
							"_id": "3cccb3c1e34704f47000095d",
							"_tpl": "5cc82d76e24e8d00134b4b83",
							"parentId": "I0923160556623493093KHEX",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"Repairable": {
									"Durability": 100,
									"MaxDurability": 100
								},
								"FireMode": {
									"FireMode": "single"
								}
							}
						},
						{
							"_id": "60c9f1389877cbddf1d29ec6",
							"_tpl": "5cc70093e4a949033c734312",
							"parentId": "3cccb3c1e34704f47000095d",
							"slotId": "mod_magazine",
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "966e417185ccf4936b46577b",
							"_tpl": "5cc700b9e4a949000f0f0f25",
							"parentId": "3cccb3c1e34704f47000095d",
							"slotId": "mod_stock",
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "019cab454a9fd6793cfecd2e",
							"_tpl": "5cc701aae4a949000e1ea45c",
							"parentId": "3cccb3c1e34704f47000095d",
							"slotId": "mod_barrel",
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "6bf4a959ca0b80c015ece517",
							"_tpl": "5cc700cae4a949035e43ba72",
							"parentId": "966e417185ccf4936b46577b",
							"slotId": "mod_stock_000",
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "ccceca3c160543981bb94655",
							"_tpl": "5cc82796e24e8d000f5859a8",
							"parentId": "019cab454a9fd6793cfecd2e",
							"slotId": "mod_muzzle",
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "286c172a8ac075fa9a12e96d",
							"_tpl": "58491f3324597764bc48fa02",
							"parentId": "7ffda234c4fab69baccef673",
							"slotId": "mod_scope",
							"upd": {
								"StackObjectsCount": 1,
								"Repairable": {
									"Durability": 100,
									"MaxDurability": 100
								}
							}
						},
						{
							"_id": "b9444a486fdf539d71e693f1",
							"_tpl": "5d2369418abbc306c62e0c80",
							"parentId": "746e5ce0b7d596a695512ac1",
							"slotId": "mod_tactical",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 4,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "7ffda234c4fab69baccef673",
							"_tpl": "5cc700ede4a949033c734315",
							"parentId": "3cccb3c1e34704f47000095d",
							"slotId": "mod_reciever",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 5,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "746e5ce0b7d596a695512ac1",
							"_tpl": "5cc7012ae4a949001252b43e",
							"parentId": "7ffda234c4fab69baccef673",
							"slotId": "mod_mount_001",
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "4b50f51bd77512a761af2c57",
							"_tpl": "5cebec00d7f00c065c53522a",
							"parentId": "ccceca3c160543981bb94655",
							"slotId": "mod_muzzle",
							"upd": {
								"StackObjectsCount": 1,
								"Repairable": {
									"Durability": 66,
									"MaxDurability": 100
								}
							}
						},
						{
							"_id": "0fd8544bcbd8a68bdac59f54",
							"_tpl": "5cc6ea85e4a949000e1ea3c3",
							"parentId": "3cccb3c1e34704f47000095d",
							"slotId": "mod_charge",
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "c2c8cbc4bf22272d6f8033fd",
							"_tpl": "5fb64bc92b1b027b1f50bcf2",
							"parentId": "I0923160556623493093KHEX",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"Repairable": {
									"Durability": 100,
									"MaxDurability": 100
								},
								"FireMode": {
									"FireMode": "single"
								},
								"Foldable": {
									"Folded": false
								}
							}
						},
						{
							"_id": "52f315150aedec1b8a49a76d",
							"_tpl": "5fb6567747ce63734e3fa1dc",
							"parentId": "c2c8cbc4bf22272d6f8033fd",
							"slotId": "mod_sight_front",
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "b084e05791458b4844213183",
							"_tpl": "5fb6564947ce63734e3fa1da",
							"parentId": "c2c8cbc4bf22272d6f8033fd",
							"slotId": "mod_sight_rear",
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "d837863e3c91d733c1e9af55",
							"_tpl": "5fb65363d1409e5ca04b54f5",
							"parentId": "c2c8cbc4bf22272d6f8033fd",
							"slotId": "mod_barrel",
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "85364d4436752260e7705799",
							"_tpl": "5fbb976df9986c4cff3fe5f2",
							"parentId": "c2c8cbc4bf22272d6f8033fd",
							"slotId": "mod_mount",
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "c938bafba940690357db820b",
							"_tpl": "5fce0f9b55375d18a253eff2",
							"parentId": "c2c8cbc4bf22272d6f8033fd",
							"slotId": "mod_mount_001",
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "575def75cc977e6764e11efc",
							"_tpl": "5fce0f9b55375d18a253eff2",
							"parentId": "c2c8cbc4bf22272d6f8033fd",
							"slotId": "mod_mount_002",
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "75dadc5267bd121ff093dfac",
							"_tpl": "58491f3324597764bc48fa02",
							"parentId": "c2c8cbc4bf22272d6f8033fd",
							"slotId": "mod_scope",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 4,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "45d0fd5767897a4982193ef9",
							"_tpl": "5fc4b9b17283c4046c5814d7",
							"parentId": "b7a101caa3670d54cb1ecbee",
							"slotId": "mod_muzzle",
							"upd": {
								"StackObjectsCount": 1,
								"Repairable": {
									"Durability": 73,
									"MaxDurability": 100
								}
							}
						},
						{
							"_id": "b7a101caa3670d54cb1ecbee",
							"_tpl": "5fc4b992187fea44d52edaa9",
							"parentId": "d837863e3c91d733c1e9af55",
							"slotId": "mod_muzzle",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 4,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "c44b171de9bf6c4bc8eb9278",
							"_tpl": "5d2369418abbc306c62e0c80",
							"parentId": "575def75cc977e6764e11efc",
							"slotId": "mod_tactical",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 4,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "c605573b94dfe73946317f2a",
							"_tpl": "5b057b4f5acfc4771e1bd3e9",
							"parentId": "85364d4436752260e7705799",
							"slotId": "mod_foregrip",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 3,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "b359a35b901eba814a2703ac",
							"_tpl": "5fb651dc85f90547f674b6f4",
							"parentId": "I0923160556623493093KHEX",
							"slotId": "main",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 8,
								"BuyRestrictionCurrent": 0
							},
							"location": {
								"x": 4,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							}
						},
						{
							"_id": "86569597d2086390320bdc17",
							"_tpl": "5fb655b748c711690e3a8d5a",
							"parentId": "c2c8cbc4bf22272d6f8033fd",
							"slotId": "mod_stock",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 7,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "2fc39024f27198c77185b8f9",
							"_tpl": "58d2947e86f77447aa070d53",
							"parentId": "34dbcd8042b1f9adafb8ac9e",
							"slotId": "mod_stock_000",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 4,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "8c4dae1ff07ac8f06bf5d3c3",
							"_tpl": "58d2912286f7744e27117493",
							"parentId": "2fc39024f27198c77185b8f9",
							"slotId": "mod_stock",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 5,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "34dbcd8042b1f9adafb8ac9e",
							"_tpl": "5c793fb92e221644f31bfb64",
							"parentId": "86569597d2086390320bdc17",
							"slotId": "mod_stock_000",
							"upd": {
								"StackObjectsCount": 1,
								"BuyRestrictionMax": 5,
								"BuyRestrictionCurrent": 0
							}
						},
						{
							"_id": "I09231919234320221807ZvZ",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012629609398aM9C",
							"upd": {
								"StackObjectsCount": 200000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923360050718a5SH",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923700896513Vlu4",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923813681139QnSr",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923712639469BIVV",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231919238138795502Crr",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923851590629EHKK",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923302466464Ia8O",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231919232931652268qWB",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923705681702Fwv0",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923355252363Mvdu",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923297620250pRPq",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923658726981pSaJ",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923110792717GGgf",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923694334773tHGm",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923203984496TZqc",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923526661226hRYL",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923703111109NePB",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923482153784dwJS",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231919231139920772phx",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923436041221pkSY",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923198726814cfhy",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923550671997SIii",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231919237535813370WR6",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231919231403207663Pbn",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923327663165U2QB",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923928923984qhGs",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923574567614dMVC",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923613617649uvRg",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923929014787PhRL",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231919235684216499Ch0",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231919236379059188PV2",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923974823770jfE1",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923668814877zW0Z",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923180276503rETi",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923698691687uUml",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923348219073VabI",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231919234607322161Tcm",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923749914359Jeew",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923789450506MB44",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923666432886AhTT",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923195630119eD71",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923310202109iEZR",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923956637468fwaS",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923633359914Ibqf",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923138134327dUec",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923464939766yNGP",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923837514605rB0M",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923465255077SMLi",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923284806367ekgp",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923948018827RSUI",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923128324236diiz",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923508431215aBXR",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923179545636wpng",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "8565a78d908561ebb2e20dfb",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923688704307IR3v",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923149959204Xz78",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923920422082oHaZ",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923191923239289691VciB",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "58dcea09dd2598ffa01fb904",
							"upd": {
								"StackObjectsCount": 500000,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "a5da9e46cc2ef33a3dbda74b",
							"_tpl": "5449016a4bdc2d6f028b456f",
							"parentId": "I0923164012800810394GhkG",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 400000
							}
						},
						{
							"_id": "I0923195740422107042o25f",
							"_tpl": "59136e1e86f774432f15d133",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231700262647132022eOS",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923195751329511935s09G",
							"_tpl": "5a0ea79b86f7741d4a35298e",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923195800636000646t2L1",
							"_tpl": "5a13ef0686f7746e5a411744",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09231958078172542954kRx",
							"_tpl": "5a0ec70e86f7742c0b518fba",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923195817582495663r96u",
							"_tpl": "5a145d7b86f7744cbb6f4a13",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923164012481084680EZIJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923200435488313643QwIU",
							"_tpl": "5c0e534186f7747fa1419867",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "48264f7f5b79eab8634caad3",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232006192496057943JEc",
							"_tpl": "5648a69d4bdc2ded0b8b457b",
							"slotId": "TacticalVest",
							"parentId": "5fe49444ae6628187a2e77b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923200621280750961ISXi",
							"_tpl": "5648a69d4bdc2ded0b8b457b",
							"slotId": "main",
							"location": {
								"x": 10,
								"y": 3,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160612720132437iwRO",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923200648784255282OeMv",
							"_tpl": "5b40e1525acfc4771e1c6611",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6e979f224a755a582140dc0b",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923200650335822233Mc2D",
							"_tpl": "5b40e1525acfc4771e1c6611",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6e979f224a755a582140dc0b",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923200758437383227Umcj",
							"_tpl": "5f5e467b0bc58666c37e7821",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923161619877040230EFdg",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923200759148912298Avv3",
							"_tpl": "5f5e467b0bc58666c37e7821",
							"slotId": "Backpack",
							"parentId": "5fe49444ae6628187a2e77b8",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923201324840706584iljq",
							"_tpl": "5ac66cb05acfc40198510a10",
							"slotId": "main",
							"parentId": "I0923160556890464248iIUm",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							},
							"location": {
								"x": 0,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							}
						},
						{
							"_id": "I0923214755595362842trzU",
							"_tpl": "5b4736a986f774040571e998",
							"slotId": "mod_mount_000",
							"parentId": "I0923214940350690601PQqC",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923214802707523779UGGE",
							"_tpl": "5b4736b986f77405cb415c10",
							"slotId": "mod_mount_002",
							"parentId": "I0923214940350690601PQqC",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923214814162700671eEDY",
							"_tpl": "5e21ca18e4d47f0da15e77dd",
							"slotId": "mod_muzzle",
							"parentId": "I0923201324840706584iljq",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923214825100208484Aadp",
							"_tpl": "5ac78eaf5acfc4001926317a",
							"slotId": "mod_stock",
							"parentId": "I0923201324840706584iljq",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923214833217038732XLZm",
							"_tpl": "6130ca3fd92c473c77020dbd",
							"slotId": "mod_charge",
							"parentId": "I0923201324840706584iljq",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232148465248357228H7j",
							"_tpl": "5d2c76ed48f03532f2136169",
							"slotId": "mod_reciever",
							"parentId": "I0923201324840706584iljq",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923214930695929224d8FF",
							"_tpl": "6087e663132d4d12c81fd96b",
							"slotId": "mod_pistol_grip",
							"parentId": "I0923201324840706584iljq",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923214940350690601PQqC",
							"_tpl": "5b237e425acfc4771e1be0b6",
							"slotId": "mod_gas_block",
							"parentId": "I0923201324840706584iljq",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923214949148209476qpWF",
							"_tpl": "59ecc3dd86f7746dc827481c",
							"slotId": "mod_stock",
							"parentId": "I0923214825100208484Aadp",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923214958275999281Ok0z",
							"_tpl": "5c1bc5af2e221602b412949b",
							"slotId": "mod_foregrip",
							"parentId": "I0923214802707523779UGGE",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923215010200971543yTCp",
							"_tpl": "58491f3324597764bc48fa02",
							"slotId": "mod_scope",
							"parentId": "I09232148465248357228H7j",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923215204347927842kmW0",
							"_tpl": "5ac66c5d5acfc4001718d314",
							"slotId": "mod_magazine",
							"parentId": "I0923201324840706584iljq",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923215205376736166zUAE",
							"_tpl": "5ac66c5d5acfc4001718d314",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923215206587652094Th7R",
							"_tpl": "5ac66c5d5acfc4001718d314",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923215207737946068gINP",
							"_tpl": "5ac66c5d5acfc4001718d314",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923215209889377154L0lv",
							"_tpl": "5ac66c5d5acfc4001718d314",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923215226584321652t5hw",
							"_tpl": "5ac66c5d5acfc4001718d314",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923215227716356214U6Kw",
							"_tpl": "5ac66c5d5acfc4001718d314",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923215228223976197jLAN",
							"_tpl": "5ac66c5d5acfc4001718d314",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923215308107725527V35R",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923215308544965650Mr7Y",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923215308885855528u99J",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923215913300596663kLqD",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923215227716356214U6Kw",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923215913186446417vdVq",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923215207737946068gINP",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923215913203695969k32b",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923215228223976197jLAN",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923215913404639794DHhh",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923215226584321652t5hw",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "bde60f0bc0d9f2661dbaddfa",
							"_tpl": "54527ac44bdc2d36668b4567",
							"parentId": "I0923215209889377154L0lv",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 30
							}
						},
						{
							"_id": "52a410ee397c7245a7051467",
							"_tpl": "54527ac44bdc2d36668b4567",
							"parentId": "I0923215205376736166zUAE",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 30
							}
						},
						{
							"_id": "d8171af80898c78aac1ea3cd",
							"_tpl": "54527ac44bdc2d36668b4567",
							"parentId": "I0923215206587652094Th7R",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 30
							}
						},
						{
							"_id": "f0f4b9b7001458a9fc9ede77",
							"_tpl": "54527ac44bdc2d36668b4567",
							"parentId": "I0923215204347927842kmW0",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 30
							}
						},
						{
							"_id": "I0923220707423680234wgUy",
							"_tpl": "5648a69d4bdc2ded0b8b457b",
							"slotId": "main",
							"location": {
								"x": 10,
								"y": 0,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160612720132437iwRO",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232207208139642053mGo",
							"_tpl": "60926df0132d4d12c81fd9df",
							"slotId": "mod_muzzle",
							"parentId": "I0923220849165310739Ub9T",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923220849165310739Ub9T",
							"_tpl": "609269c3b0e443224b421cc1",
							"slotId": "mod_muzzle",
							"parentId": "I0923214814162700671eEDY",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232209012102757142AFd",
							"_tpl": "5d2369418abbc306c62e0c80",
							"slotId": "mod_tactical",
							"parentId": "I0923214755595362842trzU",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923220939973487011uj5q",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923220939697473183rfCp",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923220939786492222TQ66",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923220939750752633a84w",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923220939714835687cCIB",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923220939292584490Yisr",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923220939390156546pcwB",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923220939160993349LV2Z",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923220939269456266hxmK",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923220939509288242MEKj",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923220939789597408DJfy",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923220939581193147f49I",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232209396432841807L2m",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923220939585740981T0TH",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232209396111596279aZb",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923220939763250472HRqn",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923220939331533290MJm8",
							"_tpl": "54527ac44bdc2d36668b4567",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222223240551072nQUh",
							"_tpl": "606587252535c57a13424cfd",
							"slotId": "main",
							"parentId": "I0923160556890464248iIUm",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							},
							"location": {
								"x": 0,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							}
						},
						{
							"_id": "I092322224135569839529fr",
							"_tpl": "5a329052c4a28200741e22d3",
							"slotId": "mod_handguard",
							"parentId": "I0923222448237924002jo34",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222250413756325wruP",
							"_tpl": "6065878ac9cf8012264142fd",
							"slotId": "mod_barrel",
							"parentId": "I0923222448237924002jo34",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232223036050767768On3",
							"_tpl": "5b3b99475acfc432ff4dcbee",
							"slotId": "mod_scope",
							"parentId": "I0923222325944103340CdSx",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222325944103340CdSx",
							"_tpl": "5b3b99265acfc4704b4a1afb",
							"slotId": "mod_scope",
							"parentId": "I0923222448237924002jo34",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222337123491801yKVM",
							"_tpl": "5d443f8fa4b93678dd4a01aa",
							"slotId": "mod_muzzle",
							"parentId": "I0923222250413756325wruP",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222346243892983RGWk",
							"_tpl": "5d44064fa4b9361e4f6eb8b5",
							"slotId": "mod_muzzle",
							"parentId": "I0923222337123491801yKVM",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222400426668970q3Yc",
							"_tpl": "6065dc8a132d4d12c81fd8e3",
							"slotId": "mod_gas_block",
							"parentId": "I0923222250413756325wruP",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222410648879006V4nC",
							"_tpl": "5c0102aa0db834001b734ba1",
							"slotId": "mod_mount_004",
							"parentId": "I092322224135569839529fr",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232224121873963011SqV",
							"_tpl": "5c0102b20db834001d23eebc",
							"slotId": "mod_foregrip",
							"parentId": "I092322224135569839529fr",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222420332728604W1NS",
							"_tpl": "5d2369418abbc306c62e0c80",
							"slotId": "mod_tactical",
							"parentId": "I0923222410648879006V4nC",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222437205234613ZGNi",
							"_tpl": "5c1cd46f2e22164bef5cfedb",
							"slotId": "mod_foregrip",
							"parentId": "I09232224121873963011SqV",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222448237924002jo34",
							"_tpl": "606587a88900dc2d9a55b659",
							"slotId": "mod_reciever",
							"parentId": "I0923222223240551072nQUh",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222504679446807TT63",
							"_tpl": "59fafc5086f7740dbe19f6c3",
							"slotId": "main",
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							},
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							}
						},
						{
							"_id": "I0923222504103944186XvQ0",
							"_tpl": "59fafc5086f7740dbe19f6c3",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222504206384040chrQ",
							"_tpl": "59fafc5086f7740dbe19f6c3",
							"slotId": "mod_magazine",
							"parentId": "I0923222223240551072nQUh",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222504822826078jkfa",
							"_tpl": "59fafc5086f7740dbe19f6c3",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222504485115558h5Lg",
							"_tpl": "59fafc5086f7740dbe19f6c3",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222504389336429iP3s",
							"_tpl": "59fafc5086f7740dbe19f6c3",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222504727826135YTNL",
							"_tpl": "59fafc5086f7740dbe19f6c3",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222512340562969j1Df",
							"_tpl": "59db3a1d86f77429e05b4e92",
							"slotId": "mod_pistol_grip",
							"parentId": "I0923222223240551072nQUh",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222539444217575uS9b",
							"_tpl": "58d2912286f7744e27117493",
							"slotId": "mod_stock",
							"parentId": "I0923222615105364652iZyV",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222615105364652iZyV",
							"_tpl": "58d2946386f774496974c37e",
							"slotId": "mod_stock_000",
							"parentId": "I0923222651817762140GOKR",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923222651817762140GOKR",
							"_tpl": "5c793fb92e221644f31bfb64",
							"slotId": "mod_stock_001",
							"parentId": "I0923222223240551072nQUh",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923223341796087579R7QA",
							"_tpl": "59fafc5086f7740dbe19f6c3",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923223354976324380w0iA",
							"_tpl": "606587bd6d0bd7580617bacc",
							"slotId": "mod_charge",
							"parentId": "I0923222223240551072nQUh",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923223528826307357ZFQO",
							"_tpl": "59e0d99486f7744a32234762",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923223528609385687lX0P",
							"_tpl": "59e0d99486f7744a32234762",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923223528229900342r6V7",
							"_tpl": "59e0d99486f7744a32234762",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923223528996366419nf00",
							"_tpl": "59e0d99486f7744a32234762",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232235281959260901hUS",
							"_tpl": "59e0d99486f7744a32234762",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923223528155009200znhq",
							"_tpl": "59e0d99486f7744a32234762",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923223528525273630rqnm",
							"_tpl": "59e0d99486f7744a32234762",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923223528638852440PAnc",
							"_tpl": "59e0d99486f7744a32234762",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923223528191026487qVfj",
							"_tpl": "59e0d99486f7744a32234762",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923223528905765092DMZb",
							"_tpl": "59e0d99486f7744a32234762",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923223528964740538hXxa",
							"_tpl": "59e0d99486f7744a32234762",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923222504103944186XvQ0",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923223528238611437eVwm",
							"_tpl": "59e0d99486f7744a32234762",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923223528311539554UdgF",
							"_tpl": "59e0d99486f7744a32234762",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923223528500233093MraO",
							"_tpl": "59e0d99486f7744a32234762",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923222504822826078jkfa",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923223528714256243LSKj",
							"_tpl": "59e0d99486f7744a32234762",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "8271bce29d6a6479362d77c6",
							"_tpl": "59e0d99486f7744a32234762",
							"parentId": "I0923222504206384040chrQ",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 30
							}
						},
						{
							"_id": "a7ec3ec6bcd982c7e2d8af8c",
							"_tpl": "59e0d99486f7744a32234762",
							"parentId": "I0923222504679446807TT63",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 30
							}
						},
						{
							"_id": "b1e772cfda49bcf308abd519",
							"_tpl": "59e0d99486f7744a32234762",
							"parentId": "I0923222504727826135YTNL",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 30
							}
						},
						{
							"_id": "1fe041244cc3b4be6b1c8738",
							"_tpl": "59e0d99486f7744a32234762",
							"parentId": "I0923222504389336429iP3s",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 30
							}
						},
						{
							"_id": "febdc4fe632004391820d85b",
							"_tpl": "59e0d99486f7744a32234762",
							"parentId": "I0923222504485115558h5Lg",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 30
							}
						},
						{
							"_id": "c0f7b664cefd0b1fcc871808",
							"_tpl": "59e0d99486f7744a32234762",
							"parentId": "I0923223341796087579R7QA",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 30
							}
						},
						{
							"_id": "I0923224051529387308nZSv",
							"_tpl": "5fd4c474dd870108a754b241",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160612720132437iwRO",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224052872389689YFXj",
							"_tpl": "5fd4c474dd870108a754b241",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 9,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160612720132437iwRO",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224251120319567Ljs5",
							"_tpl": "609e860ebd219504d8507525",
							"slotId": "main",
							"location": {
								"x": 7,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160612720132437iwRO",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224252771588711MR59",
							"_tpl": "609e860ebd219504d8507525",
							"slotId": "main",
							"location": {
								"x": 7,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160612720132437iwRO",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224323834258658OA8w",
							"_tpl": "5aa7e276e5b5b000171d0647",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6e979f224a755a582140dc0b",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224324325962772bNJE",
							"_tpl": "5aa7e276e5b5b000171d0647",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6e979f224a755a582140dc0b",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224328619213467gpv7",
							"_tpl": "5aa7e373e5b5b000137b76f0",
							"slotId": "mod_equipment",
							"parentId": "I0923224323834258658OA8w",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232243294130705910KpQ",
							"_tpl": "5aa7e373e5b5b000137b76f0",
							"slotId": "mod_equipment",
							"parentId": "I0923224324325962772bNJE",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224339997566854PsQr",
							"_tpl": "5f60c74e3b85f6263c145586",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6e979f224a755a582140dc0b",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224340246951161rFSZ",
							"_tpl": "5f60c74e3b85f6263c145586",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6e979f224a755a582140dc0b",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224343880502619BC14",
							"_tpl": "5f60c85b58eff926626a60f7",
							"slotId": "mod_equipment",
							"parentId": "I0923224339997566854PsQr",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224344468236941RbGm",
							"_tpl": "5f60c85b58eff926626a60f7",
							"slotId": "mod_equipment",
							"parentId": "I0923224340246951161rFSZ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224544672090059WQSD",
							"_tpl": "5cc70093e4a949033c734312",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 2,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160556623493093KHEX",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224544321057242M3oD",
							"_tpl": "5cc70093e4a949033c734312",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160615894581733Jt9n",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224544355569948zbaB",
							"_tpl": "5cc70093e4a949033c734312",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160615894581733Jt9n",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224544154952650xh37",
							"_tpl": "5cc70093e4a949033c734312",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160615894581733Jt9n",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224544795630131ErPY",
							"_tpl": "5cc70093e4a949033c734312",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 0,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160615894581733Jt9n",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232245445128863718QuQ",
							"_tpl": "5cc70093e4a949033c734312",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 0,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160615894581733Jt9n",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224544736638225b0lc",
							"_tpl": "5cc70093e4a949033c734312",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160615894581733Jt9n",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232246239594332445Waj",
							"_tpl": "5cc80f38e4a949001152b560",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224623740087537PCtT",
							"_tpl": "5cc80f38e4a949001152b560",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232246237299288191vAq",
							"_tpl": "5cc80f38e4a949001152b560",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224623948600889ns0y",
							"_tpl": "5cc80f38e4a949001152b560",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224623357836111WVoG",
							"_tpl": "5cc80f38e4a949001152b560",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224623138600107vdoi",
							"_tpl": "5cc80f38e4a949001152b560",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224623959956552z0mT",
							"_tpl": "5cc80f38e4a949001152b560",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224623877522742yall",
							"_tpl": "5cc80f38e4a949001152b560",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224623338795538Pcag",
							"_tpl": "5cc80f38e4a949001152b560",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224623507701018pFJ1",
							"_tpl": "5cc80f38e4a949001152b560",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224623971283528E8HC",
							"_tpl": "5cc80f38e4a949001152b560",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224623655423998mBpG",
							"_tpl": "5cc80f38e4a949001152b560",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923224544736638225b0lc",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224623442047997HNiG",
							"_tpl": "5cc80f38e4a949001152b560",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923224544672090059WQSD",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224623804597450N2XE",
							"_tpl": "5cc80f38e4a949001152b560",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923224544321057242M3oD",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232246235491061295Dgg",
							"_tpl": "5cc80f38e4a949001152b560",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923224544154952650xh37",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232246236826446234oqH",
							"_tpl": "5cc80f38e4a949001152b560",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923224544795630131ErPY",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923224623527079810x1Ao",
							"_tpl": "5cc80f38e4a949001152b560",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923224544355569948zbaB",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "94701fa129669d11d93503eb",
							"_tpl": "5cc80f38e4a949001152b560",
							"parentId": "I09232245445128863718QuQ",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 50
							}
						},
						{
							"_id": "I09232305118826056333UHB",
							"_tpl": "606dae0ab0e443224b421bb7",
							"slotId": "main",
							"parentId": "I0923160556623493093KHEX",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							},
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							}
						},
						{
							"_id": "I0923230511372063010Vptw",
							"_tpl": "6076c1b9f2cb2e02a42acedc",
							"slotId": "mod_barrel",
							"parentId": "I09232305118826056333UHB"
						},
						{
							"_id": "I0923230511315714017nDxJ",
							"_tpl": "606ee5c81246154cad35d65e",
							"slotId": "mod_handguard",
							"parentId": "I09232305118826056333UHB"
						},
						{
							"_id": "I0923230511246384454XEOh",
							"_tpl": "6076c87f232e5a31c233d50e",
							"slotId": "mod_magazine",
							"parentId": "I09232305118826056333UHB"
						},
						{
							"_id": "I0923230511776509988yWrd",
							"_tpl": "606eef46232e5a31c233d500",
							"slotId": "mod_stock",
							"parentId": "I09232305118826056333UHB"
						},
						{
							"_id": "I0923230511390462691RiKN",
							"_tpl": "606eef756d0bd7580617baf8",
							"slotId": "mod_stock",
							"parentId": "I0923230511776509988yWrd"
						},
						{
							"_id": "I0923230511300973345IsRC",
							"_tpl": "606f2696f2cb2e02a42aceb1",
							"slotId": "mod_tactical",
							"parentId": "I0923230511390462691RiKN"
						},
						{
							"_id": "I0923230511304555612YUtQ",
							"_tpl": "60785ce5132d4d12c81fd918",
							"slotId": "mod_mount",
							"parentId": "I09232305118826056333UHB"
						},
						{
							"_id": "I0923230533631035802hSnZ",
							"_tpl": "607ea812232e5a31c233d53c",
							"slotId": "mod_mount_000",
							"parentId": "I0923230511315714017nDxJ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230546175469808Iy8P",
							"_tpl": "606f262c6d0bd7580617bafa",
							"slotId": "mod_stock",
							"parentId": "I0923230511390462691RiKN",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230638417045912Pfp5",
							"_tpl": "6076c87f232e5a31c233d50e",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 2,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160615894581733Jt9n",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230644537675924T9Za",
							"_tpl": "6076c87f232e5a31c233d50e",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 2,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160615894581733Jt9n",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232306447799279943t6a",
							"_tpl": "6076c87f232e5a31c233d50e",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 2,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160615894581733Jt9n",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230644832328258PjlS",
							"_tpl": "6076c87f232e5a31c233d50e",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 2,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160615894581733Jt9n",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230644665062330kqC1",
							"_tpl": "6076c87f232e5a31c233d50e",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 2,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160615894581733Jt9n",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230644933261054BaLW",
							"_tpl": "6076c87f232e5a31c233d50e",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160615894581733Jt9n",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230644898623337KaU1",
							"_tpl": "6076c87f232e5a31c233d50e",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 2,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160615894581733Jt9n",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230709431073558TnO6",
							"_tpl": "5c0111ab0db834001966914d",
							"slotId": "mod_muzzle",
							"parentId": "I0923230511372063010Vptw",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230728116003107Lnwl",
							"_tpl": "59c0ec5b86f77435b128bfca",
							"slotId": "mod_muzzle",
							"parentId": "I0923230709431073558TnO6",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230744872244967z8Zj",
							"_tpl": "56def37dd2720bec348b456a",
							"slotId": "mod_tactical",
							"parentId": "I0923230533631035802hSnZ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230800133032178CaEv",
							"_tpl": "570fd6c2d2720bc6458b457f",
							"slotId": "mod_scope",
							"parentId": "I0923230511304555612YUtQ",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230823775377986tpnA",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923230644832328258PjlS",
							"upd": {
								"StackObjectsCount": 6,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232308233463290596QnG",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230823516687928Dsnz",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230823270382880qqNv",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230823455496174Wt4i",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230823421307911Lmmk",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230823200103048RAoZ",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230823311265750dH0X",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230823657410919FMD6",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230823925794127JqFg",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230823399131554MK0f",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230823777968840sgUf",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230823235518198np9K",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230823279747875bNKI",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230823345423685Ot8g",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230823907540009vxDq",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230823158938023T1rc",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923230823451900796VJnw",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "65710356807375afc6845dc4",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"parentId": "I0923230644933261054BaLW",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 6
							}
						},
						{
							"_id": "765308b2c3df9156c2d2334b",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"parentId": "I09232305118826056333UHB",
							"slotId": "patron_in_weapon",
							"upd": {
								"StackObjectsCount": 1
							}
						},
						{
							"_id": "5a2ab212161b79e10b101ae0",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"parentId": "I0923230511246384454XEOh",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 6
							}
						},
						{
							"_id": "fea8b147da3e4cca951eb550",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"parentId": "I0923230638417045912Pfp5",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 6
							}
						},
						{
							"_id": "04adcf1d8f5c40641939456a",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"parentId": "I0923230644537675924T9Za",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 6
							}
						},
						{
							"_id": "ea9891cd38be51eab4023416",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"parentId": "I09232306447799279943t6a",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 6
							}
						},
						{
							"_id": "ebdf458d9acee31c0cac5e3f",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"parentId": "I0923230644665062330kqC1",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 6
							}
						},
						{
							"_id": "3a6029b5a24a284373dafb32",
							"_tpl": "5d6e6911a4b9361bd5780d52",
							"parentId": "I0923230644898623337KaU1",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 6
							}
						},
						{
							"_id": "I0923232027186859751F3nm",
							"_tpl": "5cc70093e4a949033c734312",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160615894581733Jt9n",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232040109629854Trnh",
							"_tpl": "5cc80f38e4a949001152b560",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923232027186859751F3nm",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232056798161833fftQ",
							"_tpl": "5fc3e466187fea44d52eda90",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615320067631vSra",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232056395933083STrK",
							"_tpl": "5fc3e466187fea44d52eda90",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615320067631vSra",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232056665163163NrMk",
							"_tpl": "5fc3e466187fea44d52eda90",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615320067631vSra",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232056330589870qGVE",
							"_tpl": "5fc3e466187fea44d52eda90",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615320067631vSra",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232056565635216vmEg",
							"_tpl": "5fc3e466187fea44d52eda90",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615320067631vSra",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232320567763903250VXP",
							"_tpl": "5fc3e466187fea44d52eda90",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615320067631vSra",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232056833986324ymd9",
							"_tpl": "5fc3e466187fea44d52eda90",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615320067631vSra",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232126368613442eUmp",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923232056395933083STrK",
							"upd": {
								"StackObjectsCount": 25,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232126775502006hqqA",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923232056833986324ymd9",
							"upd": {
								"StackObjectsCount": 25,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232126892603134iYcL",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923232056565635216vmEg",
							"upd": {
								"StackObjectsCount": 25,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232321261406097409J6V",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923232140458441758sCLD",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232126406121777lGhR",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923232140979470076PxnN",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232321269914435868Qc2",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923232140583789102q8Sq",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232126436067202s1Nt",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923232140700091604ZSfV",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232126903660036uMfn",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549319243199X5JT",
							"upd": {
								"StackObjectsCount": 10,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232126528007563dE1p",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549319243199X5JT",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232126455704654AFej",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549319243199X5JT",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232126858989038B4Jv",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549319243199X5JT",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232126466843678CK6e",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549319243199X5JT",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232126878059401A3BK",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549319243199X5JT",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232126998439806l4O6",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549319243199X5JT",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232321267455857662iC9",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549319243199X5JT",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I092323212695987588803Ij",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549319243199X5JT",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232126897084950vNbN",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549319243199X5JT",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232126496836104lySJ",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549319243199X5JT",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232126876364705XoTO",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549319243199X5JT",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232321261076245209TEo",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549319243199X5JT",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232140979470076PxnN",
							"_tpl": "5fb651dc85f90547f674b6f4",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615320067631vSra",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232140251560372xppg",
							"_tpl": "5fb651dc85f90547f674b6f4",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615320067631vSra",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232140458441758sCLD",
							"_tpl": "5fb651dc85f90547f674b6f4",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615320067631vSra",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232140955506526jOqL",
							"_tpl": "5fb651dc85f90547f674b6f4",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615320067631vSra",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232140338684238U850",
							"_tpl": "5fb651dc85f90547f674b6f4",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615320067631vSra",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232140700091604ZSfV",
							"_tpl": "5fb651dc85f90547f674b6f4",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615320067631vSra",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232140583789102q8Sq",
							"_tpl": "5fb651dc85f90547f674b6f4",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615320067631vSra",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232213857980251eEMN",
							"_tpl": "5caf1109ae9215753c44119f",
							"slotId": "5",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09232006192496057943JEc",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232213199914296WuQ4",
							"_tpl": "5caf1109ae9215753c44119f",
							"slotId": "5",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09232006192496057943JEc",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232213192389051cQoA",
							"_tpl": "5caf1109ae9215753c44119f",
							"slotId": "3",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09232006192496057943JEc",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232213831177022914t",
							"_tpl": "5caf1109ae9215753c44119f",
							"slotId": "2",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09232006192496057943JEc",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232322131518687229tLD",
							"_tpl": "5caf1109ae9215753c44119f",
							"slotId": "1",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09232006192496057943JEc",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232213731666697lJua",
							"_tpl": "5caf1109ae9215753c44119f",
							"slotId": "4",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09232006192496057943JEc",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232322137521521558ctC",
							"_tpl": "5caf1109ae9215753c44119f",
							"slotId": "10",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09232006192496057943JEc",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326196670428rvZU",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326536901162X5Rr",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326753733555LAmx",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326843598608EB2d",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I092323232680233880083kB",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232323267064267044qiZ",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326694434178qTwz",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326555685336bQJK",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326681806986V3EQ",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232323269370212091kTL",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326382283830OrzC",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326630752946Ir45",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326536522397Z0km",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326807430697kGVh",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326514684590aUZT",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326798836698EF7S",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923232213192389051cQoA",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326768118161GYX3",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I09232322131518687229tLD",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326753854247NHKb",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326801082664V4Oc",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326184278666kieI",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326296772950wwfP",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326858675947GlUi",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326886616562fTDb",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09231605498212639068zTm",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232323269653610293T5p",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923232213731666697lJua",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326226554678HlPx",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923232213857980251eEMN",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232326624643073UOOU",
							"_tpl": "5cadf6eeae921500134b2799",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I09232322137521521558ctC",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232401535223167spqf",
							"_tpl": "5b7d37845acfc400170e2f87",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615143872800eMjk",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232401292769590oyOz",
							"_tpl": "5b7d37845acfc400170e2f87",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615143872800eMjk",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232324012074406151BEt",
							"_tpl": "5b7d37845acfc400170e2f87",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615143872800eMjk",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232401474058288ULcc",
							"_tpl": "5b7d37845acfc400170e2f87",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615143872800eMjk",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232401320865214hZjj",
							"_tpl": "5b7d37845acfc400170e2f87",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615143872800eMjk",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232401375095187xgd8",
							"_tpl": "5b7d37845acfc400170e2f87",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615143872800eMjk",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232324014007092476ug6",
							"_tpl": "5b7d37845acfc400170e2f87",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615143872800eMjk",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232441957284162M05S",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549738662111nnBi",
							"upd": {
								"StackObjectsCount": 10,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I092323244160909156521Ct",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549738662111nnBi",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232441761544683eN9m",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549738662111nnBi",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232441223638675OQKX",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549738662111nnBi",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232441362033340T5R5",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549738662111nnBi",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232324413619680954XWX",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549738662111nnBi",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232441393790021rB4X",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549738662111nnBi",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232324411539529455hM3",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549738662111nnBi",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232441799845320pMGj",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549738662111nnBi",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232441756915174PlNw",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549738662111nnBi",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232324414863409045XNe",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549738662111nnBi",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232441588839020ZSO6",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549738662111nnBi",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I092323244140781091623Gs",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549738662111nnBi",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232441892370210o7FV",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549738662111nnBi",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232441512155449JXqJ",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549738662111nnBi",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232441124263916HGun",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549738662111nnBi",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232441586799836yYsB",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549738662111nnBi",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232324415520296382mIW",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923232401535223167spqf",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232441431840501SObZ",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923232401292769590oyOz",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232441970389587xFat",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I09232324012074406151BEt",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232441693778640cX1Q",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923232401375095187xgd8",
							"upd": {
								"StackObjectsCount": 30,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232441560944798vyhN",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923232455205074839gizx",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232441109842931aWBA",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923232455265805129nmgt",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232441161207598rwvh",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0923232455551218111Xd7t",
							"upd": {
								"StackObjectsCount": 20,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232324551438806499Lia",
							"_tpl": "617131a4568c120fdd29482d",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615143872800eMjk",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232455551218111Xd7t",
							"_tpl": "617131a4568c120fdd29482d",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615143872800eMjk",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232455728397875bbAN",
							"_tpl": "617131a4568c120fdd29482d",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615143872800eMjk",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232455265805129nmgt",
							"_tpl": "617131a4568c120fdd29482d",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615143872800eMjk",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232455504242170VKDh",
							"_tpl": "617131a4568c120fdd29482d",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615143872800eMjk",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232455205074839gizx",
							"_tpl": "617131a4568c120fdd29482d",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615143872800eMjk",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923232455719846451EwD8",
							"_tpl": "617131a4568c120fdd29482d",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615143872800eMjk",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "dd88a92e06d45a9eeccf014a",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"parentId": "I0923232056798161833fftQ",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 25
							}
						},
						{
							"_id": "d9a4c73508b288a69491c400",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"parentId": "I0923232056665163163NrMk",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 25
							}
						},
						{
							"_id": "8619129f1f0439ab2daafa0e",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"parentId": "I09232320567763903250VXP",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 25
							}
						},
						{
							"_id": "84ae09ac73d1f8706f086b20",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"parentId": "I0923232056330589870qGVE",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 25
							}
						},
						{
							"_id": "076411e855e7976e04556029",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"parentId": "I09232324551438806499Lia",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 20
							}
						},
						{
							"_id": "5f40d036ce6f0327dfb5f87d",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"parentId": "I0923232455728397875bbAN",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 20
							}
						},
						{
							"_id": "4da20871887af12de88e1343",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"parentId": "I0923232455504242170VKDh",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 20
							}
						},
						{
							"_id": "71e38ad0d17650180a732c40",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"parentId": "I0923232455719846451EwD8",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 20
							}
						},
						{
							"_id": "08457067516d55ba3e0b8888",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"parentId": "I0923232401320865214hZjj",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 30
							}
						},
						{
							"_id": "151a8aa688e9eb512e6e6ab1",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"parentId": "I0923232401474058288ULcc",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 30
							}
						},
						{
							"_id": "686ace1ea47b94dfd0fc3732",
							"_tpl": "5efb0c1bd79ff02a1f5e68d9",
							"parentId": "I09232324014007092476ug6",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 30
							}
						},
						{
							"_id": "012b864a398271b1f0c3bd26",
							"_tpl": "5cadf6eeae921500134b2799",
							"parentId": "I0923232213199914296WuQ4",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 20
							}
						},
						{
							"_id": "b91bf0fb7851169e64c9eb15",
							"_tpl": "5cadf6eeae921500134b2799",
							"parentId": "I0923232213831177022914t",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 20
							}
						},
						{
							"_id": "4796e94f0502f8598e19c364",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"parentId": "I0923232140251560372xppg",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 30
							}
						},
						{
							"_id": "e39b239d58bd1d485fc2c5b7",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"parentId": "I0923232140955506526jOqL",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 30
							}
						},
						{
							"_id": "e4e2a710111f8b555e994b34",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"parentId": "I0923232140338684238U850",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 30
							}
						},
						{
							"_id": "I0923233832613127754C9Ra",
							"_tpl": "5d02797c86f774203f38e30a",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6ea94462e857b6bc08a98c77",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232339138532113757YZz",
							"_tpl": "5755383e24597772cb798966",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923233917733348314R88G",
							"_tpl": "5af0454c86f7746bf20992e8",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09232340404636336192nss",
							"_tpl": "5e32f56fcb6d5863cc5e5ee4",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "307fb5ac0ae0a6937a24e649",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923234042491269294V6U7",
							"_tpl": "5e340dcdcb6d5863cc5e5efb",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "307fb5ac0ae0a6937a24e649",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923234050274953056hsAF",
							"_tpl": "58d3db5386f77426186285a0",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "307fb5ac0ae0a6937a24e649",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0923234057170109851vyLt",
							"_tpl": "5710c24ad2720bc3458b45a3",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "307fb5ac0ae0a6937a24e649",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "82c297f91fa2e34184f3f6f8",
							"_tpl": "544fb45d4bdc2dee738b4568",
							"parentId": "6ea94462e857b6bc08a98c77",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 1,
								"r": "Vertical",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"MedKit": {
									"HpResource": 400
								}
							}
						},
						{
							"_id": "9096cfe0ab527c3307b5d21b",
							"_tpl": "544fb45d4bdc2dee738b4568",
							"parentId": "6ea94462e857b6bc08a98c77",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Vertical",
								"isSearched": true
							},
							"upd": {
								"StackObjectsCount": 1,
								"MedKit": {
									"HpResource": 400
								}
							}
						},
						{
							"_id": "I0924103107778428081sqkF",
							"_tpl": "5447a9cd4bdc2dbd208b4567",
							"slotId": "main",
							"parentId": "I0923160556890464248iIUm",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							},
							"location": {
								"x": 0,
								"y": 8,
								"r": "Horizontal",
								"isSearched": true
							}
						},
						{
							"_id": "I0924103120455022238ufJP",
							"_tpl": "5b7be4895acfc400170e2dd5",
							"slotId": "mod_foregrip",
							"parentId": "I0924103349974187676Ui7W",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103151619658328ce0S",
							"_tpl": "5b2240bf5acfc40dc528af69",
							"slotId": "mod_charge",
							"parentId": "I0924103107778428081sqkF",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103208218434683YySW",
							"_tpl": "5d00ec68d7ad1a04a067e5be",
							"slotId": "mod_gas_block",
							"parentId": "I0924103319324988536y9px",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103227117032337ubpq",
							"_tpl": "609269c3b0e443224b421cc1",
							"slotId": "mod_muzzle",
							"parentId": "I0924103319324988536y9px",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103250164137320siVg",
							"_tpl": "5c793fb92e221644f31bfb64",
							"slotId": "mod_stock",
							"parentId": "I0924103107778428081sqkF",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103300222232471IFDc",
							"_tpl": "56def37dd2720bec348b456a",
							"slotId": "mod_tactical_003",
							"parentId": "I0924103349974187676Ui7W",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103308133525410uPiQ",
							"_tpl": "59db3a1d86f77429e05b4e92",
							"slotId": "mod_pistol_grip",
							"parentId": "I0924103107778428081sqkF",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103319324988536y9px",
							"_tpl": "55d3632e4bdc2d972f8b4569",
							"slotId": "mod_barrel",
							"parentId": "I0924103334398173930rgvU",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103334398173930rgvU",
							"_tpl": "59bfe68886f7746004266202",
							"slotId": "mod_reciever",
							"parentId": "I0924103107778428081sqkF",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103349974187676Ui7W",
							"_tpl": "5c78f2492e221600114c9f04",
							"slotId": "mod_handguard",
							"parentId": "I0924103334398173930rgvU",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103437700139563xVFY",
							"_tpl": "618ba27d9008e4636a67f61d",
							"slotId": "mod_scope",
							"parentId": "I0924103446360670578SzTW",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103446360670578SzTW",
							"_tpl": "5b3b99265acfc4704b4a1afb",
							"slotId": "mod_scope",
							"parentId": "I0924103334398173930rgvU",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103527494511197jlwK",
							"_tpl": "5e8488fa988a8701445df1e4",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103527962379058treL",
							"_tpl": "5e8488fa988a8701445df1e4",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103527967519895BK8D",
							"_tpl": "5e8488fa988a8701445df1e4",
							"slotId": "9",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09232006192496057943JEc",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103527556977741M1Gs",
							"_tpl": "5e8488fa988a8701445df1e4",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103527792750031i52y",
							"_tpl": "5e8488fa988a8701445df1e4",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103527716030157mvNX",
							"_tpl": "5e8488fa988a8701445df1e4",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103527345997008b6Xh",
							"_tpl": "5e8488fa988a8701445df1e4",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103527526804161AldW",
							"_tpl": "5e8488fa988a8701445df1e4",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103544648723089xDuy",
							"_tpl": "544fb3f34bdc2d03748b456a",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241035445525022492le6",
							"_tpl": "544fb3f34bdc2d03748b456a",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "48264f7f5b79eab8634caad3",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I092410354453463012581Cg",
							"_tpl": "544fb3f34bdc2d03748b456a",
							"slotId": "8",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I09232006192496057943JEc",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103544765302567qjES",
							"_tpl": "544fb3f34bdc2d03748b456a",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103544787582463jFYj",
							"_tpl": "544fb3f34bdc2d03748b456a",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103544686262746T7Dq",
							"_tpl": "544fb3f34bdc2d03748b456a",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103544523048886Zxz3",
							"_tpl": "544fb3f34bdc2d03748b456a",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I092410354431346999361BD",
							"_tpl": "544fb3f34bdc2d03748b456a",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103544390691891BSdd",
							"_tpl": "544fb3f34bdc2d03748b456a",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103558777024441asLW",
							"_tpl": "61605e13ffa6e502ac5e7eef",
							"slotId": "SpecialSlot1",
							"parentId": "be2c737eca1dd8acf5bc9e1d",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103618932301088Rm3n",
							"_tpl": "5448be9a4bdc2dfd2f8b456a",
							"slotId": "main",
							"location": {
								"x": 7,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "307fb5ac0ae0a6937a24e649",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103618196485554Fqy0",
							"_tpl": "5448be9a4bdc2dfd2f8b456a",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "307fb5ac0ae0a6937a24e649",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103618388895884jQJs",
							"_tpl": "5448be9a4bdc2dfd2f8b456a",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "307fb5ac0ae0a6937a24e649",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103618267583560OJ8I",
							"_tpl": "5448be9a4bdc2dfd2f8b456a",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "307fb5ac0ae0a6937a24e649",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103618991388501AaPv",
							"_tpl": "5448be9a4bdc2dfd2f8b456a",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "307fb5ac0ae0a6937a24e649",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103618650027003Yisl",
							"_tpl": "5448be9a4bdc2dfd2f8b456a",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "307fb5ac0ae0a6937a24e649",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241036184557610338LYo",
							"_tpl": "5448be9a4bdc2dfd2f8b456a",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "307fb5ac0ae0a6937a24e649",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924103618994815864Fcx5",
							"_tpl": "5448be9a4bdc2dfd2f8b456a",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "307fb5ac0ae0a6937a24e649",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241047267881391762Aa2",
							"_tpl": "58d2947e86f77447aa070d53",
							"slotId": "mod_stock_000",
							"parentId": "I0924103250164137320siVg",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924104735340849715KG22",
							"_tpl": "58d2912286f7744e27117493",
							"slotId": "mod_stock",
							"parentId": "I09241047267881391762Aa2",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924104756415952079245R",
							"_tpl": "60926df0132d4d12c81fd9df",
							"slotId": "mod_muzzle",
							"parentId": "I0924103227117032337ubpq",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105332684254419zzfZ",
							"_tpl": "544a37c44bdc2d25388b4567",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241053328431412155ems",
							"_tpl": "544a37c44bdc2d25388b4567",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241053327655777708dEZ",
							"_tpl": "544a37c44bdc2d25388b4567",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105332690371679ktS8",
							"_tpl": "544a37c44bdc2d25388b4567",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105332139651141SLw6",
							"_tpl": "544a37c44bdc2d25388b4567",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105332583422521tq43",
							"_tpl": "544a37c44bdc2d25388b4567",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105332985534327XAtI",
							"_tpl": "544a37c44bdc2d25388b4567",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I092410533243103553027E4",
							"_tpl": "544a37c44bdc2d25388b4567",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 6,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105332960441254eFBI",
							"_tpl": "544a37c44bdc2d25388b4567",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241053329512127409b7w",
							"_tpl": "544a37c44bdc2d25388b4567",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105332444672343yHOe",
							"_tpl": "544a37c44bdc2d25388b4567",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105332251208664t55f",
							"_tpl": "544a37c44bdc2d25388b4567",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105332695777288GQKH",
							"_tpl": "544a37c44bdc2d25388b4567",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105332877598089fXTK",
							"_tpl": "544a37c44bdc2d25388b4567",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105332447185528SLjb",
							"_tpl": "544a37c44bdc2d25388b4567",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105332767247190Dtjf",
							"_tpl": "544a37c44bdc2d25388b4567",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 6,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105332560940332yL5n",
							"_tpl": "544a37c44bdc2d25388b4567",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 6,
								"r": "Vertical",
								"isSearched": true
							},
							"parentId": "I0923160615616283334o6to",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105346518733344aQkj",
							"_tpl": "59e690b686f7746c9f75e848",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105346939262659UuFz",
							"_tpl": "59e690b686f7746c9f75e848",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105346310493788ccuK",
							"_tpl": "59e690b686f7746c9f75e848",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0924105332684254419zzfZ",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105346122402195C6VG",
							"_tpl": "59e690b686f7746c9f75e848",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I09241053328431412155ems",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105346905194006BNVH",
							"_tpl": "59e690b686f7746c9f75e848",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I09241053327655777708dEZ",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105346767884408lZNY",
							"_tpl": "59e690b686f7746c9f75e848",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0924105332690371679ktS8",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241053467938882398hS8",
							"_tpl": "59e690b686f7746c9f75e848",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0924105332139651141SLw6",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105346736280704WQqn",
							"_tpl": "59e690b686f7746c9f75e848",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0924105332583422521tq43",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105346122482873XCWF",
							"_tpl": "59e690b686f7746c9f75e848",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0924105332985534327XAtI",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105346743524587h9A0",
							"_tpl": "59e690b686f7746c9f75e848",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105346411951429k3Ak",
							"_tpl": "59e690b686f7746c9f75e848",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105346793530354GP3h",
							"_tpl": "59e690b686f7746c9f75e848",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105346624225793u7dE",
							"_tpl": "59e690b686f7746c9f75e848",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105346768332154rIP6",
							"_tpl": "59e690b686f7746c9f75e848",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105346478609523EMIv",
							"_tpl": "59e690b686f7746c9f75e848",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105346441258942Ll7N",
							"_tpl": "59e690b686f7746c9f75e848",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241053467726087176p63",
							"_tpl": "59e690b686f7746c9f75e848",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241053572767808494oNn",
							"_tpl": "59e6906286f7746c9f75e847",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0924105332960441254eFBI",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105357252617759xiPO",
							"_tpl": "59e6906286f7746c9f75e847",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I09241053329512127409b7w",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105357425949669xSmY",
							"_tpl": "59e6906286f7746c9f75e847",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0924105332444672343yHOe",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241053573606639104WOM",
							"_tpl": "59e6906286f7746c9f75e847",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0924105332251208664t55f",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105357316321201PWnB",
							"_tpl": "59e6906286f7746c9f75e847",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0924105332695777288GQKH",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105357524698609zQGi",
							"_tpl": "59e6906286f7746c9f75e847",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0924105332877598089fXTK",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105357570384388QzYL",
							"_tpl": "59e6906286f7746c9f75e847",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0924105332447185528SLjb",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105357466026757pJyz",
							"_tpl": "59e6906286f7746c9f75e847",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105357853021358C5QA",
							"_tpl": "59e6906286f7746c9f75e847",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105357707025543A1MH",
							"_tpl": "59e6906286f7746c9f75e847",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105357429024911HVzP",
							"_tpl": "59e6906286f7746c9f75e847",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105357309177742EOta",
							"_tpl": "59e6906286f7746c9f75e847",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105357849238463njnT",
							"_tpl": "59e6906286f7746c9f75e847",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105357261027050ebtD",
							"_tpl": "59e6906286f7746c9f75e847",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241053572306517071c2W",
							"_tpl": "59e6906286f7746c9f75e847",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105357713978623iWLF",
							"_tpl": "59e6906286f7746c9f75e847",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105357188405538o5eP",
							"_tpl": "59e6906286f7746c9f75e847",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549508325839Y4hF",
							"upd": {
								"StackObjectsCount": 40,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241054092988239158MPx",
							"_tpl": "5755383e24597772cb798966",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "4762bc96ec1eb296c80c9766",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105409799673885uXHZ",
							"_tpl": "5755383e24597772cb798966",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105409387258239aYnH",
							"_tpl": "5755383e24597772cb798966",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105409798759501NJZW",
							"_tpl": "5755383e24597772cb798966",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105409211257997w2gS",
							"_tpl": "5755383e24597772cb798966",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105409665756829mxg2",
							"_tpl": "5755383e24597772cb798966",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105409887985335B8sQ",
							"_tpl": "5755383e24597772cb798966",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105421251802981kn7I",
							"_tpl": "5af0454c86f7746bf20992e8",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105421598975136t2b0",
							"_tpl": "5af0454c86f7746bf20992e8",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "4762bc96ec1eb296c80c9766",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105421122138835MQtQ",
							"_tpl": "5af0454c86f7746bf20992e8",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105421490888809TxJh",
							"_tpl": "5af0454c86f7746bf20992e8",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105421761795730D9LK",
							"_tpl": "5af0454c86f7746bf20992e8",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105421554513904UXbI",
							"_tpl": "5af0454c86f7746bf20992e8",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105421674357959tJmD",
							"_tpl": "5af0454c86f7746bf20992e8",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105431829384516ao88",
							"_tpl": "5c0e530286f7747fa1419862",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105431260448280oOYD",
							"_tpl": "5c0e530286f7747fa1419862",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241054318189322187sYD",
							"_tpl": "5c0e530286f7747fa1419862",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241054312207525900AAF",
							"_tpl": "5c0e530286f7747fa1419862",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105431383292080fDAO",
							"_tpl": "5c0e530286f7747fa1419862",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241054312252612956xN0",
							"_tpl": "5c0e530286f7747fa1419862",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105431351910443ewPD",
							"_tpl": "5c0e530286f7747fa1419862",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105438255602317NU3g",
							"_tpl": "5c0e533786f7747fa23f4d47",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105502699816363Ug4q",
							"_tpl": "5ed51652f6c34d2cc26336a1",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105511207015167AlB5",
							"_tpl": "5c0e534186f7747fa1419867",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105511206877883KwxO",
							"_tpl": "5c0e534186f7747fa1419867",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105511431293227j0vm",
							"_tpl": "5c0e534186f7747fa1419867",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105511941024289Qbsv",
							"_tpl": "5c0e534186f7747fa1419867",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105511882398528QNI2",
							"_tpl": "5c0e534186f7747fa1419867",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924105511152520616lcsf",
							"_tpl": "5c0e534186f7747fa1419867",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "69343931db3b45c07ff1ac86",
							"_tpl": "5efb0fc6aeb21837e749c801",
							"parentId": "995204aee4c53b48bd071bb9",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 25
							}
						},
						{
							"_id": "I0924110225497887587MUzv",
							"_tpl": "5c0e533786f7747fa23f4d47",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924110225434251922Ownv",
							"_tpl": "5c0e533786f7747fa23f4d47",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924110225598958463wG5M",
							"_tpl": "5c0e533786f7747fa23f4d47",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924110233679814319PiCf",
							"_tpl": "5ed51652f6c34d2cc26336a1",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924110233373369588c2my",
							"_tpl": "5ed51652f6c34d2cc26336a1",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924110233385420274cfW7",
							"_tpl": "5ed51652f6c34d2cc26336a1",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "f295eab439abccf8027ef460",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924110824561077489zDj4",
							"_tpl": "628a60ae6b1d481ff772e9c8",
							"slotId": "main",
							"parentId": "I0923160556890464248iIUm",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							},
							"location": {
								"x": 1,
								"y": 10,
								"r": "Horizontal",
								"isSearched": true
							}
						},
						{
							"_id": "I0924110918537860679YjTi",
							"_tpl": "628a83c29179c324ed269508",
							"slotId": "mod_gas_block",
							"parentId": "I0924110824561077489zDj4",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924110956732724749bhkH",
							"_tpl": "6130c43c67085e45ef1405a1",
							"slotId": "mod_muzzle",
							"parentId": "I0924110824561077489zDj4",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241110225209242559Knq",
							"_tpl": "5dfa3d2b0dee1b22f862eade",
							"slotId": "mod_muzzle",
							"parentId": "I0924110956732724749bhkH",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111031161605569u1Yr",
							"_tpl": "56def37dd2720bec348b456a",
							"slotId": "mod_tactical",
							"parentId": "I0924111047148610184sJqf",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111047148610184sJqf",
							"_tpl": "5b7be47f5acfc400170e2dd2",
							"slotId": "mod_mount_001",
							"parentId": "I0924110918537860679YjTi",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111049804956220mmMA",
							"_tpl": "5b7be4895acfc400170e2dd5",
							"slotId": "mod_foregrip",
							"parentId": "I0924110918537860679YjTi",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111104955904857dUUe",
							"_tpl": "5b057b4f5acfc4771e1bd3e9",
							"slotId": "mod_foregrip",
							"parentId": "I0924111049804956220mmMA",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111120783144933UVlF",
							"_tpl": "59fafc9386f774067d462453",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111120703034924Aau2",
							"_tpl": "59fafc9386f774067d462453",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111120930681814uHbE",
							"_tpl": "59fafc9386f774067d462453",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111120804751200i2km",
							"_tpl": "59fafc9386f774067d462453",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111120643422582lQvi",
							"_tpl": "59fafc9386f774067d462453",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111120996390915g0By",
							"_tpl": "59fafc9386f774067d462453",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111120335668161RDiT",
							"_tpl": "59fafc9386f774067d462453",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111156431226628RUMN",
							"_tpl": "628c9ab845c59e5b80768a81",
							"slotId": "mod_pistol_grip",
							"parentId": "I0924110824561077489zDj4",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111214949354347Mjsj",
							"_tpl": "5b0e794b5acfc47a877359b2",
							"slotId": "mod_stock_000",
							"parentId": "I0924110824561077489zDj4",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111223214850121YDGE",
							"_tpl": "5b3b99265acfc4704b4a1afb",
							"slotId": "mod_scope",
							"parentId": "I0924111244452838016Blx9",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111232824796725Bcib",
							"_tpl": "618ba27d9008e4636a67f61d",
							"slotId": "mod_scope",
							"parentId": "I0924111223214850121YDGE",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111244452838016Blx9",
							"_tpl": "5d2c772c48f0355d95672c25",
							"slotId": "mod_reciever",
							"parentId": "I0924110824561077489zDj4",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111320296212212DvWk",
							"_tpl": "6130ca3fd92c473c77020dbd",
							"slotId": "mod_charge",
							"parentId": "I0924110824561077489zDj4",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111345784662489Gv0p",
							"_tpl": "5cfe8010d7ad1a59283b14c6",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111345665055317zLgb",
							"_tpl": "5cfe8010d7ad1a59283b14c6",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111345740647662Hd91",
							"_tpl": "5cfe8010d7ad1a59283b14c6",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111345692591321zizx",
							"_tpl": "5cfe8010d7ad1a59283b14c6",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241113455935498371R9U",
							"_tpl": "5cfe8010d7ad1a59283b14c6",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111345801506450W8L5",
							"_tpl": "5cfe8010d7ad1a59283b14c6",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111345934752259MnJj",
							"_tpl": "5cfe8010d7ad1a59283b14c6",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160615981914890Ew67",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111345902859589j9cy",
							"_tpl": "5cfe8010d7ad1a59283b14c6",
							"slotId": "mod_magazine",
							"parentId": "I0924110824561077489zDj4",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111355916165484To7m",
							"_tpl": "601aa3d2b2bcb34913271e6d",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0924111345934752259MnJj",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111355265236315EEZw",
							"_tpl": "601aa3d2b2bcb34913271e6d",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0924111345801506450W8L5",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111355226216787sYdh",
							"_tpl": "601aa3d2b2bcb34913271e6d",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I09241113455935498371R9U",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111355425269881rEaw",
							"_tpl": "601aa3d2b2bcb34913271e6d",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0924111345692591321zizx",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111355581728927GF6r",
							"_tpl": "601aa3d2b2bcb34913271e6d",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0924111345740647662Hd91",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111355984108199r492",
							"_tpl": "601aa3d2b2bcb34913271e6d",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111355165620848ecpL",
							"_tpl": "601aa3d2b2bcb34913271e6d",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111355845524363KnO9",
							"_tpl": "601aa3d2b2bcb34913271e6d",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111355448674919QG2n",
							"_tpl": "601aa3d2b2bcb34913271e6d",
							"slotId": "main",
							"location": {
								"x": 2,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111355325013295p3Mc",
							"_tpl": "601aa3d2b2bcb34913271e6d",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111355114366007goM1",
							"_tpl": "601aa3d2b2bcb34913271e6d",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111355641777293v1sE",
							"_tpl": "601aa3d2b2bcb34913271e6d",
							"slotId": "main",
							"location": {
								"x": 5,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111355989509160Efes",
							"_tpl": "601aa3d2b2bcb34913271e6d",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111355815942310GgRb",
							"_tpl": "601aa3d2b2bcb34913271e6d",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111355180690534mrAm",
							"_tpl": "601aa3d2b2bcb34913271e6d",
							"slotId": "main",
							"location": {
								"x": 1,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160549838359074wGUG",
							"upd": {
								"StackObjectsCount": 60,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924111355265741038LZAY",
							"_tpl": "601aa3d2b2bcb34913271e6d",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0924111345784662489Gv0p",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241113558304606893LJL",
							"_tpl": "601aa3d2b2bcb34913271e6d",
							"slotId": "cartridges",
							"location": 0,
							"parentId": "I0924111345665055317zLgb",
							"upd": {
								"StackObjectsCount": 50,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "be010f49a5c93cf428a2ecb5",
							"_tpl": "601aa3d2b2bcb34913271e6d",
							"parentId": "I0924111345902859589j9cy",
							"slotId": "cartridges",
							"location": 0,
							"upd": {
								"StackObjectsCount": 50
							}
						},
						{
							"_id": "I0924195856229983462KeGl",
							"_tpl": "5a154d5cfcdbcb001a3b00da",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6e979f224a755a582140dc0b",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241959018409065640pta",
							"_tpl": "5a16b7e1fcdbcb00165aa6c9",
							"slotId": "mod_equipment_000",
							"parentId": "I0924195856229983462KeGl",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924195903381762512YN2L",
							"_tpl": "5a16b7e1fcdbcb00165aa6c9",
							"slotId": "mod_equipment_000",
							"parentId": "I0924195906474785769vb4W",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924195906474785769vb4W",
							"_tpl": "5a154d5cfcdbcb001a3b00da",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6e979f224a755a582140dc0b",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924195917705483215nyCI",
							"_tpl": "5c0e655586f774045612eeb2",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160612720132437iwRO",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924195917948281343hrhM",
							"_tpl": "5c0e655586f774045612eeb2",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 9,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160612720132437iwRO",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924195929663570432cF3c",
							"_tpl": "5e4ac41886f77406a511c9a8",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160612720132437iwRO",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924195931824560602xSxP",
							"_tpl": "5e4ac41886f77406a511c9a8",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 9,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160612720132437iwRO",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09241959427772165309AWM",
							"_tpl": "5c0e746986f7741453628fe5",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160612720132437iwRO",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924195944241087799P6iR",
							"_tpl": "5c0e746986f7741453628fe5",
							"slotId": "main",
							"location": {
								"x": 3,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923160612720132437iwRO",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924195951139644907Ko2J",
							"_tpl": "5aa2ba71e5b5b000137b758f",
							"slotId": "main",
							"location": {
								"x": 4,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6e979f224a755a582140dc0b",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924195952677011323zGQg",
							"_tpl": "5aa2ba71e5b5b000137b758f",
							"slotId": "main",
							"location": {
								"x": 6,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6e979f224a755a582140dc0b",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924200000877104011XSXv",
							"_tpl": "545cdae64bdc2d39198b4568",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923161619877040230EFdg",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I09242000025957761157b93",
							"_tpl": "545cdae64bdc2d39198b4568",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0924200000877104011XSXv",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924200042213149416Gv2x",
							"_tpl": "5df8a4d786f77412672a1e3b",
							"slotId": "main",
							"location": {
								"x": 8,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923161619877040230EFdg",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924200044800889486TTdC",
							"_tpl": "5df8a4d786f77412672a1e3b",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0924200042213149416Gv2x",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924200146217238919hwzR",
							"_tpl": "5c093e3486f77430cb02e593",
							"slotId": "8",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "I0923172355114862980Xjmy",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924200202554477313NxzO",
							"_tpl": "5d02778e86f774203e7dedbe",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 0,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6ea94462e857b6bc08a98c77",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I092420020274473327962Sx",
							"_tpl": "5d02778e86f774203e7dedbe",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 1,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6ea94462e857b6bc08a98c77",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924200202254821819boqR",
							"_tpl": "5d02778e86f774203e7dedbe",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 2,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6ea94462e857b6bc08a98c77",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924200202639289878yGiU",
							"_tpl": "5d02778e86f774203e7dedbe",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 6,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6ea94462e857b6bc08a98c77",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924200202667487506KyCc",
							"_tpl": "5d02778e86f774203e7dedbe",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 3,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6ea94462e857b6bc08a98c77",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924200202924368129GbNV",
							"_tpl": "5d02778e86f774203e7dedbe",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 4,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6ea94462e857b6bc08a98c77",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						},
						{
							"_id": "I0924200202475135048qiBc",
							"_tpl": "5d02778e86f774203e7dedbe",
							"slotId": "main",
							"location": {
								"x": 0,
								"y": 5,
								"r": "Horizontal",
								"isSearched": true
							},
							"parentId": "6ea94462e857b6bc08a98c77",
							"upd": {
								"StackObjectsCount": 1,
								"SpawnedInSession": false
							}
						}
					],
					"equipment": "5fe49444ae6628187a2e77b8",
					"stash": "5fe49444ae6628187a2e78b8",
					"sortingTable": "60dca3da42ad9b706b369aca",
					"questRaidItems": "5fe49444ae6628187a2e78b9",
					"questStashItems": "5fe49444ae6628187a2e78ba",
					"fastPanel": {}
				},
				"Skills": {
					"Common": [{
							"Id": "BotReload",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": -2147483648
						}, {
							"Id": "BotSound",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": -2147483648
						}, {
							"Id": "Endurance",
							"Progress": 5200,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Strength",
							"Progress": 5200,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Vitality",
							"Progress": 3400,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Health",
							"Progress": 5200,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "StressResistance",
							"Progress": 2500,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Metabolism",
							"Progress": 5200,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Immunity",
							"Progress": 300,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Perception",
							"Progress": 5200,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Intellect",
							"Progress": 50,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Attention",
							"Progress": 5200,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Charisma",
							"Progress": 2200,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Memory",
							"Progress": 5200,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Pistol",
							"Progress": 150,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Revolver",
							"Progress": 50,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "SMG",
							"Progress": 900,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Assault",
							"Progress": 1200,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Shotgun",
							"Progress": 800,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Sniper",
							"Progress": 600,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "LMG",
							"Progress": 120,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "HMG",
							"Progress": 20,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Launcher",
							"Progress": 20,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "AttachedLauncher",
							"Progress": 20,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Throwing",
							"Progress": 200,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Melee",
							"Progress": 20,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "DMR",
							"Progress": 900,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "RecoilControl",
							"Progress": 2100,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "AimDrills",
							"Progress": 1100,
							"PointsEarnedDuringSession": 0,
							"LastAccess": -2147483648
						}, {
							"Id": "Surgery",
							"Progress": 900,
							"PointsEarnedDuringSession": 0,
							"LastAccess": -2147483648
						}, {
							"Id": "CovertMovement",
							"Progress": 2500,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Search",
							"Progress": 2600,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "MagDrills",
							"Progress": 700,
							"PointsEarnedDuringSession": 0,
							"LastAccess": -2147483648
						}, {
							"Id": "Sniping",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "ProneMovement",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "FieldMedicine",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "FirstAid",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "LightVests",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "HeavyVests",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "WeaponModding",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "AdvancedModding",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "NightOps",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "SilentOps",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Lockpicking",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "WeaponTreatment",
							"Progress": 900,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Freetrading",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Auctions",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Cleanoperations",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Barter",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Shadowconnections",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Taskperformance",
							"Progress": 0,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "Crafting",
							"Progress": 500,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}, {
							"Id": "HideoutManagement",
							"Progress": 700,
							"PointsEarnedDuringSession": 0,
							"LastAccess": 0
						}
					],
					"Mastering": [],
					"Points": 0
				},
				"Stats": {
					"SessionCounters": null,
					"OverallCounters": {
						"Items": []
					},
					"SessionExperienceMult": 0,
					"ExperienceBonusMult": 0,
					"TotalSessionExperience": 0,
					"LastSessionDate": 0,
					"Aggressor": null,
					"DroppedItems": [],
					"FoundInRaidItems": [],
					"Victims": [],
					"CarriedQuestItems": [],
					"DamageHistory": {
						"LethalDamagePart": "Head",
						"LethalDamage": null,
						"BodyParts": []
					},
					"LastPlayerState": null,
					"TotalInGameTime": 0,
					"SurvivorClass": "Unknown"
				},
				"Encyclopedia": {
					"56dfef82d2720bbd668b4567": true,
					"57dc324a24597759501edc20": true,
					"57dc334d245977597164366f": true,
					"59d36a0086f7747e673f3946": true,
					"58864a4f2459770fcc257101": true,
					"5448be9a4bdc2dfd2f8b456a": true,
					"544fb45d4bdc2dee738b4568": true,
					"545cdae64bdc2d39198b4568": true,
					"545cdb794bdc2d3a198b456a": true,
					"590c678286f77426c9660122": true,
					"5645bc214bdc2d363b8b4571": true,
					"584984812459776a704a82a6": true,
					"59ccfdba86f7747f2109a587": true,
					"544fb3f34bdc2d03748b456a": true,
					"590c657e86f77412b013051d": true,
					"592c2d1a86f7746dbe2af32a": true,
					"567143bf4bdc2d1a0f8b4567": true,
					"59bffbb386f77435b379b9c2": true,
					"59bffc1f86f77435b128b872": true,
					"595cf16b86f77427440c32e2": true,
					"5644bd2b4bdc2d3b4c8b4572": true,
					"59c6633186f7740cf0493bb9": true,
					"5649b0544bdc2d1b2b8b458a": true,
					"576a581d2459771e7b1bc4f1": true,
					"576a7c512459771e796e0e17": true,
					"59984ab886f7743e98271174": true,
					"59985a8086f77414ec448d1a": true,
					"599860e986f7743bb57573a6": true,
					"59ccd11386f77428f24a488f": true,
					"55801eed4bdc2d89578b4588": true,
					"559ba5b34bdc2d1f1a8b4582": true,
					"5887431f2459777e1612938f": true,
					"56083e1b4bdc2dc8488b4572": true,
					"56083eab4bdc2d26448b456a": true,
					"560e620e4bdc2d724b8b456b": true,
					"56ea8222d2720b69698b4567": true,
					"58948c8e86f77409493f7266": true,
					"5894a51286f77426d13baf02": true,
					"5894a5b586f77426d2590767": true,
					"5894a2c386f77427140b8342": true,
					"58949dea86f77409483e16a8": true,
					"5894a42086f77426d2590762": true,
					"5894a73486f77426d259076c": true,
					"5894a81786f77427140b8347": true,
					"5894a13e86f7742405482982": true,
					"58949edd86f77409483e16a9": true,
					"55d7217a4bdc2d86028b456d": true,
					"557ffd194bdc2d28148b457f": true,
					"544a5cde4bdc2d39388b456b": true,
					"5857a8bc2459772bad15db29": true,
					"5ca20abf86f77418567a43f2": true,
					"564ca99c4bdc2d16268b4589": true,
					"57cd379a24597778e7682ecf": true,
					"57dc2fa62459775949412633": true,
					"57dc32dc245977596d4ef3d3": true,
					"57dc347d245977596754e7a1": true,
					"5649ad3f4bdc2df8348b4585": true,
					"5811ce772459770e9e5f9532": true,
					"5894a05586f774094708ef75": true,
					"5648b1504bdc2d9d488b4584": true,
					"5998597786f77414ea6da093": true,
					"599860ac86f77436b225ed1a": true,
					"599851db86f77467372f0a18": true,
					"5998517986f7746017232f7e": true,
					"576a63cd2459771e796e0e11": true,
					"576a5ed62459771e9c2096cb": true,
					"56d59d3ad2720bdb418b4577": true,
					"5448bd6b4bdc2dfc2f8b4569": true,
					"5448c12b4bdc2d02308b456f": true,
					"573718ba2459775a75491131": true,
					"5649b1c04bdc2d16268b457c": true,
					"5649af094bdc2df8348b4586": true,
					"5649aa744bdc2ded0b8b457e": true,
					"5648b0744bdc2d363b8b4578": true,
					"5696686a4bdc2da3298b456a": true,
					"5449016a4bdc2d6f028b456f": true,
					"57347d7224597744596b4e72": true,
					"544fb25a4bdc2dfb738b4567": true,
					"5448fee04bdc2dbc018b4567": true,
					"544fb3364bdc2d34748b456a": true,
					"5755356824597772cb798962": true,
					"5645bcc04bdc2d363b8b4572": true,
					"5751a25924597722c463c472": true,
					"544fb37f4bdc2dee738b4567": true,
					"5e831507ea0a7c419c2f9bd9": true,
					"5648a7494bdc2d9d488b4583": true,
					"544a11ac4bdc2d470e8b456a": true,
					"55d480c04bdc2d1d4e8b456a": true,
					"56dff3afd2720bba668b4567": true,
					"5aa2b87de5b5b00016327c25": true,
					"5bffdc370db834001d23eca8": true,
					"5ac4cd105acfc40016339859": true,
					"5ac50c185acfc400163398d4": true,
					"5ac72e475acfc400180ae6fe": true,
					"5ac50da15acfc4001718d287": true,
					"5649ade84bdc2d1b2b8b4587": true,
					"5ac7655e5acfc40016339a19": true,
					"5af0454c86f7746bf20992e8": true,
					"569668774bdc2da2298b4568": true,
					"5ab8f39486f7745cd93a1cca": true,
					"5aa7cfc0e5b5b00015693143": true,
					"5d02778e86f774203e7dedbe": true,
					"557ff21e4bdc2d89578b4586": true,
					"5710c24ad2720bc3458b45a3": true,
					"5d0a29fed7ad1a002769ad08": true,
					"5d0a3e8cd7ad1a6f6a3d35bd": true,
					"5d1b371186f774253763a656": true,
					"5ca20d5986f774331e7c9602": true,
					"590c5d4b86f774784e1b9c45": true,
					"5c0e53c886f7747fa54205c7": true,
					"5e870397991fd70db46995c8": true,
					"560d5e524bdc2d25448b4571": true,
					"5e87114fe2db31558c75a120": true,
					"5e87116b81c4ed43e83cefdd": true,
					"5e87080c81c4ed43e83cefda": true,
					"5e87076ce2db31558c75a11d": true,
					"5e87071478f43e51ca2de5e1": true,
					"5e8708d4ae379e67d22e0102": true,
					"590c695186f7741e566b64a2": true,
					"57347da92459774491567cf5": true,
					"5a0c27731526d80618476ac4": true,
					"5755383e24597772cb798966": true,
					"590c661e86f7741e566b646a": true,
					"5b432b965acfc47a8774094e": true,
					"5d40407c86f774318526545a": true,
					"56e294cdd2720b603a8b4575": true,
					"5c488a752e221602b412af63": true,
					"5c48a2852e221602b21d5923": true,
					"5c48a2a42e221602b66d1e07": true,
					"5c48a14f2e2216152006edd7": true,
					"55802d5f4bdc2dac148b458e": true,
					"5c48a2c22e221602b313fb6c": true,
					"55d4887d4bdc2d962f8b4570": true,
					"570fd6c2d2720bc6458b457f": true,
					"54527a984bdc2d4e668b4567": true,
					"5e8488fa988a8701445df1e4": true,
					"5c0e530286f7747fa1419862": true,
					"5f4f9eb969cdc30ff33f09db": true,
					"59e770b986f7742cbd762754": true,
					"5d02797c86f774203f38e30a": true,
					"5d5e9c74a4b9364855191c40": true,
					"5aafbde786f774389d0cbc0f": true,
					"544a5caa4bdc2d1a388b4568": true,
					"5d5d85c586f774279a21cbdb": true,
					"5d5d940f86f7742797262046": true,
					"5beed0f50db834001c062b12": true,
					"5beec1bd0db834001e6006f3": true,
					"5beec3420db834001b095429": true,
					"5beec3e30db8340019619424": true,
					"5beecbb80db834001d2c465e": true,
					"5beec8b20db834001961942a": true,
					"5beec8c20db834001d2c465c": true,
					"5bed625c0db834001c062946": true,
					"5beec91a0db834001961942d": true,
					"5beec9450db83400970084fd": true,
					"5bf3f59f0db834001a6fa060": true,
					"5beec8ea0db834001a6f9dbf": true,
					"5c0505e00db834001b735073": true,
					"5b432d215acfc4771e1c6624": true,
					"5c0e722886f7740458316a57": true,
					"5e2af4a786f7746d3f3c3400": true,
					"5e2af47786f7746d404f3aaa": true,
					"5b40e5e25acfc4001a599bea": true,
					"5d1b36a186f7742523398433": true
				},
				"ConditionCounters": {
					"Counters": []
				},
				"BackendCounters": {},
				"InsuredItems": [],
				"Hideout": {
					"Production": {},
					"Areas": [{
							"type": 3,
							"level": 4,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 0,
							"level": 3,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 1,
							"level": 3,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 2,
							"level": 3,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 4,
							"level": 3,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 5,
							"level": 3,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 6,
							"level": 3,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 7,
							"level": 3,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 8,
							"level": 3,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 9,
							"level": 3,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 10,
							"level": 3,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 11,
							"level": 3,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 12,
							"level": 1,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 13,
							"level": 1,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 14,
							"level": 1,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 15,
							"level": 3,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 16,
							"level": 1,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 17,
							"level": 1,
							"active": true,
							"passiveBonusesEnabled": false,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 18,
							"level": 1,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 19,
							"level": 1,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 20,
							"level": 3,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}, {
							"type": 21,
							"level": 0,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}
					]
				},
				"Bonuses": [{
						"type": "StashSize",
						"templateId": "566abbc34bdc2d92178b4576"
					}, {
						"type": "StashSize",
						"templateId": "5811ce572459770cba1a34ea"
					}, {
						"type": "StashSize",
						"templateId": "5811ce662459770f6f490f32"
					}, {
						"type": "StashSize",
						"templateId": "5811ce772459770e9e5f9532"
					}
				],
				"Notes": {
					"Notes": []
				},
				"Quests": [],
				"TradersInfo": {},
				"RagfairInfo": {
					"rating": 2.0,
					"isRatingGrowing": true,
					"offers": []
				},
				"WishList": []
				},
				"suits": ["5cd946231388ce000d572fe3", "5cd945d71388ce000a659dfb"],
				"dialogues": {},
				"weaponbuilds": {
					"SA58": {
						"id": "3b3df48a5189033240cbc490",
						"name": "SA58",
						"root": "268a56c49239447e1ceaf2f0",
						"items": [
							{
								"_id": "268a56c49239447e1ceaf2f0",
								"_tpl": "5b0bbe4e5acfc40dc528a72d",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "14e6c51cadf00ff41da0d5e4",
								"_tpl": "5b7d679f5acfc4001a5c4024",
								"parentId": "268a56c49239447e1ceaf2f0",
								"slotId": "mod_pistol_grip"
							},
							{
								"_id": "a0bf32a90791e34cf55c8889",
								"_tpl": "5b7d37845acfc400170e2f87",
								"parentId": "268a56c49239447e1ceaf2f0",
								"slotId": "mod_magazine"
							},
							{
								"_id": "f9f958bc2a535f5a2a5994c4",
								"_tpl": "5b7bedd75acfc43d825283f9",
								"parentId": "268a56c49239447e1ceaf2f0",
								"slotId": "mod_handguard"
							},
							{
								"_id": "2ca0e76f55698024d1608210",
								"_tpl": "5b7be1265acfc400161d0798",
								"parentId": "268a56c49239447e1ceaf2f0",
								"slotId": "mod_barrel"
							},
							{
								"_id": "49593fe441ed1bb418a23d70",
								"_tpl": "5b099bb25acfc400186331e8",
								"parentId": "268a56c49239447e1ceaf2f0",
								"slotId": "mod_reciever"
							},
							{
								"_id": "122f645f02ac5070d40ec012",
								"_tpl": "5b099bf25acfc4001637e683",
								"parentId": "268a56c49239447e1ceaf2f0",
								"slotId": "mod_stock"
							},
							{
								"_id": "0018dc299ec4e233f1111802",
								"_tpl": "58dd3ad986f77403051cba8f",
								"parentId": "268a56c49239447e1ceaf2f0",
								"slotId": "patron_in_weapon"
							},
							{
								"_id": "329780b1a5b0191b5493ab71",
								"_tpl": "58dd3ad986f77403051cba8f",
								"parentId": "a0bf32a90791e34cf55c8889",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 29
								}
							},
							{
								"_id": "d772eac3df81c4173afd95a0",
								"_tpl": "5b7be46e5acfc400170e2dcf",
								"parentId": "f9f958bc2a535f5a2a5994c4",
								"slotId": "mod_mount_000"
							},
							{
								"_id": "c27a2b62eb2f6e3d56f1ea5e",
								"_tpl": "5b7be4575acfc400161d0832",
								"parentId": "f9f958bc2a535f5a2a5994c4",
								"slotId": "mod_mount_001"
							},
							{
								"_id": "44a111b0eb1c5088212616d9",
								"_tpl": "5cf78496d7f00c065703d6ca",
								"parentId": "2ca0e76f55698024d1608210",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "e636adccbab8d85117da2291",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "49593fe441ed1bb418a23d70",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "a0d5cfad2d04e990c35cab5e",
								"_tpl": "5c793fb92e221644f31bfb64",
								"parentId": "122f645f02ac5070d40ec012",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "5bc87d6ae3ebd09560912f67",
								"_tpl": "5c1cd46f2e22164bef5cfedb",
								"parentId": "d772eac3df81c4173afd95a0",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "317417c865aaab8c69f76cdb",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "c27a2b62eb2f6e3d56f1ea5e",
								"slotId": "mod_tactical",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "64d2d540509a3d24c4595371",
								"_tpl": "5c878e9d2e2216000f201903",
								"parentId": "44a111b0eb1c5088212616d9",
								"slotId": "mod_muzzle_000"
							},
							{
								"_id": "450d68919c5ed85dc1d54db8",
								"_tpl": "5cf78720d7f00c06595bc93e",
								"parentId": "44a111b0eb1c5088212616d9",
								"slotId": "mod_muzzle_001"
							},
							{
								"_id": "4e55d882dada542c26d2f75c",
								"_tpl": "58d2947e86f77447aa070d53",
								"parentId": "a0d5cfad2d04e990c35cab5e",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "5f7bac2b1e9b653ee1f74e61",
								"_tpl": "58d2912286f7744e27117493",
								"parentId": "4e55d882dada542c26d2f75c",
								"slotId": "mod_stock"
							}
						],
						"Parent": "5447b5f14bdc2d61278b4567"
					},
					"G28": {
						"id": "562ebd1be9d329672e3618a0",
						"name": "G28",
						"root": "d81fce1f645deecd57ad52c6",
						"items": [
							{
								"_id": "d81fce1f645deecd57ad52c6",
								"_tpl": "6176aca650224f204c1da3fb",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "11655d5299e66de5d8cd0047",
								"_tpl": "5d025cc1d7ad1a53845279ef",
								"parentId": "d81fce1f645deecd57ad52c6",
								"slotId": "mod_pistol_grip"
							},
							{
								"_id": "47d753f952516b52152a5bec",
								"_tpl": "617131a4568c120fdd29482d",
								"parentId": "d81fce1f645deecd57ad52c6",
								"slotId": "mod_magazine"
							},
							{
								"_id": "d62d733470663b8eb70a281f",
								"_tpl": "617153016c780c1e710c9a2f",
								"parentId": "d81fce1f645deecd57ad52c6",
								"slotId": "mod_stock"
							},
							{
								"_id": "b60a02a394910dcd0b4bf3e1",
								"_tpl": "61713a8fd92c473c770214a4",
								"parentId": "d81fce1f645deecd57ad52c6",
								"slotId": "mod_reciever"
							},
							{
								"_id": "3f9a13303a52a4eeaeb3b3ca",
								"_tpl": "61702d8a67085e45ef140b24",
								"parentId": "d81fce1f645deecd57ad52c6",
								"slotId": "mod_charge"
							},
							{
								"_id": "d59692183de00bcd9e6e638c",
								"_tpl": "58dd3ad986f77403051cba8f",
								"parentId": "47d753f952516b52152a5bec",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "521f5023b7318a4d5f40ea69",
								"_tpl": "617155ee50224f204c1da3cd",
								"parentId": "d62d733470663b8eb70a281f",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "09d27aa2822322aa602e92a0",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "b60a02a394910dcd0b4bf3e1",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "cd3c784f37487a915c0a642f",
								"_tpl": "61702be9faa1272e431522c3",
								"parentId": "b60a02a394910dcd0b4bf3e1",
								"slotId": "mod_barrel"
							},
							{
								"_id": "89cff2adb72d2e19710be96d",
								"_tpl": "61703001d92c473c77021497",
								"parentId": "b60a02a394910dcd0b4bf3e1",
								"slotId": "mod_handguard"
							},
							{
								"_id": "58863afa5ed39c7dcf3a4491",
								"_tpl": "61715e7e67085e45ef140b33",
								"parentId": "521f5023b7318a4d5f40ea69",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "03f3887a0b0917503585f376",
								"_tpl": "5dfa3cd1b33c0951220c079b",
								"parentId": "cd3c784f37487a915c0a642f",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "8e4f4f6e5760b3162633c045",
								"_tpl": "61702f1b67085e45ef140b26",
								"parentId": "cd3c784f37487a915c0a642f",
								"slotId": "mod_gas_block"
							},
							{
								"_id": "ee6982f8894d41d2fdab6c59",
								"_tpl": "5a7dbfc1159bd40016548fde",
								"parentId": "89cff2adb72d2e19710be96d",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "f18c528e2ec002eebd066a24",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "89cff2adb72d2e19710be96d",
								"slotId": "mod_tactical_002",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "1329ef0df744ea775dde3f57",
								"_tpl": "5dfa3d2b0dee1b22f862eade",
								"parentId": "03f3887a0b0917503585f376",
								"slotId": "mod_muzzle"
							}
						],
						"Parent": "5447b6194bdc2d67278b4567"
					},
					"UMP45": {
						"id": "f0f1c4f6ad973e4cdd31b3cc",
						"name": "UMP45",
						"root": "56b49630d8e5ae8fedb77c5d",
						"items": [
							{
								"_id": "56b49630d8e5ae8fedb77c5d",
								"_tpl": "5fc3e272f8b6a877a729eac5",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "7d0032474bbf714d1239d64f",
								"_tpl": "5fc3e466187fea44d52eda90",
								"parentId": "56b49630d8e5ae8fedb77c5d",
								"slotId": "mod_magazine"
							},
							{
								"_id": "72ea143157ef48971bf4227d",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "56b49630d8e5ae8fedb77c5d",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "c7119bf70d33862058766b91",
								"_tpl": "5fc3e4ee7283c4046c5814af",
								"parentId": "56b49630d8e5ae8fedb77c5d",
								"slotId": "mod_stock"
							},
							{
								"_id": "b5dddb73fb25280c4cd51bd9",
								"_tpl": "5fc3e4a27283c4046c5814ab",
								"parentId": "56b49630d8e5ae8fedb77c5d",
								"slotId": "mod_barrel"
							},
							{
								"_id": "dc6c6ec13c454eb4ecc36413",
								"_tpl": "5fc53954f8b6a877a729eaeb",
								"parentId": "56b49630d8e5ae8fedb77c5d",
								"slotId": "mod_mount_000"
							},
							{
								"_id": "ba308a3ba9dccf96b8a71923",
								"_tpl": "5fc5396e900b1d5091531e72",
								"parentId": "56b49630d8e5ae8fedb77c5d",
								"slotId": "mod_mount_001"
							},
							{
								"_id": "5272b636536f56867b7bf5bd",
								"_tpl": "5fc5396e900b1d5091531e72",
								"parentId": "56b49630d8e5ae8fedb77c5d",
								"slotId": "mod_mount_002"
							},
							{
								"_id": "640711061389e5c422dceac4",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "7d0032474bbf714d1239d64f",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "d99e728e7ba0fcaa16facda7",
								"_tpl": "6130c4d51cb55961fa0fd49f",
								"parentId": "b5dddb73fb25280c4cd51bd9",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "292112a8a313f2c2bc8f6198",
								"_tpl": "59fc48e086f77463b1118392",
								"parentId": "dc6c6ec13c454eb4ecc36413",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "a1697b641d14d98854e2fbfc",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "5272b636536f56867b7bf5bd",
								"slotId": "mod_tactical",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							}
						],
						"Parent": "5447b5e04bdc2d62278b4567"
					},
					"Ash12": {
						"id": "07d3fa2df5541b17d8b3746d",
						"name": "Ash12",
						"root": "b0492383acd5a4b53301f849",
						"items": [
							{
								"_id": "b0492383acd5a4b53301f849",
								"_tpl": "5cadfbf7ae92152ac412eeef",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "06f729e3ec2cc7c2e007cf34",
								"_tpl": "5caf187cae92157c28402e43",
								"parentId": "b0492383acd5a4b53301f849",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "4a80df247da70a49478eddcd",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "b0492383acd5a4b53301f849",
								"slotId": "mod_magazine"
							},
							{
								"_id": "644659c1d1c295468af6fe8d",
								"_tpl": "5cdaa99dd7f00c002412d0b2",
								"parentId": "b0492383acd5a4b53301f849",
								"slotId": "mod_handguard"
							},
							{
								"_id": "e40feedc3242e1eb1f4b339c",
								"_tpl": "6171407e50224f204c1da3c5",
								"parentId": "b0492383acd5a4b53301f849",
								"slotId": "mod_scope"
							},
							{
								"_id": "2a41911ee1c30cc5ce2aac69",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "b0492383acd5a4b53301f849",
								"slotId": "mod_tactical_002",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "ef23097795755cbfed95e6f4",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "4a80df247da70a49478eddcd",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "f55f09db6d5707cb79e981e0",
								"_tpl": "5a7dbfc1159bd40016548fde",
								"parentId": "644659c1d1c295468af6fe8d",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "2661b729eaef9f43453b04b5",
								"_tpl": "5b3b99475acfc432ff4dcbee",
								"parentId": "e40feedc3242e1eb1f4b339c",
								"slotId": "mod_scope_000",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "a7e59cd2bf174ac63bfd3acc",
								"_tpl": "577d128124597739d65d0e56",
								"parentId": "e40feedc3242e1eb1f4b339c",
								"slotId": "mod_scope_001"
							},
							{
								"_id": "41517e6587a5a32db092babd",
								"_tpl": "577d141e24597739c5255e01",
								"parentId": "a7e59cd2bf174ac63bfd3acc",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							}
						],
						"Parent": "5447b5f14bdc2d61278b4567"
					},
					"P90": {
						"id": "34efc571d0cec8ccf403549d",
						"name": "P90",
						"root": "dd843713676f27335a2e1cf2",
						"items": [
							{
								"_id": "dd843713676f27335a2e1cf2",
								"_tpl": "5cc82d76e24e8d00134b4b83",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "3176bde7a4b120c881e8548f",
								"_tpl": "5cc70093e4a949033c734312",
								"parentId": "dd843713676f27335a2e1cf2",
								"slotId": "mod_magazine"
							},
							{
								"_id": "fe8c9fbfba45b0c6cdff5c5a",
								"_tpl": "5cc700b9e4a949000f0f0f25",
								"parentId": "dd843713676f27335a2e1cf2",
								"slotId": "mod_stock"
							},
							{
								"_id": "ba4fd3a338a84993ae240496",
								"_tpl": "5cc700ede4a949033c734315",
								"parentId": "dd843713676f27335a2e1cf2",
								"slotId": "mod_reciever"
							},
							{
								"_id": "bf6e9893ab3007b659dc4b82",
								"_tpl": "5cc701aae4a949000e1ea45c",
								"parentId": "dd843713676f27335a2e1cf2",
								"slotId": "mod_barrel"
							},
							{
								"_id": "b42303c6a17eacea5ec94840",
								"_tpl": "5cc6ea85e4a949000e1ea3c3",
								"parentId": "dd843713676f27335a2e1cf2",
								"slotId": "mod_charge"
							},
							{
								"_id": "019781e3a852d7c1b317ced9",
								"_tpl": "5cc700cae4a949035e43ba72",
								"parentId": "fe8c9fbfba45b0c6cdff5c5a",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "a9bc42064c0a3fade8bfc145",
								"_tpl": "5cc7012ae4a949001252b43e",
								"parentId": "ba4fd3a338a84993ae240496",
								"slotId": "mod_mount_001"
							},
							{
								"_id": "1005b7f0273f44c276ab6e33",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "ba4fd3a338a84993ae240496",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "630bc500ddeb1d8696b8f869",
								"_tpl": "5cc82796e24e8d000f5859a8",
								"parentId": "bf6e9893ab3007b659dc4b82",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "1bcab9783bcfcbafc084afd7",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "a9bc42064c0a3fade8bfc145",
								"slotId": "mod_tactical",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "776dab288b2f085945d070df",
								"_tpl": "5cebec00d7f00c065c53522a",
								"parentId": "630bc500ddeb1d8696b8f869",
								"slotId": "mod_muzzle"
							}
						],
						"Parent": "5447b5e04bdc2d62278b4567"
					},
					"Vector45": {
						"id": "7f23489af05b4840f3fb9f3a",
						"name": "Vector45",
						"root": "ee55b56a73c2c664ef3c70f1",
						"items": [
							{
								"_id": "ee55b56a73c2c664ef3c70f1",
								"_tpl": "5fb64bc92b1b027b1f50bcf2",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "23d55299ee384a653e76bcc3",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"parentId": "ee55b56a73c2c664ef3c70f1",
								"slotId": "mod_magazine"
							},
							{
								"_id": "ea34495c42869be39a9e703b",
								"_tpl": "5fb6567747ce63734e3fa1dc",
								"parentId": "ee55b56a73c2c664ef3c70f1",
								"slotId": "mod_sight_front",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "c73c714b24f597298304c6ae",
								"_tpl": "5fb6564947ce63734e3fa1da",
								"parentId": "ee55b56a73c2c664ef3c70f1",
								"slotId": "mod_sight_rear",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "5ddf0a2cbe6136ba90115046",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "ee55b56a73c2c664ef3c70f1",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "a937fddce820f072049dcfa0",
								"_tpl": "5fb655b748c711690e3a8d5a",
								"parentId": "ee55b56a73c2c664ef3c70f1",
								"slotId": "mod_stock"
							},
							{
								"_id": "939f445c327cf8e61e19d8ab",
								"_tpl": "5fb65363d1409e5ca04b54f5",
								"parentId": "ee55b56a73c2c664ef3c70f1",
								"slotId": "mod_barrel"
							},
							{
								"_id": "bcd026f643914c6ae8c99670",
								"_tpl": "5fbb976df9986c4cff3fe5f2",
								"parentId": "ee55b56a73c2c664ef3c70f1",
								"slotId": "mod_mount"
							},
							{
								"_id": "1e937b23ef67265a4d334be0",
								"_tpl": "5fce0f9b55375d18a253eff2",
								"parentId": "ee55b56a73c2c664ef3c70f1",
								"slotId": "mod_mount_001"
							},
							{
								"_id": "3ee1559ebae1365fbb2ec723",
								"_tpl": "5fce0f9b55375d18a253eff2",
								"parentId": "ee55b56a73c2c664ef3c70f1",
								"slotId": "mod_mount_002"
							},
							{
								"_id": "aab0b288f526f173ff41733f",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "23d55299ee384a653e76bcc3",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "09243bb027055ed7a9ed9efb",
								"_tpl": "5c793fb92e221644f31bfb64",
								"parentId": "a937fddce820f072049dcfa0",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "26bbb6be4454334beffc5c09",
								"_tpl": "5fc4b992187fea44d52edaa9",
								"parentId": "939f445c327cf8e61e19d8ab",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "4bda6f829f0eb4e7334c0435",
								"_tpl": "5b057b4f5acfc4771e1bd3e9",
								"parentId": "bcd026f643914c6ae8c99670",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "d0c0c653d66374773df79818",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "3ee1559ebae1365fbb2ec723",
								"slotId": "mod_tactical",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "521b09ae4e2cf9535d0d892e",
								"_tpl": "58d2947e86f77447aa070d53",
								"parentId": "09243bb027055ed7a9ed9efb",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "9c3d84ea579b955b330a92cb",
								"_tpl": "58d2912286f7744e27117493",
								"parentId": "521b09ae4e2cf9535d0d892e",
								"slotId": "mod_stock"
							},
							{
								"_id": "36f02a4e6c1572d218497142",
								"_tpl": "5fc4b9b17283c4046c5814d7",
								"parentId": "26bbb6be4454334beffc5c09",
								"slotId": "mod_muzzle"
							}
						],
						"Parent": "5447b5e04bdc2d62278b4567"
					},
					"AK101": {
						"id": "4ff8c007e93f82b11a9a5fa9",
						"name": "AK101",
						"root": "8894267b5447d86491e6b076",
						"items": [
							{
								"_id": "8894267b5447d86491e6b076",
								"_tpl": "5ac66cb05acfc40198510a10",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "19dcb0cfd6c6da0d1fb4cb8b",
								"_tpl": "5b237e425acfc4771e1be0b6",
								"parentId": "8894267b5447d86491e6b076",
								"slotId": "mod_gas_block"
							},
							{
								"_id": "2c28dd603993e80e2d6c6bec",
								"_tpl": "5e21ca18e4d47f0da15e77dd",
								"parentId": "8894267b5447d86491e6b076",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "0533700f94cf6b7b314ddca7",
								"_tpl": "6087e663132d4d12c81fd96b",
								"parentId": "8894267b5447d86491e6b076",
								"slotId": "mod_pistol_grip"
							},
							{
								"_id": "6f85ed916c5bdf457ed62d80",
								"_tpl": "5d2c76ed48f03532f2136169",
								"parentId": "8894267b5447d86491e6b076",
								"slotId": "mod_reciever"
							},
							{
								"_id": "21094b0bd304cc739f39cf59",
								"_tpl": "5ac78eaf5acfc4001926317a",
								"parentId": "8894267b5447d86491e6b076",
								"slotId": "mod_stock"
							},
							{
								"_id": "40bbd7458ba10589bb458737",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"parentId": "8894267b5447d86491e6b076",
								"slotId": "mod_magazine"
							},
							{
								"_id": "ab8def21f939c08cdc1bda02",
								"_tpl": "6130ca3fd92c473c77020dbd",
								"parentId": "8894267b5447d86491e6b076",
								"slotId": "mod_charge"
							},
							{
								"_id": "3f28ec4b3059d31ab70844b4",
								"_tpl": "5b4736a986f774040571e998",
								"parentId": "19dcb0cfd6c6da0d1fb4cb8b",
								"slotId": "mod_mount_000"
							},
							{
								"_id": "55a83285019e7405a9978701",
								"_tpl": "5b4736b986f77405cb415c10",
								"parentId": "19dcb0cfd6c6da0d1fb4cb8b",
								"slotId": "mod_mount_002"
							},
							{
								"_id": "626400a160d3c33527c3ddd8",
								"_tpl": "609269c3b0e443224b421cc1",
								"parentId": "2c28dd603993e80e2d6c6bec",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "814df26855e7ca7a943ead17",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "6f85ed916c5bdf457ed62d80",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "51df4e5c437ee573050cd322",
								"_tpl": "59ecc3dd86f7746dc827481c",
								"parentId": "21094b0bd304cc739f39cf59",
								"slotId": "mod_stock"
							},
							{
								"_id": "6e8d128e68946dbf26ae6ad3",
								"_tpl": "54527ac44bdc2d36668b4567",
								"parentId": "40bbd7458ba10589bb458737",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "2b078e87b6314b6c5608d67d",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "3f28ec4b3059d31ab70844b4",
								"slotId": "mod_tactical",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "e5ca59760ba4d61f6c383b13",
								"_tpl": "5c1bc5af2e221602b412949b",
								"parentId": "55a83285019e7405a9978701",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "b9b422525155e731567bb439",
								"_tpl": "60926df0132d4d12c81fd9df",
								"parentId": "626400a160d3c33527c3ddd8",
								"slotId": "mod_muzzle"
							}
						],
						"Parent": "5447b5f14bdc2d61278b4567"
					},
					"Mk47": {
						"id": "11c87363cd19eceabe638159",
						"name": "Mk47",
						"root": "bf8980bc113ec4791a7578ec",
						"items": [
							{
								"_id": "bf8980bc113ec4791a7578ec",
								"_tpl": "606587252535c57a13424cfd",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "800c1dd42086186db9b27e47",
								"_tpl": "59db3a1d86f77429e05b4e92",
								"parentId": "bf8980bc113ec4791a7578ec",
								"slotId": "mod_pistol_grip"
							},
							{
								"_id": "30009c25831bf560ba42e264",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"parentId": "bf8980bc113ec4791a7578ec",
								"slotId": "mod_magazine"
							},
							{
								"_id": "ed6f89a2665a153c678da0df",
								"_tpl": "606587a88900dc2d9a55b659",
								"parentId": "bf8980bc113ec4791a7578ec",
								"slotId": "mod_reciever"
							},
							{
								"_id": "7f9e10a098e98c2dafdb2755",
								"_tpl": "5c793fb92e221644f31bfb64",
								"parentId": "bf8980bc113ec4791a7578ec",
								"slotId": "mod_stock_001"
							},
							{
								"_id": "f02b0ec14947868d59cace71",
								"_tpl": "606587bd6d0bd7580617bacc",
								"parentId": "bf8980bc113ec4791a7578ec",
								"slotId": "mod_charge"
							},
							{
								"_id": "8a07795bcdcc997ea6db46aa",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "30009c25831bf560ba42e264",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "baaa1a1146ca63822a626fb3",
								"_tpl": "5b3b99265acfc4704b4a1afb",
								"parentId": "ed6f89a2665a153c678da0df",
								"slotId": "mod_scope"
							},
							{
								"_id": "ad94ba4220d7d98465df6a11",
								"_tpl": "6065878ac9cf8012264142fd",
								"parentId": "ed6f89a2665a153c678da0df",
								"slotId": "mod_barrel"
							},
							{
								"_id": "625a15f090de1fff4967a8a4",
								"_tpl": "5a329052c4a28200741e22d3",
								"parentId": "ed6f89a2665a153c678da0df",
								"slotId": "mod_handguard"
							},
							{
								"_id": "0c6fe1ea8b7794378d198839",
								"_tpl": "58d2946386f774496974c37e",
								"parentId": "7f9e10a098e98c2dafdb2755",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "45fba130ee5eb063bb60e62f",
								"_tpl": "5b3b99475acfc432ff4dcbee",
								"parentId": "baaa1a1146ca63822a626fb3",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "95ba5b45b2570067817da764",
								"_tpl": "5d443f8fa4b93678dd4a01aa",
								"parentId": "ad94ba4220d7d98465df6a11",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "1be56cb228a9f44041570ef5",
								"_tpl": "6065dc8a132d4d12c81fd8e3",
								"parentId": "ad94ba4220d7d98465df6a11",
								"slotId": "mod_gas_block"
							},
							{
								"_id": "e997b199a647951099030c27",
								"_tpl": "5c0102b20db834001d23eebc",
								"parentId": "625a15f090de1fff4967a8a4",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "3727df95f0a0c38c6c50c6ff",
								"_tpl": "5c0102aa0db834001b734ba1",
								"parentId": "625a15f090de1fff4967a8a4",
								"slotId": "mod_mount_004"
							},
							{
								"_id": "4919c86d0fc5d7e30fb1c28a",
								"_tpl": "5d44064fa4b9361e4f6eb8b5",
								"parentId": "95ba5b45b2570067817da764",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "9a70db3a18a4723d6ff6cea6",
								"_tpl": "5c1cd46f2e22164bef5cfedb",
								"parentId": "e997b199a647951099030c27",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "977d9b9caddfe67418330481",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "3727df95f0a0c38c6c50c6ff",
								"slotId": "mod_tactical",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "25fdeeec5ab96a7be5598b02",
								"_tpl": "58d2912286f7744e27117493",
								"parentId": "0c6fe1ea8b7794378d198839",
								"slotId": "mod_stock"
							}
						],
						"Parent": "5447b5f14bdc2d61278b4567"
					},
					"MP155": {
						"id": "29ab50dd9de4109922143b4d",
						"name": "MP155",
						"root": "09c8416ab3b626d0bb9c4203",
						"items": [
							{
								"_id": "09c8416ab3b626d0bb9c4203",
								"_tpl": "606dae0ab0e443224b421bb7",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "0c3aa16f7d7826260f2dea1b",
								"_tpl": "6076c1b9f2cb2e02a42acedc",
								"parentId": "09c8416ab3b626d0bb9c4203",
								"slotId": "mod_barrel"
							},
							{
								"_id": "6c77ab9eac7260b91e5e4dd6",
								"_tpl": "606ee5c81246154cad35d65e",
								"parentId": "09c8416ab3b626d0bb9c4203",
								"slotId": "mod_handguard"
							},
							{
								"_id": "5cddb46707a40f7d55a2b246",
								"_tpl": "6076c87f232e5a31c233d50e",
								"parentId": "09c8416ab3b626d0bb9c4203",
								"slotId": "mod_magazine"
							},
							{
								"_id": "b7548e57ce7aeb68a05567b2",
								"_tpl": "606eef46232e5a31c233d500",
								"parentId": "09c8416ab3b626d0bb9c4203",
								"slotId": "mod_stock"
							},
							{
								"_id": "e31af76495fac565713a7eb7",
								"_tpl": "60785ce5132d4d12c81fd918",
								"parentId": "09c8416ab3b626d0bb9c4203",
								"slotId": "mod_mount"
							},
							{
								"_id": "93d4c7c2bca28b15fae6ddc7",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "09c8416ab3b626d0bb9c4203",
								"slotId": "patron_in_weapon"
							},
							{
								"_id": "d33a81fee5d1c8ec8c3a295f",
								"_tpl": "5c0111ab0db834001966914d",
								"parentId": "0c3aa16f7d7826260f2dea1b",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "3a61ccabd0bf24e2a7aca587",
								"_tpl": "607ea812232e5a31c233d53c",
								"parentId": "6c77ab9eac7260b91e5e4dd6",
								"slotId": "mod_mount_000"
							},
							{
								"_id": "aa742043879d660821d21e69",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "5cddb46707a40f7d55a2b246",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "5a66fce868a726cb6f6b2533",
								"_tpl": "606eef756d0bd7580617baf8",
								"parentId": "b7548e57ce7aeb68a05567b2",
								"slotId": "mod_stock"
							},
							{
								"_id": "9e29e86421bb8d7cecea9347",
								"_tpl": "570fd6c2d2720bc6458b457f",
								"parentId": "e31af76495fac565713a7eb7",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "05ef173908038174012f7723",
								"_tpl": "59c0ec5b86f77435b128bfca",
								"parentId": "d33a81fee5d1c8ec8c3a295f",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "0a8cd85c07d8b5b1da1f93fa",
								"_tpl": "56def37dd2720bec348b456a",
								"parentId": "3a61ccabd0bf24e2a7aca587",
								"slotId": "mod_tactical",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "3072a88ea2d551681b4585f3",
								"_tpl": "606f262c6d0bd7580617bafa",
								"parentId": "5a66fce868a726cb6f6b2533",
								"slotId": "mod_stock"
							},
							{
								"_id": "fe3b24c20ddebf7fcbaaabe3",
								"_tpl": "606f2696f2cb2e02a42aceb1",
								"parentId": "5a66fce868a726cb6f6b2533",
								"slotId": "mod_tactical",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							}
						],
						"Parent": "5447b6094bdc2dc3278b4567"
					},
					"M4A1": {
						"id": "e7936630a2c0d64112788602",
						"name": "M4A1",
						"root": "a480cb04e8a1b3c03862fe07",
						"items": [
							{
								"_id": "a480cb04e8a1b3c03862fe07",
								"_tpl": "5447a9cd4bdc2dbd208b4567",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "96527a4d089c2c18dceb3f0c",
								"_tpl": "59db3a1d86f77429e05b4e92",
								"parentId": "a480cb04e8a1b3c03862fe07",
								"slotId": "mod_pistol_grip"
							},
							{
								"_id": "4e51c8127df4928348601c51",
								"_tpl": "59bfe68886f7746004266202",
								"parentId": "a480cb04e8a1b3c03862fe07",
								"slotId": "mod_reciever"
							},
							{
								"_id": "495e0c756611d7f78c09316f",
								"_tpl": "5c793fb92e221644f31bfb64",
								"parentId": "a480cb04e8a1b3c03862fe07",
								"slotId": "mod_stock"
							},
							{
								"_id": "7d4c825194094be438766b93",
								"_tpl": "5b2240bf5acfc40dc528af69",
								"parentId": "a480cb04e8a1b3c03862fe07",
								"slotId": "mod_charge"
							},
							{
								"_id": "bb24af9074b5381f25076b61",
								"_tpl": "5b3b99265acfc4704b4a1afb",
								"parentId": "4e51c8127df4928348601c51",
								"slotId": "mod_scope"
							},
							{
								"_id": "146ff2e06ae76487ee013faf",
								"_tpl": "55d3632e4bdc2d972f8b4569",
								"parentId": "4e51c8127df4928348601c51",
								"slotId": "mod_barrel"
							},
							{
								"_id": "9980bcc79fc7ed2c77c17fa3",
								"_tpl": "5c78f2492e221600114c9f04",
								"parentId": "4e51c8127df4928348601c51",
								"slotId": "mod_handguard"
							},
							{
								"_id": "f355f3cd68c31215acf4deda",
								"_tpl": "58d2947e86f77447aa070d53",
								"parentId": "495e0c756611d7f78c09316f",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "4713eb2e0312ec140cb5a229",
								"_tpl": "618ba27d9008e4636a67f61d",
								"parentId": "bb24af9074b5381f25076b61",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "39cc988aa9e78e471813ef3f",
								"_tpl": "609269c3b0e443224b421cc1",
								"parentId": "146ff2e06ae76487ee013faf",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "1dea65169749146969e81937",
								"_tpl": "5d00ec68d7ad1a04a067e5be",
								"parentId": "146ff2e06ae76487ee013faf",
								"slotId": "mod_gas_block"
							},
							{
								"_id": "1da200de64995349172abf37",
								"_tpl": "5b7be4895acfc400170e2dd5",
								"parentId": "9980bcc79fc7ed2c77c17fa3",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "be720edc664af932932f3788",
								"_tpl": "56def37dd2720bec348b456a",
								"parentId": "9980bcc79fc7ed2c77c17fa3",
								"slotId": "mod_tactical_003",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "f1f3f0f0cab7992d9bf29d7a",
								"_tpl": "60926df0132d4d12c81fd9df",
								"parentId": "39cc988aa9e78e471813ef3f",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "2747648813a2ecae05b81a42",
								"_tpl": "58d2912286f7744e27117493",
								"parentId": "f355f3cd68c31215acf4deda",
								"slotId": "mod_stock"
							}
						],
						"Parent": "5447b5f14bdc2d61278b4567"
					},
					"RD704": {
						"id": "efa26b788869e44e1aba2b26",
						"name": "RD704",
						"root": "44e5329adcc29bd81bff85fc",
						"items": [
							{
								"_id": "44e5329adcc29bd81bff85fc",
								"_tpl": "628a60ae6b1d481ff772e9c8",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "2dc061942241070991bfab9b",
								"_tpl": "628a83c29179c324ed269508",
								"parentId": "44e5329adcc29bd81bff85fc",
								"slotId": "mod_gas_block"
							},
							{
								"_id": "d51608fb1de72820d5f10c97",
								"_tpl": "6130c43c67085e45ef1405a1",
								"parentId": "44e5329adcc29bd81bff85fc",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "a96c305883f093ae74bd5424",
								"_tpl": "628c9ab845c59e5b80768a81",
								"parentId": "44e5329adcc29bd81bff85fc",
								"slotId": "mod_pistol_grip"
							},
							{
								"_id": "64bc890dbd65cafbe592218f",
								"_tpl": "5d2c772c48f0355d95672c25",
								"parentId": "44e5329adcc29bd81bff85fc",
								"slotId": "mod_reciever"
							},
							{
								"_id": "7e8845a9b18030a1c0de32be",
								"_tpl": "5b0e794b5acfc47a877359b2",
								"parentId": "44e5329adcc29bd81bff85fc",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "763f09c02bffc9aca1a8f4de",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"parentId": "44e5329adcc29bd81bff85fc",
								"slotId": "mod_magazine"
							},
							{
								"_id": "5449e333954dbdfd9f958c66",
								"_tpl": "6130ca3fd92c473c77020dbd",
								"parentId": "44e5329adcc29bd81bff85fc",
								"slotId": "mod_charge"
							},
							{
								"_id": "c37c96576051f4d23e4ea2db",
								"_tpl": "5b7be47f5acfc400170e2dd2",
								"parentId": "2dc061942241070991bfab9b",
								"slotId": "mod_mount_001"
							},
							{
								"_id": "c9e15cddb62d39dc65b50734",
								"_tpl": "5b7be4895acfc400170e2dd5",
								"parentId": "2dc061942241070991bfab9b",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "7d11292f9e8628dc4c59ed7d",
								"_tpl": "5dfa3d2b0dee1b22f862eade",
								"parentId": "d51608fb1de72820d5f10c97",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "1265b311600dd9dca3899141",
								"_tpl": "5b3b99265acfc4704b4a1afb",
								"parentId": "64bc890dbd65cafbe592218f",
								"slotId": "mod_scope"
							},
							{
								"_id": "f73ae9db60fca0dcfa6bd0eb",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"parentId": "763f09c02bffc9aca1a8f4de",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 50
								}
							},
							{
								"_id": "147ebcb14d43d9b3441de5aa",
								"_tpl": "56def37dd2720bec348b456a",
								"parentId": "c37c96576051f4d23e4ea2db",
								"slotId": "mod_tactical",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "30191c0ea06acb1487748514",
								"_tpl": "5b057b4f5acfc4771e1bd3e9",
								"parentId": "c9e15cddb62d39dc65b50734",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "94808546f03f64c618ffb670",
								"_tpl": "618ba27d9008e4636a67f61d",
								"parentId": "1265b311600dd9dca3899141",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							}
						]
					}
				},
				"trader": {
					"initialLoyaltyLevel": 4,
					"initialStanding": 6.5,
					"initialSalesSum": 10000000,
					"jaegerUnlocked": true
				}
			},
			"usec": {
				"character": {
					"_id": "__REPLACEME__",
					"aid": "__REPLACEME__",
					"savage": "__REPLACEME__",
					"Info": {
						"Nickname": "__REPLACEME__",
						"LowerNickname": "__REPLACEME__",
						"Side": "Usec",
						"Voice": "__REPLACEME__",
						"Level": 50,
						"Experience": 5000000,
						"RegistrationDate": "__REPLACEME__",
						"GameVersion": "edge_of_darkness",
						"AccountType": 0,
						"MemberCategory": 0,
						"lockedMoveCommands": false,
						"SavageLockTime": 0,
						"LastTimePlayedAsSavage": 0,
						"Settings": {
							"Role": "assault",
							"BotDifficulty": "easy",
							"Experience": -1
						},
						"NicknameChangeDate": 0,
						"IsStreamerModeAvailable": false,
						"Bans": [],
						"BannedState": false,
						"BannedUntil": 0
					},
					"Customization": {
						"Head": "__REPLACEME__",
						"Body": "5cde95d97d6c8b647a3769b0",
						"Feet": "5cde95ef7d6c8b04713c4f2d",
						"Hands": "5cde95fa7d6c8b04737c2d13"
					},
					"Health": {
						"Hydration": {
							"Current": 100,
							"Maximum": 100
						},
						"Energy": {
							"Current": 100,
							"Maximum": 100
						},
						"Temperature": {
							"Current": 36.6,
							"Maximum": 40
						},
						"BodyParts": {
							"Head": {
								"Health": {
									"Current": 35,
									"Maximum": 35
								}
							},
							"Chest": {
								"Health": {
									"Current": 85,
									"Maximum": 85
								}
							},
							"Stomach": {
								"Health": {
									"Current": 70,
									"Maximum": 70
								}
							},
							"LeftArm": {
								"Health": {
									"Current": 60,
									"Maximum": 60
								}
							},
							"RightArm": {
								"Health": {
									"Current": 60,
									"Maximum": 60
								}
							},
							"LeftLeg": {
								"Health": {
									"Current": 65,
									"Maximum": 65
								}
							},
							"RightLeg": {
								"Health": {
									"Current": 65,
									"Maximum": 65
								}
							}
						},
						"UpdateTime": 1608815684
					},
					"Inventory": {
						"items": [
							{
								"_id": "5fe49444ae6628187a2e77b8",
								"_tpl": "55d7217a4bdc2d86028b456d"
							},
							{
								"_id": "4762bc96ec1eb296c80c9766",
								"_tpl": "5857a8bc2459772bad15db29",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "SecuredContainer"
							},
							{
								"_id": "be2c737eca1dd8acf5bc9e1d",
								"_tpl": "627a4e6b255f7527fb05a0f6",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "Pockets"
							},
							{
								"_id": "5fe49444ae6628187a2e78b8",
								"_tpl": "5811ce772459770e9e5f9532"
							},
							{
								"_id": "5fe49444ae6628187a2e78ba",
								"_tpl": "5963866b86f7747bfa1c4462"
							},
							{
								"_id": "5fe49444ae6628187a2e78b9",
								"_tpl": "5963866286f7747bf429b572"
							},
							{
								"_id": "60dca3da42ad9b706b369aca",
								"_tpl": "602543c13fee350cd564d032"
							},
							{
								"_id": "c5437eefa45f91432f8a7f0f",
								"_tpl": "569668774bdc2da2298b4568",
								"parentId": "aa181c6bc697085eb24a8387",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 50000
								}
							},
							{
								"_id": "58dcea09dd2598ffa01fb904",
								"_tpl": "59fb016586f7746d0d4b423a",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "ad6a118bc008509fbcc42221",
								"_tpl": "5d235bb686f77443f4331278",
								"parentId": "I0923172355114862980Xjmy",
								"slotId": "2",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Tag": {
										"Color": 0,
										"Name": "Reserve"
									}
								}
							},
							{
								"_id": "c28701e285917a5f1aba97d9",
								"_tpl": "59fb042886f7746c5005a7b2",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 4,
									"y": 19,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Tag": {
										"Color": 0,
										"Name": ""
									}
								}
							},
							{
								"_id": "48264f7f5b79eab8634caad3",
								"_tpl": "619cbf7d23893217ec30b689",
								"parentId": "4762bc96ec1eb296c80c9766",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "6e979f224a755a582140dc0b",
								"_tpl": "59fb042886f7746c5005a7b2",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 19,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Tag": {
										"Color": 0,
										"Name": "Head gear"
									}
								}
							},
							{
								"_id": "6ea94462e857b6bc08a98c77",
								"_tpl": "5aafbcd986f7745e590fff23",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 7,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "3dddf0476f5ecbb16e42e815",
								"_tpl": "5c093db286f7740a1b2617e3",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "4ee998775174fb58923f0e60",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "3dddf0476f5ecbb16e42e815",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "44493b178072c83ac6e5bf28",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "3dddf0476f5ecbb16e42e815",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8f409532668769d248ff8ec8",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "3dddf0476f5ecbb16e42e815",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "66b7f884b954e399e9b8c53f",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "3dddf0476f5ecbb16e42e815",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "df58315c9d3943c030cc8ef7",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "3dddf0476f5ecbb16e42e815",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "7d3524b30264d991400854af",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "3dddf0476f5ecbb16e42e815",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "41fb5820773cb651d407acd0",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "45f0c10affb653b9c69f81ac",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "32547cf5efd36b8de1438a83",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "45f0c10affb653b9c69f81ac",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "db5029a12c02d8d85f7b438b",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "45f0c10affb653b9c69f81ac",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "6caf452aa653eaec39fecb10",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "45f0c10affb653b9c69f81ac",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "20da3021d8b3e95373bd3638",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "45f0c10affb653b9c69f81ac",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "36f56b9c50bc79c5757939e5",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "45f0c10affb653b9c69f81ac",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "a1f57ad64fcc35a88f6f547a",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "45f0c10affb653b9c69f81ac",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "05bf6fd2b8fb4c1e2d9354d7",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "45f0c10affb653b9c69f81ac",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "22ce701caafbfa1e89240a61",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "3dddf0476f5ecbb16e42e815",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "b7bdc5967f39db5aa502e642",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "3dddf0476f5ecbb16e42e815",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "226bf8e909fab8f41534221f",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "6ea94462e857b6bc08a98c77",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 334
									}
								}
							},
							{
								"_id": "062d7e89ebe520275e909b06",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "6ea94462e857b6bc08a98c77",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "d3c6a8e97edd98efb722e4d0",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "6ea94462e857b6bc08a98c77",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "6b26c05c01ae290d54af2adb",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "6ea94462e857b6bc08a98c77",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "e18d42cc676f9ed76e200c42",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "6ea94462e857b6bc08a98c77",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "e262c9173855bc984fc552e1",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "6ea94462e857b6bc08a98c77",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "c82b9e60dcc88cabb8b3b1f2",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "4762bc96ec1eb296c80c9766",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "6df74ab62b30c361ec342ca7",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "6ea94462e857b6bc08a98c77",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "fdf59b599f369db65131cb4d",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "6ea94462e857b6bc08a98c77",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "876349c6644fb7d383956a71",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "6ea94462e857b6bc08a98c77",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "082038786b3ad4223108599f",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "6ea94462e857b6bc08a98c77",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "30b50554931675cd041020ee",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "6ea94462e857b6bc08a98c77",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "6622c0b6cbf8b8ff7e5d479b",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "I09232006192496057943JEc",
								"slotId": "11",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "I09231505117344600002ySF",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150511577884091hw32",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150511604947979ecoZ",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150511622225070YxQT",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231505245916849523wPm",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524976338992UCPV",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524704122323gs4S",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231505245660709872L9C",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524604662795FbKE",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524460820611ShQR",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231505242470217199fKN",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524459633618818U",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524153572886U0wA",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I092315052414233241342Zr",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524399097881GkFS",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524759681273qDzD",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524557209990vUM8",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524206610957mtbW",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524881649640mCEw",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524538194680p64v",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524803610957iSyW",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524573595903SEuw",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524669349074SA5O",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I092315052469016537434Nw",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231505243313616290wQI",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524988098607y2YT",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524857578061ZIhF",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524419482174yoLW",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524543746016rTvs",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524218649172jL81",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524732382854zz90",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524557298050upBc",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150524844321916rS4u",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150543203563293B3O4",
								"_tpl": "5c0126f40db834002a125382",
								"slotId": "Scabbard",
								"parentId": "5fe49444ae6628187a2e77b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150633238226641EKiv",
								"_tpl": "5ed51652f6c34d2cc26336a1",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "48264f7f5b79eab8634caad3",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150639374570244ygmK",
								"_tpl": "5c0e533786f7747fa23f4d47",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "48264f7f5b79eab8634caad3",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150639820821845KxVU",
								"_tpl": "5c0e533786f7747fa23f4d47",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "48264f7f5b79eab8634caad3",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150640387789765tsw6",
								"_tpl": "5c0e531d86f7747fa23f4d42",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "48264f7f5b79eab8634caad3",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150642143758271Grjp",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "48264f7f5b79eab8634caad3",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150644884663268J2O7",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "48264f7f5b79eab8634caad3",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150644981348911wTyM",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "48264f7f5b79eab8634caad3",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150706104419884GHtT",
								"_tpl": "628e4e576d783146b124c64d",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e979f224a755a582140dc0b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150706106231208lbts",
								"_tpl": "628e4e576d783146b124c64d",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e979f224a755a582140dc0b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150710382699887SLBY",
								"_tpl": "6033fa48ffd42c541047f728",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e979f224a755a582140dc0b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150710435455531Caa1",
								"_tpl": "6033fa48ffd42c541047f728",
								"slotId": "Earpiece",
								"parentId": "5fe49444ae6628187a2e77b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150710970067736ij4S",
								"_tpl": "6033fa48ffd42c541047f728",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e979f224a755a582140dc0b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I092315074175429401339GR",
								"_tpl": "5e00c1ad86f774747333222c",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e979f224a755a582140dc0b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150741731864861sGgR",
								"_tpl": "5e00c1ad86f774747333222c",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e979f224a755a582140dc0b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150741431012970LK9Z",
								"_tpl": "5e00c1ad86f774747333222c",
								"slotId": "Headwear",
								"parentId": "5fe49444ae6628187a2e77b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150750737252746dK0Z",
								"_tpl": "5ab8e79e86f7742d8b372e78",
								"slotId": "ArmorVest",
								"parentId": "5fe49444ae6628187a2e77b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923150750616426950p2m3",
								"_tpl": "5ab8e79e86f7742d8b372e78",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160612720132437iwRO",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I092315075037698297670LR",
								"_tpl": "5ab8e79e86f7742d8b372e78",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160612720132437iwRO",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "307fb5ac0ae0a6937a24e649",
								"_tpl": "5e2af55f86f7746d4159f07c",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "e929c824b16963b3c1f24dd4",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "be2c737eca1dd8acf5bc9e1d",
								"slotId": "pocket3",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "5494a182c5547f032d8152c2",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "9c9fcda4b0f53a08aa415c7f",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "7fb3ea7589b1c4381e755e86",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "245c4dca97d479148c5bed05",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "45ea7672a3cb869793156469",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "c3f4d3ac344a96c4c8ae12ad",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "247859fe71864ec5601c1738",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "18f62c5fa8215b67f6d01ef3",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "e4ab05418cd9b3c371e9c675",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "e38d04b897fe43074b95f8ae",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "be2c737eca1dd8acf5bc9e1d",
								"slotId": "pocket4",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "526b5a23130d721986f3a5b8",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "f8a349af39c17dfae3e95e8a",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "35ff21edc5339cd33afdefa9",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "16e3bafe214130049de7613a",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "25a608792b4b727b3adc58e0",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "69c288ba282e86aea4add2b0",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "be2c737eca1dd8acf5bc9e1d",
								"slotId": "pocket2",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "6d9ff9ddc4cc2ea3d111b2b8",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "0a198e7d78eddf49f2c5d47c",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "a391360d5b9fc02ab2611e17",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "2f92e5ba2d704586e8c85bdc",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "9b2a7d1321ab3605e5594088",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "0eae732e676aef15d7af1cfe",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "9339ec51fa6f3d7b200e4c40",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "23f6f01d177dad0c4282261d",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "04fa3a02a5ce8b2d5fea4566",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "3d9f4cdcc72937507e84cadf",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "9464d703522f47fb51c361a1",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "be2c737eca1dd8acf5bc9e1d",
								"slotId": "pocket1",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "2f3ac210117fdcd99928527e",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "9aac8df8f5517ff35965fe96",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "57e01f9d8b59d09d0e0624b7",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "e7f86cc2cf29b21b3c2d6460",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "307fb5ac0ae0a6937a24e649",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "add3df75e8cfe05856413451",
								"_tpl": "5910968f86f77425cf569c32",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "39e2be2b5aa113223a13a542",
								"_tpl": "591094e086f7747caa7bb2ef",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 8,
									"y": 6,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "I09231605498212639068zTm",
								"_tpl": "5aafbde786f774389d0cbc0f",
								"slotId": "hideout",
								"location": {
									"x": 8,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Other"
									}
								}
							},
							{
								"_id": "I0923160549838359074wGUG",
								"_tpl": "5aafbde786f774389d0cbc0f",
								"slotId": "hideout",
								"location": {
									"x": 2,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "762x39"
									}
								}
							},
							{
								"_id": "I0923160549738662111nnBi",
								"_tpl": "5aafbde786f774389d0cbc0f",
								"slotId": "hideout",
								"location": {
									"x": 6,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "762x51"
									}
								}
							},
							{
								"_id": "I0923160549508325839Y4hF",
								"_tpl": "5aafbde786f774389d0cbc0f",
								"slotId": "hideout",
								"location": {
									"x": 4,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "556x45"
									}
								}
							},
							{
								"_id": "I0923160549319243199X5JT",
								"_tpl": "5aafbde786f774389d0cbc0f",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": ".45"
									}
								}
							},
							{
								"_id": "I0923160556890464248iIUm",
								"_tpl": "5b6d9ce188a4501afc1b2b25",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 14,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Assault Rifles"
									}
								}
							},
							{
								"_id": "I0923160556623493093KHEX",
								"_tpl": "5b6d9ce188a4501afc1b2b25",
								"slotId": "hideout",
								"location": {
									"x": 5,
									"y": 14,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Other"
									}
								}
							},
							{
								"_id": "I0923160602973905323w2QM",
								"_tpl": "5b7c710788a4506dec015957",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 23,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923160602230159174A6DJ",
								"_tpl": "5b7c710788a4506dec015957",
								"slotId": "hideout",
								"location": {
									"x": 4,
									"y": 23,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231606064060654146YQv",
								"_tpl": "5c093e3486f77430cb02e593",
								"slotId": "7",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923172355114862980Xjmy",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923160612720132437iwRO",
								"_tpl": "5c0a840b86f7742ffa4f2482",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 16,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Armor & Rigs"
									}
								}
							},
							{
								"_id": "I0923160615894581733Jt9n",
								"_tpl": "5c127c4486f7745625356c13",
								"slotId": "hideout",
								"location": {
									"x": 8,
									"y": 11,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Other"
									}
								}
							},
							{
								"_id": "I0923160615981914890Ew67",
								"_tpl": "5c127c4486f7745625356c13",
								"slotId": "hideout",
								"location": {
									"x": 2,
									"y": 11,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "762x39"
									}
								}
							},
							{
								"_id": "I0923160615616283334o6to",
								"_tpl": "5c127c4486f7745625356c13",
								"slotId": "hideout",
								"location": {
									"x": 4,
									"y": 11,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "556x45"
									}
								}
							},
							{
								"_id": "I0923160615143872800eMjk",
								"_tpl": "5c127c4486f7745625356c13",
								"slotId": "hideout",
								"location": {
									"x": 6,
									"y": 11,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "762x51"
									}
								}
							},
							{
								"_id": "I0923160615320067631vSra",
								"_tpl": "5c127c4486f7745625356c13",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 11,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": ".45"
									}
								}
							},
							{
								"_id": "I092316064482387996028sP",
								"_tpl": "5696686a4bdc2da3298b456a",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "aa181c6bc697085eb24a8387",
								"upd": {
									"StackObjectsCount": 50000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923160655221997734MxjG",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923160655661579150cEGL",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923160655643467516U7nH",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923160655327196399dG2V",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923160655296024656bEy5",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923160655634899980j46z",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923160655543371561lxgt",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923160705321786202WWlY",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c50bc17c282a20ad45cae2db",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"parentId": "I09231700262647132022eOS",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 400000
								}
							},
							{
								"_id": "I0923161619877040230EFdg",
								"_tpl": "5c0a840b86f7742ffa4f2482",
								"slotId": "hideout",
								"location": {
									"x": 5,
									"y": 16,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Backpacks"
									}
								}
							},
							{
								"_id": "I0923161957499532300MIuG",
								"_tpl": "5a0dc45586f7742f6b0b73e3",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162004117531977qtrE",
								"_tpl": "5a0dc95c86f77452440fc675",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162016311997251vlxk",
								"_tpl": "5a0eb6ac86f7743124037a28",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162030258419121HkoX",
								"_tpl": "61a64428a8c6aa1b795f0ba1",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012629609398aM9C",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162037336030465R8G8",
								"_tpl": "5a0ea64786f7741707720468",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231620464257305228O25",
								"_tpl": "5a144dfd86f77445cb5a0982",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162110650095376Mvpg",
								"_tpl": "5a0ee30786f774023b6ee08f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162119180063389XCPQ",
								"_tpl": "5a13eebd86f7746fd639aa93",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162138603509211jslO",
								"_tpl": "5a0f0f5886f7741c4e32a472",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162142920503796Uun7",
								"_tpl": "5a0f08bc86f77478f33b84c2",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162156877833751je6r",
								"_tpl": "5a144bdb86f7741d374bbde0",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162204956830228mR9J",
								"_tpl": "5a13f35286f77413ef1436b0",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162215958050277kfus",
								"_tpl": "5a0ee34586f774023b6ee092",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162222661457286E4cF",
								"_tpl": "5a13ef7e86f7741290491063",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162231287148888ARNs",
								"_tpl": "5a145d4786f7744cbb6f4a12",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162237896280952FJ5M",
								"_tpl": "5a0eec9686f77402ac5c39f2",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231622483010052846sqK",
								"_tpl": "5a13f46386f7741dd7384b04",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162256706080618No9V",
								"_tpl": "5a0eff2986f7741fd654e684",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162300970571332BC2u",
								"_tpl": "5a0eecf686f7740350630097",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162306431140881Gh4J",
								"_tpl": "5a145ebb86f77458f1796f05",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162404427441047y5Vh",
								"_tpl": "591382d986f774465a6413a7",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231700262647132022eOS",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162416969996398rMiG",
								"_tpl": "5780cf7f2459777de4559322",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231700262647132022eOS",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162426133200119wIAc",
								"_tpl": "59148c8a86f774197930e983",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231700262647132022eOS",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162456436558551eiKk",
								"_tpl": "5780d0652459777df90dcb74",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231700262647132022eOS",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162459378529940k8bo",
								"_tpl": "5913877a86f774432f15d444",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231700262647132022eOS",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162501364305248LAUW",
								"_tpl": "5a0f045e86f7745b0f0d0e42",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162507480192422obkE",
								"_tpl": "59387a4986f77401cc236e62",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231700262647132022eOS",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231625141257603694kU9",
								"_tpl": "5448ba0b4bdc2d02308b456c",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923170024829821580HKfP",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162522663576888MDa2",
								"_tpl": "5780cf942459777df90dcb72",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231700262647132022eOS",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162539187483313u7QC",
								"_tpl": "5ad5d7d286f77450166e0a89",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012800810394GhkG",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162541362146756xO4f",
								"_tpl": "5addaffe86f77470b455f900",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012800810394GhkG",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162607345330041cRjb",
								"_tpl": "5ad5cfbd86f7742c825d6104",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012800810394GhkG",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231626219343963429XjD",
								"_tpl": "5ad5db3786f7743568421cce",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012800810394GhkG",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162629472294635rp8F",
								"_tpl": "5ad7247386f7747487619dc3",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012800810394GhkG",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162651525564523woqA",
								"_tpl": "5ad5d64486f774079b080af8",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012800810394GhkG",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162704113897000ots6",
								"_tpl": "5c1d0f4986f7744bb01837fa",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012117881969lzoU",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162712641757458SFSX",
								"_tpl": "5c1d0c5f86f7744bb2683cf0",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012117881969lzoU",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162721452342744mSia",
								"_tpl": "5efde6b4f5448336730dbd61",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012117881969lzoU",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162726607067070OdtK",
								"_tpl": "5eff09cd30a7dc22fd1ddfed",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162735444669727Xx48",
								"_tpl": "5c1d0dc586f7744baf2e7b79",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012117881969lzoU",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162741105051133QsNf",
								"_tpl": "5c1d0efb86f7744baf2e7b7b",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012117881969lzoU",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162811840717750Qxcg",
								"_tpl": "5c1f79a086f7746ed066fb8f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012117881969lzoU",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162813523579788gVxY",
								"_tpl": "5c1e2d1f86f77431e9280bee",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012117881969lzoU",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162815445924135I7f2",
								"_tpl": "5c1e2a1e86f77431ea0ea84c",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012117881969lzoU",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162822221409619dKAC",
								"_tpl": "5d80cb3886f77440556dbf09",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "ad6a118bc008509fbcc42221",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162828424670024HyL6",
								"_tpl": "5d95d6fa86f77424484aa5e9",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "ad6a118bc008509fbcc42221",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231628407451160469Y93",
								"_tpl": "5d80c62a86f7744036212b3f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "ad6a118bc008509fbcc42221",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162846296380322baVX",
								"_tpl": "5d80c60f86f77440373c4ece",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "ad6a118bc008509fbcc42221",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923162859406734599Kxni",
								"_tpl": "5d8e0e0e86f774321140eb56",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "ad6a118bc008509fbcc42221",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231629545928477733l5j",
								"_tpl": "5d947d4e86f774447b415895",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "ad6a118bc008509fbcc42221",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923163004209038306c5ol",
								"_tpl": "5d80c6c586f77440351beef1",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "ad6a118bc008509fbcc42221",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231630133995671537jna",
								"_tpl": "5d80ccac86f77470841ff452",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "ad6a118bc008509fbcc42221",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923163014955364689U15y",
								"_tpl": "5d80ccdd86f77474f7575e02",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "ad6a118bc008509fbcc42221",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923163015234369493fnVz",
								"_tpl": "5d80cd1a86f77402aa362f42",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "ad6a118bc008509fbcc42221",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231630267120719986Qou",
								"_tpl": "5d947d3886f774447b415893",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "ad6a118bc008509fbcc42221",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231630366918020910U0M",
								"_tpl": "5d9f1fa686f774726974a992",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "ad6a118bc008509fbcc42221",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923163052676536479jVta",
								"_tpl": "591afe0186f77431bd616a11",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923170024829821580HKfP",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923163112566676080RcKi",
								"_tpl": "62987c658081af308d7558c6",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012629609398aM9C",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923163119233899003fmbh",
								"_tpl": "62987da96188c076bc0d8c51",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012629609398aM9C",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923163128337226353keAi",
								"_tpl": "62987dfc402c7f69bf010923",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012629609398aM9C",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923163354339051805B2Pq",
								"_tpl": "5448ba0b4bdc2d02308b456c",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231700262647132022eOS",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923164012629609398aM9C",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "3",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923172355114862980Xjmy",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Lighthouse"
									}
								}
							},
							{
								"_id": "I0923164012481084680EZIJ",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "1",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923172355114862980Xjmy",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Shoreline"
									}
								}
							},
							{
								"_id": "I0923164012800810394GhkG",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "2",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923172355114862980Xjmy",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Interchange"
									}
								}
							},
							{
								"_id": "I0923164012117881969lzoU",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "4",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923172355114862980Xjmy",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Labs"
									}
								}
							},
							{
								"_id": "I0923170023119291739gLwI",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "6",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923172355114862980Xjmy",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923170024829821580HKfP",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "5",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923172355114862980Xjmy",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Other"
									}
								}
							},
							{
								"_id": "I09231700262647132022eOS",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "1",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923172355114862980Xjmy",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Customs"
									}
								}
							},
							{
								"_id": "I0923172355114862980Xjmy",
								"_tpl": "5e9db13186f7742f845ee9d3",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "aa181c6bc697085eb24a8387",
								"_tpl": "59fb016586f7746d0d4b423a",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 2,
									"y": 0,
									"r": 1
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "45f0c10affb653b9c69f81ac",
								"_tpl": "5c093db286f7740a1b2617e3",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "f295eab439abccf8027ef460",
								"_tpl": "5aafbcd986f7745e590fff23",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 7,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "8565a78d908561ebb2e20dfb",
								"_tpl": "59fb016586f7746d0d4b423a",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "7947a550219b0c20ec693be3",
								"_tpl": "59fb016586f7746d0d4b423a",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "a70e99fe1baba1af8f040baf",
								"_tpl": "59fb023c86f7746d0d4b423c",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 8,
									"y": 19,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "757d322eeab3640f9ed307a1",
								"_tpl": "59fb023c86f7746d0d4b423c",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 8,
									"y": 24,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "4a2e190061cb984ac698cd98",
								"_tpl": "5b0bbe4e5acfc40dc528a72d",
								"parentId": "I0923160556890464248iIUm",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "6b420d961b8b632cabaa9b57",
								"_tpl": "5b7bedd75acfc43d825283f9",
								"parentId": "4a2e190061cb984ac698cd98",
								"slotId": "mod_handguard",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "a3f2907f036f1b78d5f04af3",
								"_tpl": "5cf78720d7f00c06595bc93e",
								"parentId": "5d02a088606fe8f0e4f26d7c",
								"slotId": "mod_muzzle_001",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "8e1d7fe33914f8327838410e",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "2a26b93bacc831eada432f99",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "80a6cb58f064779fcac7de79",
								"_tpl": "5b7d679f5acfc4001a5c4024",
								"parentId": "4a2e190061cb984ac698cd98",
								"slotId": "mod_pistol_grip",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "88dea6ff9b82f2ec0740c5d9",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "599a826347b28ac2c679a93a",
								"slotId": "mod_tactical",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "5d02a088606fe8f0e4f26d7c",
								"_tpl": "5cf78496d7f00c065703d6ca",
								"parentId": "ab913eee8131b8eb4f7847d3",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "ab913eee8131b8eb4f7847d3",
								"_tpl": "5b7be1265acfc400161d0798",
								"parentId": "4a2e190061cb984ac698cd98",
								"slotId": "mod_barrel",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "4be2adab0920aa06e05147e6",
								"_tpl": "5c878e9d2e2216000f201903",
								"parentId": "5d02a088606fe8f0e4f26d7c",
								"slotId": "mod_muzzle_000",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "2a26b93bacc831eada432f99",
								"_tpl": "5b099bb25acfc400186331e8",
								"parentId": "4a2e190061cb984ac698cd98",
								"slotId": "mod_reciever",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "599a826347b28ac2c679a93a",
								"_tpl": "5b7be4575acfc400161d0832",
								"parentId": "6b420d961b8b632cabaa9b57",
								"slotId": "mod_mount_001",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 8,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "a3bbee686d038c3ffa90028d",
								"_tpl": "5c1cd46f2e22164bef5cfedb",
								"parentId": "dc6466f62e17cc8c0bca9f34",
								"slotId": "mod_foregrip",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "dc6466f62e17cc8c0bca9f34",
								"_tpl": "5b7be46e5acfc400170e2dcf",
								"parentId": "6b420d961b8b632cabaa9b57",
								"slotId": "mod_mount_000",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 6,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "9561339044accc28f333a477",
								"_tpl": "5b7d37845acfc400170e2f87",
								"parentId": "4a2e190061cb984ac698cd98",
								"slotId": "mod_magazine",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "108b9966426dcdf821dd3d31",
								"_tpl": "5b099bf25acfc4001637e683",
								"parentId": "4a2e190061cb984ac698cd98",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "5874ab8b3c06f827d0184339",
								"_tpl": "58d2947e86f77447aa070d53",
								"parentId": "9c39cbd7dd97ca27e54158f3",
								"slotId": "mod_stock_000",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "cf8969ab754ddad83817d145",
								"_tpl": "58d2912286f7744e27117493",
								"parentId": "5874ab8b3c06f827d0184339",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 5,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "9c39cbd7dd97ca27e54158f3",
								"_tpl": "5c793fb92e221644f31bfb64",
								"parentId": "108b9966426dcdf821dd3d31",
								"slotId": "mod_stock_000",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 5,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "f89562ad399a6e6f15a7e3b2",
								"_tpl": "58dd3ad986f77403051cba8f",
								"parentId": "9561339044accc28f333a477",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 29
								}
							},
							{
								"_id": "2376a60c9d6ffdee107b73b5",
								"_tpl": "58dd3ad986f77403051cba8f",
								"parentId": "4a2e190061cb984ac698cd98",
								"slotId": "patron_in_weapon",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "46fe73c5bc10db3832a8c4aa",
								"_tpl": "5cadfbf7ae92152ac412eeef",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "FirstPrimaryWeapon",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "ddc91fbce6e06f7e2e0192e8",
								"_tpl": "5cdaa99dd7f00c002412d0b2",
								"parentId": "46fe73c5bc10db3832a8c4aa",
								"slotId": "mod_handguard",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "28bb2da8f46d04c976c36b2b",
								"_tpl": "5b3b99475acfc432ff4dcbee",
								"parentId": "eede634970f78411f650ee06",
								"slotId": "mod_scope_000",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 79,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "eede634970f78411f650ee06",
								"_tpl": "6171407e50224f204c1da3c5",
								"parentId": "46fe73c5bc10db3832a8c4aa",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "49042674eb441cf353481d55",
								"_tpl": "577d141e24597739c5255e01",
								"parentId": "7cf5beee21558175c56fddc8",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 67,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "7cf5beee21558175c56fddc8",
								"_tpl": "577d128124597739d65d0e56",
								"parentId": "eede634970f78411f650ee06",
								"slotId": "mod_scope_001",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 5,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "eaf1aa6422c4cb1dfafb874e",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "46fe73c5bc10db3832a8c4aa",
								"slotId": "mod_tactical_002",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "c66e42a993435bc3079ef815",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "46fe73c5bc10db3832a8c4aa",
								"slotId": "mod_magazine",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 5,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "142b303fa72f32c109fbf447",
								"_tpl": "5caf187cae92157c28402e43",
								"parentId": "46fe73c5bc10db3832a8c4aa",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 83,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "c5cb219fa42c9c2555cee62b",
								"_tpl": "5a7dbfc1159bd40016548fde",
								"parentId": "ddc91fbce6e06f7e2e0192e8",
								"slotId": "mod_foregrip",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 75,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "0ded896ea2eb62f7f247d23b",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "c66e42a993435bc3079ef815",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "0225f70a4f8e661543d561fe",
								"_tpl": "5fc3e272f8b6a877a729eac5",
								"parentId": "I0923160556623493093KHEX",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "4a8508c7972939ed02ca640a",
								"_tpl": "5fc3e466187fea44d52eda90",
								"parentId": "0225f70a4f8e661543d561fe",
								"slotId": "mod_magazine",
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "034cecbd0df49539a8b5036b",
								"_tpl": "5fc3e4ee7283c4046c5814af",
								"parentId": "0225f70a4f8e661543d561fe",
								"slotId": "mod_stock",
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "4d87e35a5c4bed9946defb16",
								"_tpl": "5fc3e4a27283c4046c5814ab",
								"parentId": "0225f70a4f8e661543d561fe",
								"slotId": "mod_barrel",
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "c9c461aaa8c78c7659a0d771",
								"_tpl": "5fc53954f8b6a877a729eaeb",
								"parentId": "0225f70a4f8e661543d561fe",
								"slotId": "mod_mount_000",
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "f4368002a8dc72cc594716a2",
								"_tpl": "5fc5396e900b1d5091531e72",
								"parentId": "0225f70a4f8e661543d561fe",
								"slotId": "mod_mount_001",
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "51c63a58985525cf5992e1a1",
								"_tpl": "5fc5396e900b1d5091531e72",
								"parentId": "0225f70a4f8e661543d561fe",
								"slotId": "mod_mount_002",
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "33ab3e860b29cacce0374f7a",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "0225f70a4f8e661543d561fe",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "4a3e810db253c6b60b5a4d3e",
								"_tpl": "6130c4d51cb55961fa0fd49f",
								"parentId": "4d87e35a5c4bed9946defb16",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "995204aee4c53b48bd071bb9",
								"_tpl": "5fc3e466187fea44d52eda90",
								"parentId": "I0923160556623493093KHEX",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "a49a1232e354baca22d150ae",
								"_tpl": "59fc48e086f77463b1118392",
								"parentId": "c9c461aaa8c78c7659a0d771",
								"slotId": "mod_foregrip",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "d0f5390b8a4eabf3b57bf420",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "51c63a58985525cf5992e1a1",
								"slotId": "mod_tactical",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "7713694f1a4494f07a9b84c4",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "b359a35b901eba814a2703ac",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "8efbd89d7817b2ba8452c04d",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "4a8508c7972939ed02ca640a",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "0311e4e0d26b7485023311a6",
								"_tpl": "6176aca650224f204c1da3fb",
								"parentId": "I0923160556890464248iIUm",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "8712c59ed8d2c430746a623a",
								"_tpl": "617153016c780c1e710c9a2f",
								"parentId": "0311e4e0d26b7485023311a6",
								"slotId": "mod_stock",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "8bf2d0156e716ffdf48dc546",
								"_tpl": "61713a8fd92c473c770214a4",
								"parentId": "0311e4e0d26b7485023311a6",
								"slotId": "mod_reciever",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "71a9cac94df7812ad8ad0fec",
								"_tpl": "61702d8a67085e45ef140b24",
								"parentId": "0311e4e0d26b7485023311a6",
								"slotId": "mod_charge",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "1c9f7033f2f23bd93d8cdd23",
								"_tpl": "617155ee50224f204c1da3cd",
								"parentId": "8712c59ed8d2c430746a623a",
								"slotId": "mod_stock_000",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "31364d17adaee4b05ccb5b88",
								"_tpl": "61702be9faa1272e431522c3",
								"parentId": "8bf2d0156e716ffdf48dc546",
								"slotId": "mod_barrel",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "dd65b123c410059df32f37b3",
								"_tpl": "61703001d92c473c77021497",
								"parentId": "8bf2d0156e716ffdf48dc546",
								"slotId": "mod_handguard",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "9bf6d2f9c54c1041496f45bb",
								"_tpl": "61715e7e67085e45ef140b33",
								"parentId": "1c9f7033f2f23bd93d8cdd23",
								"slotId": "mod_stock_000",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "4a05cd7d4795218fbff72783",
								"_tpl": "61702f1b67085e45ef140b26",
								"parentId": "31364d17adaee4b05ccb5b88",
								"slotId": "mod_gas_block",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "210d15a84e86a961d076d9d1",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "8bf2d0156e716ffdf48dc546",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "5eff291f32a238f4c0a07236",
								"_tpl": "617131a4568c120fdd29482d",
								"parentId": "0311e4e0d26b7485023311a6",
								"slotId": "mod_magazine",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 6,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "46674d66bf109d2812551d89",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "dd65b123c410059df32f37b3",
								"slotId": "mod_tactical_002",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "56b7544dbc0f8061bbaa5752",
								"_tpl": "5a7dbfc1159bd40016548fde",
								"parentId": "dd65b123c410059df32f37b3",
								"slotId": "mod_foregrip",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "b3689102098be9c7a6c187cd",
								"_tpl": "5dfa3d2b0dee1b22f862eade",
								"parentId": "c0180e622e38d68c0abf2340",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 2,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "c0180e622e38d68c0abf2340",
								"_tpl": "5dfa3cd1b33c0951220c079b",
								"parentId": "31364d17adaee4b05ccb5b88",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "1fdfc85885f260600bf98d81",
								"_tpl": "5d025cc1d7ad1a53845279ef",
								"parentId": "0311e4e0d26b7485023311a6",
								"slotId": "mod_pistol_grip",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "037d58fcd23fa79679db50a9",
								"_tpl": "58dd3ad986f77403051cba8f",
								"parentId": "5eff291f32a238f4c0a07236",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "3cccb3c1e34704f47000095d",
								"_tpl": "5cc82d76e24e8d00134b4b83",
								"parentId": "I0923160556623493093KHEX",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "60c9f1389877cbddf1d29ec6",
								"_tpl": "5cc70093e4a949033c734312",
								"parentId": "3cccb3c1e34704f47000095d",
								"slotId": "mod_magazine",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "966e417185ccf4936b46577b",
								"_tpl": "5cc700b9e4a949000f0f0f25",
								"parentId": "3cccb3c1e34704f47000095d",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "019cab454a9fd6793cfecd2e",
								"_tpl": "5cc701aae4a949000e1ea45c",
								"parentId": "3cccb3c1e34704f47000095d",
								"slotId": "mod_barrel",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "6bf4a959ca0b80c015ece517",
								"_tpl": "5cc700cae4a949035e43ba72",
								"parentId": "966e417185ccf4936b46577b",
								"slotId": "mod_stock_000",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "ccceca3c160543981bb94655",
								"_tpl": "5cc82796e24e8d000f5859a8",
								"parentId": "019cab454a9fd6793cfecd2e",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "286c172a8ac075fa9a12e96d",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "7ffda234c4fab69baccef673",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "b9444a486fdf539d71e693f1",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "746e5ce0b7d596a695512ac1",
								"slotId": "mod_tactical",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "7ffda234c4fab69baccef673",
								"_tpl": "5cc700ede4a949033c734315",
								"parentId": "3cccb3c1e34704f47000095d",
								"slotId": "mod_reciever",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 5,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "746e5ce0b7d596a695512ac1",
								"_tpl": "5cc7012ae4a949001252b43e",
								"parentId": "7ffda234c4fab69baccef673",
								"slotId": "mod_mount_001",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "4b50f51bd77512a761af2c57",
								"_tpl": "5cebec00d7f00c065c53522a",
								"parentId": "ccceca3c160543981bb94655",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 66,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "0fd8544bcbd8a68bdac59f54",
								"_tpl": "5cc6ea85e4a949000e1ea3c3",
								"parentId": "3cccb3c1e34704f47000095d",
								"slotId": "mod_charge",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "c2c8cbc4bf22272d6f8033fd",
								"_tpl": "5fb64bc92b1b027b1f50bcf2",
								"parentId": "I0923160556623493093KHEX",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									},
									"FireMode": {
										"FireMode": "single"
									},
									"Foldable": {
										"Folded": false
									}
								}
							},
							{
								"_id": "52f315150aedec1b8a49a76d",
								"_tpl": "5fb6567747ce63734e3fa1dc",
								"parentId": "c2c8cbc4bf22272d6f8033fd",
								"slotId": "mod_sight_front",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "b084e05791458b4844213183",
								"_tpl": "5fb6564947ce63734e3fa1da",
								"parentId": "c2c8cbc4bf22272d6f8033fd",
								"slotId": "mod_sight_rear",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "d837863e3c91d733c1e9af55",
								"_tpl": "5fb65363d1409e5ca04b54f5",
								"parentId": "c2c8cbc4bf22272d6f8033fd",
								"slotId": "mod_barrel",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "85364d4436752260e7705799",
								"_tpl": "5fbb976df9986c4cff3fe5f2",
								"parentId": "c2c8cbc4bf22272d6f8033fd",
								"slotId": "mod_mount",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "c938bafba940690357db820b",
								"_tpl": "5fce0f9b55375d18a253eff2",
								"parentId": "c2c8cbc4bf22272d6f8033fd",
								"slotId": "mod_mount_001",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "575def75cc977e6764e11efc",
								"_tpl": "5fce0f9b55375d18a253eff2",
								"parentId": "c2c8cbc4bf22272d6f8033fd",
								"slotId": "mod_mount_002",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "75dadc5267bd121ff093dfac",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "c2c8cbc4bf22272d6f8033fd",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "45d0fd5767897a4982193ef9",
								"_tpl": "5fc4b9b17283c4046c5814d7",
								"parentId": "b7a101caa3670d54cb1ecbee",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 73,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "b7a101caa3670d54cb1ecbee",
								"_tpl": "5fc4b992187fea44d52edaa9",
								"parentId": "d837863e3c91d733c1e9af55",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "c44b171de9bf6c4bc8eb9278",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "575def75cc977e6764e11efc",
								"slotId": "mod_tactical",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "c605573b94dfe73946317f2a",
								"_tpl": "5b057b4f5acfc4771e1bd3e9",
								"parentId": "85364d4436752260e7705799",
								"slotId": "mod_foregrip",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "b359a35b901eba814a2703ac",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"parentId": "I0923160556623493093KHEX",
								"slotId": "main",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 8,
									"BuyRestrictionCurrent": 0
								},
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "86569597d2086390320bdc17",
								"_tpl": "5fb655b748c711690e3a8d5a",
								"parentId": "c2c8cbc4bf22272d6f8033fd",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "2fc39024f27198c77185b8f9",
								"_tpl": "58d2947e86f77447aa070d53",
								"parentId": "34dbcd8042b1f9adafb8ac9e",
								"slotId": "mod_stock_000",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "8c4dae1ff07ac8f06bf5d3c3",
								"_tpl": "58d2912286f7744e27117493",
								"parentId": "2fc39024f27198c77185b8f9",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 5,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "34dbcd8042b1f9adafb8ac9e",
								"_tpl": "5c793fb92e221644f31bfb64",
								"parentId": "86569597d2086390320bdc17",
								"slotId": "mod_stock_000",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 5,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "I09231919234320221807ZvZ",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012629609398aM9C",
								"upd": {
									"StackObjectsCount": 200000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923360050718a5SH",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923700896513Vlu4",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923813681139QnSr",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923712639469BIVV",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231919238138795502Crr",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923851590629EHKK",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923302466464Ia8O",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231919232931652268qWB",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923705681702Fwv0",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923355252363Mvdu",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923297620250pRPq",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923658726981pSaJ",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923110792717GGgf",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923694334773tHGm",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923203984496TZqc",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923526661226hRYL",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923703111109NePB",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923482153784dwJS",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231919231139920772phx",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923436041221pkSY",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923198726814cfhy",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923550671997SIii",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231919237535813370WR6",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231919231403207663Pbn",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923327663165U2QB",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923928923984qhGs",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923574567614dMVC",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923613617649uvRg",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923929014787PhRL",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231919235684216499Ch0",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231919236379059188PV2",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923974823770jfE1",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923668814877zW0Z",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923180276503rETi",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923698691687uUml",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923348219073VabI",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231919234607322161Tcm",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923749914359Jeew",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923789450506MB44",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923666432886AhTT",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923195630119eD71",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923310202109iEZR",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923956637468fwaS",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923633359914Ibqf",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923138134327dUec",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923464939766yNGP",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923837514605rB0M",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923465255077SMLi",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923284806367ekgp",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923948018827RSUI",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923128324236diiz",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923508431215aBXR",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923179545636wpng",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8565a78d908561ebb2e20dfb",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923688704307IR3v",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923149959204Xz78",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923920422082oHaZ",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923191923239289691VciB",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "58dcea09dd2598ffa01fb904",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a5da9e46cc2ef33a3dbda74b",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"parentId": "I0923164012800810394GhkG",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 400000
								}
							},
							{
								"_id": "I0923195740422107042o25f",
								"_tpl": "59136e1e86f774432f15d133",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231700262647132022eOS",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923195751329511935s09G",
								"_tpl": "5a0ea79b86f7741d4a35298e",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923195800636000646t2L1",
								"_tpl": "5a13ef0686f7746e5a411744",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09231958078172542954kRx",
								"_tpl": "5a0ec70e86f7742c0b518fba",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923195817582495663r96u",
								"_tpl": "5a145d7b86f7744cbb6f4a13",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923164012481084680EZIJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923200435488313643QwIU",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "48264f7f5b79eab8634caad3",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232006192496057943JEc",
								"_tpl": "5648a69d4bdc2ded0b8b457b",
								"slotId": "TacticalVest",
								"parentId": "5fe49444ae6628187a2e77b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923200621280750961ISXi",
								"_tpl": "5648a69d4bdc2ded0b8b457b",
								"slotId": "main",
								"location": {
									"x": 10,
									"y": 3,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160612720132437iwRO",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923200648784255282OeMv",
								"_tpl": "5b40e1525acfc4771e1c6611",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e979f224a755a582140dc0b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923200650335822233Mc2D",
								"_tpl": "5b40e1525acfc4771e1c6611",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e979f224a755a582140dc0b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923200758437383227Umcj",
								"_tpl": "5f5e467b0bc58666c37e7821",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923161619877040230EFdg",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923200759148912298Avv3",
								"_tpl": "5f5e467b0bc58666c37e7821",
								"slotId": "Backpack",
								"parentId": "5fe49444ae6628187a2e77b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923201324840706584iljq",
								"_tpl": "5ac66cb05acfc40198510a10",
								"slotId": "main",
								"parentId": "I0923160556890464248iIUm",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								},
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "I0923214755595362842trzU",
								"_tpl": "5b4736a986f774040571e998",
								"slotId": "mod_mount_000",
								"parentId": "I0923214940350690601PQqC",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923214802707523779UGGE",
								"_tpl": "5b4736b986f77405cb415c10",
								"slotId": "mod_mount_002",
								"parentId": "I0923214940350690601PQqC",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923214814162700671eEDY",
								"_tpl": "5e21ca18e4d47f0da15e77dd",
								"slotId": "mod_muzzle",
								"parentId": "I0923201324840706584iljq",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923214825100208484Aadp",
								"_tpl": "5ac78eaf5acfc4001926317a",
								"slotId": "mod_stock",
								"parentId": "I0923201324840706584iljq",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923214833217038732XLZm",
								"_tpl": "6130ca3fd92c473c77020dbd",
								"slotId": "mod_charge",
								"parentId": "I0923201324840706584iljq",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232148465248357228H7j",
								"_tpl": "5d2c76ed48f03532f2136169",
								"slotId": "mod_reciever",
								"parentId": "I0923201324840706584iljq",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923214930695929224d8FF",
								"_tpl": "6087e663132d4d12c81fd96b",
								"slotId": "mod_pistol_grip",
								"parentId": "I0923201324840706584iljq",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923214940350690601PQqC",
								"_tpl": "5b237e425acfc4771e1be0b6",
								"slotId": "mod_gas_block",
								"parentId": "I0923201324840706584iljq",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923214949148209476qpWF",
								"_tpl": "59ecc3dd86f7746dc827481c",
								"slotId": "mod_stock",
								"parentId": "I0923214825100208484Aadp",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923214958275999281Ok0z",
								"_tpl": "5c1bc5af2e221602b412949b",
								"slotId": "mod_foregrip",
								"parentId": "I0923214802707523779UGGE",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923215010200971543yTCp",
								"_tpl": "58491f3324597764bc48fa02",
								"slotId": "mod_scope",
								"parentId": "I09232148465248357228H7j",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923215204347927842kmW0",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "mod_magazine",
								"parentId": "I0923201324840706584iljq",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923215205376736166zUAE",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923215206587652094Th7R",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923215207737946068gINP",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923215209889377154L0lv",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923215226584321652t5hw",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923215227716356214U6Kw",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923215228223976197jLAN",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923215308107725527V35R",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923215308544965650Mr7Y",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923215308885855528u99J",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923215913300596663kLqD",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923215227716356214U6Kw",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923215913186446417vdVq",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923215207737946068gINP",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923215913203695969k32b",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923215228223976197jLAN",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923215913404639794DHhh",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923215226584321652t5hw",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bde60f0bc0d9f2661dbaddfa",
								"_tpl": "54527ac44bdc2d36668b4567",
								"parentId": "I0923215209889377154L0lv",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "52a410ee397c7245a7051467",
								"_tpl": "54527ac44bdc2d36668b4567",
								"parentId": "I0923215205376736166zUAE",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "d8171af80898c78aac1ea3cd",
								"_tpl": "54527ac44bdc2d36668b4567",
								"parentId": "I0923215206587652094Th7R",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "f0f4b9b7001458a9fc9ede77",
								"_tpl": "54527ac44bdc2d36668b4567",
								"parentId": "I0923215204347927842kmW0",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "I0923220707423680234wgUy",
								"_tpl": "5648a69d4bdc2ded0b8b457b",
								"slotId": "main",
								"location": {
									"x": 10,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160612720132437iwRO",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232207208139642053mGo",
								"_tpl": "60926df0132d4d12c81fd9df",
								"slotId": "mod_muzzle",
								"parentId": "I0923220849165310739Ub9T",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923220849165310739Ub9T",
								"_tpl": "609269c3b0e443224b421cc1",
								"slotId": "mod_muzzle",
								"parentId": "I0923214814162700671eEDY",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232209012102757142AFd",
								"_tpl": "5d2369418abbc306c62e0c80",
								"slotId": "mod_tactical",
								"parentId": "I0923214755595362842trzU",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923220939973487011uj5q",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923220939697473183rfCp",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923220939786492222TQ66",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923220939750752633a84w",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923220939714835687cCIB",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923220939292584490Yisr",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923220939390156546pcwB",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923220939160993349LV2Z",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923220939269456266hxmK",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923220939509288242MEKj",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923220939789597408DJfy",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923220939581193147f49I",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232209396432841807L2m",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923220939585740981T0TH",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232209396111596279aZb",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923220939763250472HRqn",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923220939331533290MJm8",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222223240551072nQUh",
								"_tpl": "606587252535c57a13424cfd",
								"slotId": "main",
								"parentId": "I0923160556890464248iIUm",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								},
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "I092322224135569839529fr",
								"_tpl": "5a329052c4a28200741e22d3",
								"slotId": "mod_handguard",
								"parentId": "I0923222448237924002jo34",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222250413756325wruP",
								"_tpl": "6065878ac9cf8012264142fd",
								"slotId": "mod_barrel",
								"parentId": "I0923222448237924002jo34",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232223036050767768On3",
								"_tpl": "5b3b99475acfc432ff4dcbee",
								"slotId": "mod_scope",
								"parentId": "I0923222325944103340CdSx",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222325944103340CdSx",
								"_tpl": "5b3b99265acfc4704b4a1afb",
								"slotId": "mod_scope",
								"parentId": "I0923222448237924002jo34",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222337123491801yKVM",
								"_tpl": "5d443f8fa4b93678dd4a01aa",
								"slotId": "mod_muzzle",
								"parentId": "I0923222250413756325wruP",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222346243892983RGWk",
								"_tpl": "5d44064fa4b9361e4f6eb8b5",
								"slotId": "mod_muzzle",
								"parentId": "I0923222337123491801yKVM",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222400426668970q3Yc",
								"_tpl": "6065dc8a132d4d12c81fd8e3",
								"slotId": "mod_gas_block",
								"parentId": "I0923222250413756325wruP",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222410648879006V4nC",
								"_tpl": "5c0102aa0db834001b734ba1",
								"slotId": "mod_mount_004",
								"parentId": "I092322224135569839529fr",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232224121873963011SqV",
								"_tpl": "5c0102b20db834001d23eebc",
								"slotId": "mod_foregrip",
								"parentId": "I092322224135569839529fr",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222420332728604W1NS",
								"_tpl": "5d2369418abbc306c62e0c80",
								"slotId": "mod_tactical",
								"parentId": "I0923222410648879006V4nC",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222437205234613ZGNi",
								"_tpl": "5c1cd46f2e22164bef5cfedb",
								"slotId": "mod_foregrip",
								"parentId": "I09232224121873963011SqV",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222448237924002jo34",
								"_tpl": "606587a88900dc2d9a55b659",
								"slotId": "mod_reciever",
								"parentId": "I0923222223240551072nQUh",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222504679446807TT63",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								},
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "I0923222504103944186XvQ0",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222504206384040chrQ",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "mod_magazine",
								"parentId": "I0923222223240551072nQUh",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222504822826078jkfa",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222504485115558h5Lg",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222504389336429iP3s",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222504727826135YTNL",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222512340562969j1Df",
								"_tpl": "59db3a1d86f77429e05b4e92",
								"slotId": "mod_pistol_grip",
								"parentId": "I0923222223240551072nQUh",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222539444217575uS9b",
								"_tpl": "58d2912286f7744e27117493",
								"slotId": "mod_stock",
								"parentId": "I0923222615105364652iZyV",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222615105364652iZyV",
								"_tpl": "58d2946386f774496974c37e",
								"slotId": "mod_stock_000",
								"parentId": "I0923222651817762140GOKR",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923222651817762140GOKR",
								"_tpl": "5c793fb92e221644f31bfb64",
								"slotId": "mod_stock_001",
								"parentId": "I0923222223240551072nQUh",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923223341796087579R7QA",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923223354976324380w0iA",
								"_tpl": "606587bd6d0bd7580617bacc",
								"slotId": "mod_charge",
								"parentId": "I0923222223240551072nQUh",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923223528826307357ZFQO",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923223528609385687lX0P",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923223528229900342r6V7",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923223528996366419nf00",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232235281959260901hUS",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923223528155009200znhq",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923223528525273630rqnm",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923223528638852440PAnc",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923223528191026487qVfj",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923223528905765092DMZb",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923223528964740538hXxa",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923222504103944186XvQ0",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923223528238611437eVwm",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923223528311539554UdgF",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923223528500233093MraO",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923222504822826078jkfa",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923223528714256243LSKj",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8271bce29d6a6479362d77c6",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "I0923222504206384040chrQ",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "a7ec3ec6bcd982c7e2d8af8c",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "I0923222504679446807TT63",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "b1e772cfda49bcf308abd519",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "I0923222504727826135YTNL",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "1fe041244cc3b4be6b1c8738",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "I0923222504389336429iP3s",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "febdc4fe632004391820d85b",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "I0923222504485115558h5Lg",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "c0f7b664cefd0b1fcc871808",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "I0923223341796087579R7QA",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "I0923224051529387308nZSv",
								"_tpl": "5fd4c474dd870108a754b241",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160612720132437iwRO",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224052872389689YFXj",
								"_tpl": "5fd4c474dd870108a754b241",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160612720132437iwRO",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224251120319567Ljs5",
								"_tpl": "609e860ebd219504d8507525",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160612720132437iwRO",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224252771588711MR59",
								"_tpl": "609e860ebd219504d8507525",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160612720132437iwRO",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224323834258658OA8w",
								"_tpl": "5aa7e276e5b5b000171d0647",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e979f224a755a582140dc0b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224324325962772bNJE",
								"_tpl": "5aa7e276e5b5b000171d0647",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e979f224a755a582140dc0b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224328619213467gpv7",
								"_tpl": "5aa7e373e5b5b000137b76f0",
								"slotId": "mod_equipment",
								"parentId": "I0923224323834258658OA8w",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232243294130705910KpQ",
								"_tpl": "5aa7e373e5b5b000137b76f0",
								"slotId": "mod_equipment",
								"parentId": "I0923224324325962772bNJE",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224339997566854PsQr",
								"_tpl": "5f60c74e3b85f6263c145586",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e979f224a755a582140dc0b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224340246951161rFSZ",
								"_tpl": "5f60c74e3b85f6263c145586",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e979f224a755a582140dc0b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224343880502619BC14",
								"_tpl": "5f60c85b58eff926626a60f7",
								"slotId": "mod_equipment",
								"parentId": "I0923224339997566854PsQr",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224344468236941RbGm",
								"_tpl": "5f60c85b58eff926626a60f7",
								"slotId": "mod_equipment",
								"parentId": "I0923224340246951161rFSZ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224544672090059WQSD",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160556623493093KHEX",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224544321057242M3oD",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160615894581733Jt9n",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224544355569948zbaB",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160615894581733Jt9n",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224544154952650xh37",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160615894581733Jt9n",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224544795630131ErPY",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160615894581733Jt9n",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232245445128863718QuQ",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160615894581733Jt9n",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224544736638225b0lc",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160615894581733Jt9n",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232246239594332445Waj",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224623740087537PCtT",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232246237299288191vAq",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224623948600889ns0y",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224623357836111WVoG",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224623138600107vdoi",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224623959956552z0mT",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224623877522742yall",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224623338795538Pcag",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224623507701018pFJ1",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224623971283528E8HC",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224623655423998mBpG",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923224544736638225b0lc",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224623442047997HNiG",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923224544672090059WQSD",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224623804597450N2XE",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923224544321057242M3oD",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232246235491061295Dgg",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923224544154952650xh37",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232246236826446234oqH",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923224544795630131ErPY",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923224623527079810x1Ao",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923224544355569948zbaB",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "94701fa129669d11d93503eb",
								"_tpl": "5cc80f38e4a949001152b560",
								"parentId": "I09232245445128863718QuQ",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 50
								}
							},
							{
								"_id": "I09232305118826056333UHB",
								"_tpl": "606dae0ab0e443224b421bb7",
								"slotId": "main",
								"parentId": "I0923160556623493093KHEX",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								},
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "I0923230511372063010Vptw",
								"_tpl": "6076c1b9f2cb2e02a42acedc",
								"slotId": "mod_barrel",
								"parentId": "I09232305118826056333UHB"
							},
							{
								"_id": "I0923230511315714017nDxJ",
								"_tpl": "606ee5c81246154cad35d65e",
								"slotId": "mod_handguard",
								"parentId": "I09232305118826056333UHB"
							},
							{
								"_id": "I0923230511246384454XEOh",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "mod_magazine",
								"parentId": "I09232305118826056333UHB"
							},
							{
								"_id": "I0923230511776509988yWrd",
								"_tpl": "606eef46232e5a31c233d500",
								"slotId": "mod_stock",
								"parentId": "I09232305118826056333UHB"
							},
							{
								"_id": "I0923230511390462691RiKN",
								"_tpl": "606eef756d0bd7580617baf8",
								"slotId": "mod_stock",
								"parentId": "I0923230511776509988yWrd"
							},
							{
								"_id": "I0923230511300973345IsRC",
								"_tpl": "606f2696f2cb2e02a42aceb1",
								"slotId": "mod_tactical",
								"parentId": "I0923230511390462691RiKN"
							},
							{
								"_id": "I0923230511304555612YUtQ",
								"_tpl": "60785ce5132d4d12c81fd918",
								"slotId": "mod_mount",
								"parentId": "I09232305118826056333UHB"
							},
							{
								"_id": "I0923230533631035802hSnZ",
								"_tpl": "607ea812232e5a31c233d53c",
								"slotId": "mod_mount_000",
								"parentId": "I0923230511315714017nDxJ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230546175469808Iy8P",
								"_tpl": "606f262c6d0bd7580617bafa",
								"slotId": "mod_stock",
								"parentId": "I0923230511390462691RiKN",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230638417045912Pfp5",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160615894581733Jt9n",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230644537675924T9Za",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160615894581733Jt9n",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232306447799279943t6a",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160615894581733Jt9n",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230644832328258PjlS",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160615894581733Jt9n",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230644665062330kqC1",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160615894581733Jt9n",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230644933261054BaLW",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160615894581733Jt9n",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230644898623337KaU1",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160615894581733Jt9n",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230709431073558TnO6",
								"_tpl": "5c0111ab0db834001966914d",
								"slotId": "mod_muzzle",
								"parentId": "I0923230511372063010Vptw",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230728116003107Lnwl",
								"_tpl": "59c0ec5b86f77435b128bfca",
								"slotId": "mod_muzzle",
								"parentId": "I0923230709431073558TnO6",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230744872244967z8Zj",
								"_tpl": "56def37dd2720bec348b456a",
								"slotId": "mod_tactical",
								"parentId": "I0923230533631035802hSnZ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230800133032178CaEv",
								"_tpl": "570fd6c2d2720bc6458b457f",
								"slotId": "mod_scope",
								"parentId": "I0923230511304555612YUtQ",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230823775377986tpnA",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923230644832328258PjlS",
								"upd": {
									"StackObjectsCount": 6,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232308233463290596QnG",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230823516687928Dsnz",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230823270382880qqNv",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230823455496174Wt4i",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230823421307911Lmmk",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230823200103048RAoZ",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230823311265750dH0X",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230823657410919FMD6",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230823925794127JqFg",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230823399131554MK0f",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230823777968840sgUf",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230823235518198np9K",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230823279747875bNKI",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230823345423685Ot8g",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230823907540009vxDq",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230823158938023T1rc",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923230823451900796VJnw",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "65710356807375afc6845dc4",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "I0923230644933261054BaLW",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "765308b2c3df9156c2d2334b",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "I09232305118826056333UHB",
								"slotId": "patron_in_weapon",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "5a2ab212161b79e10b101ae0",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "I0923230511246384454XEOh",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "fea8b147da3e4cca951eb550",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "I0923230638417045912Pfp5",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "04adcf1d8f5c40641939456a",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "I0923230644537675924T9Za",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "ea9891cd38be51eab4023416",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "I09232306447799279943t6a",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "ebdf458d9acee31c0cac5e3f",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "I0923230644665062330kqC1",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "3a6029b5a24a284373dafb32",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "I0923230644898623337KaU1",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "I0923232027186859751F3nm",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160615894581733Jt9n",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232040109629854Trnh",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923232027186859751F3nm",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232056798161833fftQ",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615320067631vSra",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232056395933083STrK",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615320067631vSra",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232056665163163NrMk",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615320067631vSra",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232056330589870qGVE",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615320067631vSra",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232056565635216vmEg",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615320067631vSra",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232320567763903250VXP",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615320067631vSra",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232056833986324ymd9",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615320067631vSra",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232126368613442eUmp",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923232056395933083STrK",
								"upd": {
									"StackObjectsCount": 25,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232126775502006hqqA",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923232056833986324ymd9",
								"upd": {
									"StackObjectsCount": 25,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232126892603134iYcL",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923232056565635216vmEg",
								"upd": {
									"StackObjectsCount": 25,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232321261406097409J6V",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923232140458441758sCLD",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232126406121777lGhR",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923232140979470076PxnN",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232321269914435868Qc2",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923232140583789102q8Sq",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232126436067202s1Nt",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923232140700091604ZSfV",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232126903660036uMfn",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549319243199X5JT",
								"upd": {
									"StackObjectsCount": 10,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232126528007563dE1p",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549319243199X5JT",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232126455704654AFej",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549319243199X5JT",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232126858989038B4Jv",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549319243199X5JT",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232126466843678CK6e",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549319243199X5JT",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232126878059401A3BK",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549319243199X5JT",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232126998439806l4O6",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549319243199X5JT",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232321267455857662iC9",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549319243199X5JT",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I092323212695987588803Ij",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549319243199X5JT",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232126897084950vNbN",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549319243199X5JT",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232126496836104lySJ",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549319243199X5JT",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232126876364705XoTO",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549319243199X5JT",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232321261076245209TEo",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549319243199X5JT",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232140979470076PxnN",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615320067631vSra",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232140251560372xppg",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615320067631vSra",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232140458441758sCLD",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615320067631vSra",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232140955506526jOqL",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615320067631vSra",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232140338684238U850",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615320067631vSra",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232140700091604ZSfV",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615320067631vSra",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232140583789102q8Sq",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615320067631vSra",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232213857980251eEMN",
								"_tpl": "5caf1109ae9215753c44119f",
								"slotId": "5",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09232006192496057943JEc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232213199914296WuQ4",
								"_tpl": "5caf1109ae9215753c44119f",
								"slotId": "5",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09232006192496057943JEc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232213192389051cQoA",
								"_tpl": "5caf1109ae9215753c44119f",
								"slotId": "3",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09232006192496057943JEc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232213831177022914t",
								"_tpl": "5caf1109ae9215753c44119f",
								"slotId": "2",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09232006192496057943JEc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232322131518687229tLD",
								"_tpl": "5caf1109ae9215753c44119f",
								"slotId": "1",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09232006192496057943JEc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232213731666697lJua",
								"_tpl": "5caf1109ae9215753c44119f",
								"slotId": "4",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09232006192496057943JEc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232322137521521558ctC",
								"_tpl": "5caf1109ae9215753c44119f",
								"slotId": "10",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09232006192496057943JEc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326196670428rvZU",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326536901162X5Rr",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326753733555LAmx",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326843598608EB2d",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I092323232680233880083kB",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232323267064267044qiZ",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326694434178qTwz",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326555685336bQJK",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326681806986V3EQ",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232323269370212091kTL",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326382283830OrzC",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326630752946Ir45",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326536522397Z0km",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326807430697kGVh",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326514684590aUZT",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326798836698EF7S",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923232213192389051cQoA",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326768118161GYX3",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I09232322131518687229tLD",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326753854247NHKb",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326801082664V4Oc",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326184278666kieI",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326296772950wwfP",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326858675947GlUi",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326886616562fTDb",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09231605498212639068zTm",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232323269653610293T5p",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923232213731666697lJua",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326226554678HlPx",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923232213857980251eEMN",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232326624643073UOOU",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I09232322137521521558ctC",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232401535223167spqf",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615143872800eMjk",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232401292769590oyOz",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615143872800eMjk",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232324012074406151BEt",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615143872800eMjk",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232401474058288ULcc",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615143872800eMjk",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232401320865214hZjj",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615143872800eMjk",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232401375095187xgd8",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615143872800eMjk",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232324014007092476ug6",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615143872800eMjk",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232441957284162M05S",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549738662111nnBi",
								"upd": {
									"StackObjectsCount": 10,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I092323244160909156521Ct",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549738662111nnBi",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232441761544683eN9m",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549738662111nnBi",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232441223638675OQKX",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549738662111nnBi",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232441362033340T5R5",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549738662111nnBi",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232324413619680954XWX",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549738662111nnBi",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232441393790021rB4X",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549738662111nnBi",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232324411539529455hM3",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549738662111nnBi",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232441799845320pMGj",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549738662111nnBi",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232441756915174PlNw",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549738662111nnBi",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232324414863409045XNe",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549738662111nnBi",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232441588839020ZSO6",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549738662111nnBi",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I092323244140781091623Gs",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549738662111nnBi",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232441892370210o7FV",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549738662111nnBi",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232441512155449JXqJ",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549738662111nnBi",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232441124263916HGun",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549738662111nnBi",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232441586799836yYsB",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549738662111nnBi",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232324415520296382mIW",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923232401535223167spqf",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232441431840501SObZ",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923232401292769590oyOz",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232441970389587xFat",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I09232324012074406151BEt",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232441693778640cX1Q",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923232401375095187xgd8",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232441560944798vyhN",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923232455205074839gizx",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232441109842931aWBA",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923232455265805129nmgt",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232441161207598rwvh",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0923232455551218111Xd7t",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232324551438806499Lia",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615143872800eMjk",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232455551218111Xd7t",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615143872800eMjk",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232455728397875bbAN",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615143872800eMjk",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232455265805129nmgt",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615143872800eMjk",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232455504242170VKDh",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615143872800eMjk",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232455205074839gizx",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615143872800eMjk",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923232455719846451EwD8",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615143872800eMjk",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "dd88a92e06d45a9eeccf014a",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "I0923232056798161833fftQ",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "d9a4c73508b288a69491c400",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "I0923232056665163163NrMk",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "8619129f1f0439ab2daafa0e",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "I09232320567763903250VXP",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "84ae09ac73d1f8706f086b20",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "I0923232056330589870qGVE",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "076411e855e7976e04556029",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "I09232324551438806499Lia",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "5f40d036ce6f0327dfb5f87d",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "I0923232455728397875bbAN",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "4da20871887af12de88e1343",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "I0923232455504242170VKDh",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "71e38ad0d17650180a732c40",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "I0923232455719846451EwD8",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "08457067516d55ba3e0b8888",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "I0923232401320865214hZjj",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "151a8aa688e9eb512e6e6ab1",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "I0923232401474058288ULcc",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "686ace1ea47b94dfd0fc3732",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "I09232324014007092476ug6",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "012b864a398271b1f0c3bd26",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "I0923232213199914296WuQ4",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "b91bf0fb7851169e64c9eb15",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "I0923232213831177022914t",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "4796e94f0502f8598e19c364",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "I0923232140251560372xppg",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "e39b239d58bd1d485fc2c5b7",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "I0923232140955506526jOqL",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "e4e2a710111f8b555e994b34",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "I0923232140338684238U850",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "I0923233832613127754C9Ra",
								"_tpl": "5d02797c86f774203f38e30a",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6ea94462e857b6bc08a98c77",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232339138532113757YZz",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923233917733348314R88G",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09232340404636336192nss",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "307fb5ac0ae0a6937a24e649",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923234042491269294V6U7",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "307fb5ac0ae0a6937a24e649",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923234050274953056hsAF",
								"_tpl": "58d3db5386f77426186285a0",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "307fb5ac0ae0a6937a24e649",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0923234057170109851vyLt",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "307fb5ac0ae0a6937a24e649",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "82c297f91fa2e34184f3f6f8",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "6ea94462e857b6bc08a98c77",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "9096cfe0ab527c3307b5d21b",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "6ea94462e857b6bc08a98c77",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "I0924103107778428081sqkF",
								"_tpl": "5447a9cd4bdc2dbd208b4567",
								"slotId": "main",
								"parentId": "I0923160556890464248iIUm",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								},
								"location": {
									"x": 0,
									"y": 8,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "I0924103120455022238ufJP",
								"_tpl": "5b7be4895acfc400170e2dd5",
								"slotId": "mod_foregrip",
								"parentId": "I0924103349974187676Ui7W",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103151619658328ce0S",
								"_tpl": "5b2240bf5acfc40dc528af69",
								"slotId": "mod_charge",
								"parentId": "I0924103107778428081sqkF",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103208218434683YySW",
								"_tpl": "5d00ec68d7ad1a04a067e5be",
								"slotId": "mod_gas_block",
								"parentId": "I0924103319324988536y9px",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103227117032337ubpq",
								"_tpl": "609269c3b0e443224b421cc1",
								"slotId": "mod_muzzle",
								"parentId": "I0924103319324988536y9px",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103250164137320siVg",
								"_tpl": "5c793fb92e221644f31bfb64",
								"slotId": "mod_stock",
								"parentId": "I0924103107778428081sqkF",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103300222232471IFDc",
								"_tpl": "56def37dd2720bec348b456a",
								"slotId": "mod_tactical_003",
								"parentId": "I0924103349974187676Ui7W",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103308133525410uPiQ",
								"_tpl": "59db3a1d86f77429e05b4e92",
								"slotId": "mod_pistol_grip",
								"parentId": "I0924103107778428081sqkF",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103319324988536y9px",
								"_tpl": "55d3632e4bdc2d972f8b4569",
								"slotId": "mod_barrel",
								"parentId": "I0924103334398173930rgvU",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103334398173930rgvU",
								"_tpl": "59bfe68886f7746004266202",
								"slotId": "mod_reciever",
								"parentId": "I0924103107778428081sqkF",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103349974187676Ui7W",
								"_tpl": "5c78f2492e221600114c9f04",
								"slotId": "mod_handguard",
								"parentId": "I0924103334398173930rgvU",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103437700139563xVFY",
								"_tpl": "618ba27d9008e4636a67f61d",
								"slotId": "mod_scope",
								"parentId": "I0924103446360670578SzTW",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103446360670578SzTW",
								"_tpl": "5b3b99265acfc4704b4a1afb",
								"slotId": "mod_scope",
								"parentId": "I0924103334398173930rgvU",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103527494511197jlwK",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103527962379058treL",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103527967519895BK8D",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "9",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09232006192496057943JEc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103527556977741M1Gs",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103527792750031i52y",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103527716030157mvNX",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103527345997008b6Xh",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103527526804161AldW",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103544648723089xDuy",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241035445525022492le6",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "48264f7f5b79eab8634caad3",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I092410354453463012581Cg",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "8",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I09232006192496057943JEc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103544765302567qjES",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103544787582463jFYj",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103544686262746T7Dq",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103544523048886Zxz3",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I092410354431346999361BD",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103544390691891BSdd",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103558777024441asLW",
								"_tpl": "61605e13ffa6e502ac5e7eef",
								"slotId": "SpecialSlot1",
								"parentId": "be2c737eca1dd8acf5bc9e1d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103618932301088Rm3n",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "307fb5ac0ae0a6937a24e649",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103618196485554Fqy0",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "307fb5ac0ae0a6937a24e649",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103618388895884jQJs",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "307fb5ac0ae0a6937a24e649",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103618267583560OJ8I",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "307fb5ac0ae0a6937a24e649",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103618991388501AaPv",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "307fb5ac0ae0a6937a24e649",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103618650027003Yisl",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "307fb5ac0ae0a6937a24e649",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241036184557610338LYo",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "307fb5ac0ae0a6937a24e649",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924103618994815864Fcx5",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "307fb5ac0ae0a6937a24e649",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241047267881391762Aa2",
								"_tpl": "58d2947e86f77447aa070d53",
								"slotId": "mod_stock_000",
								"parentId": "I0924103250164137320siVg",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924104735340849715KG22",
								"_tpl": "58d2912286f7744e27117493",
								"slotId": "mod_stock",
								"parentId": "I09241047267881391762Aa2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924104756415952079245R",
								"_tpl": "60926df0132d4d12c81fd9df",
								"slotId": "mod_muzzle",
								"parentId": "I0924103227117032337ubpq",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105332684254419zzfZ",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241053328431412155ems",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241053327655777708dEZ",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105332690371679ktS8",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105332139651141SLw6",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105332583422521tq43",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105332985534327XAtI",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I092410533243103553027E4",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105332960441254eFBI",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241053329512127409b7w",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105332444672343yHOe",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105332251208664t55f",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105332695777288GQKH",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105332877598089fXTK",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105332447185528SLjb",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105332767247190Dtjf",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105332560940332yL5n",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "I0923160615616283334o6to",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105346518733344aQkj",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105346939262659UuFz",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105346310493788ccuK",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0924105332684254419zzfZ",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105346122402195C6VG",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I09241053328431412155ems",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105346905194006BNVH",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I09241053327655777708dEZ",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105346767884408lZNY",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0924105332690371679ktS8",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241053467938882398hS8",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0924105332139651141SLw6",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105346736280704WQqn",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0924105332583422521tq43",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105346122482873XCWF",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0924105332985534327XAtI",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105346743524587h9A0",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105346411951429k3Ak",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105346793530354GP3h",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105346624225793u7dE",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105346768332154rIP6",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105346478609523EMIv",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105346441258942Ll7N",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241053467726087176p63",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241053572767808494oNn",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0924105332960441254eFBI",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105357252617759xiPO",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I09241053329512127409b7w",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105357425949669xSmY",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0924105332444672343yHOe",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241053573606639104WOM",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0924105332251208664t55f",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105357316321201PWnB",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0924105332695777288GQKH",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105357524698609zQGi",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0924105332877598089fXTK",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105357570384388QzYL",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0924105332447185528SLjb",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105357466026757pJyz",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105357853021358C5QA",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105357707025543A1MH",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105357429024911HVzP",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105357309177742EOta",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105357849238463njnT",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105357261027050ebtD",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241053572306517071c2W",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105357713978623iWLF",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105357188405538o5eP",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549508325839Y4hF",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241054092988239158MPx",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "4762bc96ec1eb296c80c9766",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105409799673885uXHZ",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105409387258239aYnH",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105409798759501NJZW",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105409211257997w2gS",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105409665756829mxg2",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105409887985335B8sQ",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105421251802981kn7I",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105421598975136t2b0",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "4762bc96ec1eb296c80c9766",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105421122138835MQtQ",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105421490888809TxJh",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105421761795730D9LK",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105421554513904UXbI",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105421674357959tJmD",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105431829384516ao88",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105431260448280oOYD",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241054318189322187sYD",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241054312207525900AAF",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105431383292080fDAO",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241054312252612956xN0",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105431351910443ewPD",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105438255602317NU3g",
								"_tpl": "5c0e533786f7747fa23f4d47",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105502699816363Ug4q",
								"_tpl": "5ed51652f6c34d2cc26336a1",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105511207015167AlB5",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105511206877883KwxO",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105511431293227j0vm",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105511941024289Qbsv",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105511882398528QNI2",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924105511152520616lcsf",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "69343931db3b45c07ff1ac86",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "995204aee4c53b48bd071bb9",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "I0924110225497887587MUzv",
								"_tpl": "5c0e533786f7747fa23f4d47",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924110225434251922Ownv",
								"_tpl": "5c0e533786f7747fa23f4d47",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924110225598958463wG5M",
								"_tpl": "5c0e533786f7747fa23f4d47",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924110233679814319PiCf",
								"_tpl": "5ed51652f6c34d2cc26336a1",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924110233373369588c2my",
								"_tpl": "5ed51652f6c34d2cc26336a1",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924110233385420274cfW7",
								"_tpl": "5ed51652f6c34d2cc26336a1",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f295eab439abccf8027ef460",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924110824561077489zDj4",
								"_tpl": "628a60ae6b1d481ff772e9c8",
								"slotId": "main",
								"parentId": "I0923160556890464248iIUm",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								},
								"location": {
									"x": 1,
									"y": 10,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "I0924110918537860679YjTi",
								"_tpl": "628a83c29179c324ed269508",
								"slotId": "mod_gas_block",
								"parentId": "I0924110824561077489zDj4",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924110956732724749bhkH",
								"_tpl": "6130c43c67085e45ef1405a1",
								"slotId": "mod_muzzle",
								"parentId": "I0924110824561077489zDj4",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241110225209242559Knq",
								"_tpl": "5dfa3d2b0dee1b22f862eade",
								"slotId": "mod_muzzle",
								"parentId": "I0924110956732724749bhkH",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111031161605569u1Yr",
								"_tpl": "56def37dd2720bec348b456a",
								"slotId": "mod_tactical",
								"parentId": "I0924111047148610184sJqf",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111047148610184sJqf",
								"_tpl": "5b7be47f5acfc400170e2dd2",
								"slotId": "mod_mount_001",
								"parentId": "I0924110918537860679YjTi",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111049804956220mmMA",
								"_tpl": "5b7be4895acfc400170e2dd5",
								"slotId": "mod_foregrip",
								"parentId": "I0924110918537860679YjTi",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111104955904857dUUe",
								"_tpl": "5b057b4f5acfc4771e1bd3e9",
								"slotId": "mod_foregrip",
								"parentId": "I0924111049804956220mmMA",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111120783144933UVlF",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111120703034924Aau2",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111120930681814uHbE",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111120804751200i2km",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111120643422582lQvi",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111120996390915g0By",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111120335668161RDiT",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111156431226628RUMN",
								"_tpl": "628c9ab845c59e5b80768a81",
								"slotId": "mod_pistol_grip",
								"parentId": "I0924110824561077489zDj4",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111214949354347Mjsj",
								"_tpl": "5b0e794b5acfc47a877359b2",
								"slotId": "mod_stock_000",
								"parentId": "I0924110824561077489zDj4",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111223214850121YDGE",
								"_tpl": "5b3b99265acfc4704b4a1afb",
								"slotId": "mod_scope",
								"parentId": "I0924111244452838016Blx9",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111232824796725Bcib",
								"_tpl": "618ba27d9008e4636a67f61d",
								"slotId": "mod_scope",
								"parentId": "I0924111223214850121YDGE",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111244452838016Blx9",
								"_tpl": "5d2c772c48f0355d95672c25",
								"slotId": "mod_reciever",
								"parentId": "I0924110824561077489zDj4",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111320296212212DvWk",
								"_tpl": "6130ca3fd92c473c77020dbd",
								"slotId": "mod_charge",
								"parentId": "I0924110824561077489zDj4",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111345784662489Gv0p",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111345665055317zLgb",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111345740647662Hd91",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111345692591321zizx",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241113455935498371R9U",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111345801506450W8L5",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111345934752259MnJj",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160615981914890Ew67",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111345902859589j9cy",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "mod_magazine",
								"parentId": "I0924110824561077489zDj4",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111355916165484To7m",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0924111345934752259MnJj",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111355265236315EEZw",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0924111345801506450W8L5",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111355226216787sYdh",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I09241113455935498371R9U",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111355425269881rEaw",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0924111345692591321zizx",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111355581728927GF6r",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0924111345740647662Hd91",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111355984108199r492",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111355165620848ecpL",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111355845524363KnO9",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111355448674919QG2n",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111355325013295p3Mc",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111355114366007goM1",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111355641777293v1sE",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111355989509160Efes",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111355815942310GgRb",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111355180690534mrAm",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160549838359074wGUG",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924111355265741038LZAY",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0924111345784662489Gv0p",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241113558304606893LJL",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "I0924111345665055317zLgb",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "be010f49a5c93cf428a2ecb5",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"parentId": "I0924111345902859589j9cy",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 50
								}
							},
							{
								"_id": "I0924195856229983462KeGl",
								"_tpl": "5a154d5cfcdbcb001a3b00da",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e979f224a755a582140dc0b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241959018409065640pta",
								"_tpl": "5a16b7e1fcdbcb00165aa6c9",
								"slotId": "mod_equipment_000",
								"parentId": "I0924195856229983462KeGl",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924195903381762512YN2L",
								"_tpl": "5a16b7e1fcdbcb00165aa6c9",
								"slotId": "mod_equipment_000",
								"parentId": "I0924195906474785769vb4W",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924195906474785769vb4W",
								"_tpl": "5a154d5cfcdbcb001a3b00da",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e979f224a755a582140dc0b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924195917705483215nyCI",
								"_tpl": "5c0e655586f774045612eeb2",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160612720132437iwRO",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924195917948281343hrhM",
								"_tpl": "5c0e655586f774045612eeb2",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160612720132437iwRO",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924195929663570432cF3c",
								"_tpl": "5e4ac41886f77406a511c9a8",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160612720132437iwRO",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924195931824560602xSxP",
								"_tpl": "5e4ac41886f77406a511c9a8",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160612720132437iwRO",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09241959427772165309AWM",
								"_tpl": "5c0e746986f7741453628fe5",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160612720132437iwRO",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924195944241087799P6iR",
								"_tpl": "5c0e746986f7741453628fe5",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923160612720132437iwRO",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924195951139644907Ko2J",
								"_tpl": "5aa2ba71e5b5b000137b758f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e979f224a755a582140dc0b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924195952677011323zGQg",
								"_tpl": "5aa2ba71e5b5b000137b758f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e979f224a755a582140dc0b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924200000877104011XSXv",
								"_tpl": "545cdae64bdc2d39198b4568",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923161619877040230EFdg",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I09242000025957761157b93",
								"_tpl": "545cdae64bdc2d39198b4568",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0924200000877104011XSXv",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924200042213149416Gv2x",
								"_tpl": "5df8a4d786f77412672a1e3b",
								"slotId": "main",
								"location": {
									"x": 8,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923161619877040230EFdg",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924200044800889486TTdC",
								"_tpl": "5df8a4d786f77412672a1e3b",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0924200042213149416Gv2x",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924200146217238919hwzR",
								"_tpl": "5c093e3486f77430cb02e593",
								"slotId": "8",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "I0923172355114862980Xjmy",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924200202554477313NxzO",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6ea94462e857b6bc08a98c77",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I092420020274473327962Sx",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6ea94462e857b6bc08a98c77",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924200202254821819boqR",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6ea94462e857b6bc08a98c77",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924200202639289878yGiU",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6ea94462e857b6bc08a98c77",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924200202667487506KyCc",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6ea94462e857b6bc08a98c77",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924200202924368129GbNV",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6ea94462e857b6bc08a98c77",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "I0924200202475135048qiBc",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6ea94462e857b6bc08a98c77",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							}
						],
						"equipment": "5fe49444ae6628187a2e77b8",
						"stash": "5fe49444ae6628187a2e78b8",
						"sortingTable": "60dca3da42ad9b706b369aca",
						"questRaidItems": "5fe49444ae6628187a2e78b9",
						"questStashItems": "5fe49444ae6628187a2e78ba",
						"fastPanel": {}
					},
					"Skills": {
						"Common": [{
								"Id": "BotReload",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": -2147483648
							}, {
								"Id": "BotSound",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": -2147483648
							}, {
								"Id": "Endurance",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Strength",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Vitality",
								"Progress": 3400,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Health",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "StressResistance",
								"Progress": 2500,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Metabolism",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Immunity",
								"Progress": 300,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Perception",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Intellect",
								"Progress": 50,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Attention",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Charisma",
								"Progress": 2200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Memory",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Pistol",
								"Progress": 150,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Revolver",
								"Progress": 50,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "SMG",
								"Progress": 900,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Assault",
								"Progress": 1200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Shotgun",
								"Progress": 800,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Sniper",
								"Progress": 600,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "LMG",
								"Progress": 120,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "HMG",
								"Progress": 20,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Launcher",
								"Progress": 20,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "AttachedLauncher",
								"Progress": 20,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Throwing",
								"Progress": 200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Melee",
								"Progress": 20,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "DMR",
								"Progress": 900,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "RecoilControl",
								"Progress": 2100,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "AimDrills",
								"Progress": 1100,
								"PointsEarnedDuringSession": 0,
								"LastAccess": -2147483648
							}, {
								"Id": "Surgery",
								"Progress": 900,
								"PointsEarnedDuringSession": 0,
								"LastAccess": -2147483648
							}, {
								"Id": "CovertMovement",
								"Progress": 2500,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Search",
								"Progress": 2600,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "MagDrills",
								"Progress": 700,
								"PointsEarnedDuringSession": 0,
								"LastAccess": -2147483648
							}, {
								"Id": "Sniping",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "ProneMovement",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "FieldMedicine",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "FirstAid",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "LightVests",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "HeavyVests",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "WeaponModding",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "AdvancedModding",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "NightOps",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "SilentOps",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Lockpicking",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "WeaponTreatment",
								"Progress": 900,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Freetrading",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Auctions",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Cleanoperations",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Barter",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Shadowconnections",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Taskperformance",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Crafting",
								"Progress": 500,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "HideoutManagement",
								"Progress": 700,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}
						],
						"Mastering": [],
						"Points": 0
					},
					"Stats": {
						"SessionCounters": null,
						"OverallCounters": {
							"Items": []
						},
						"SessionExperienceMult": 0,
						"ExperienceBonusMult": 0,
						"TotalSessionExperience": 0,
						"LastSessionDate": 0,
						"Aggressor": null,
						"DroppedItems": [],
						"FoundInRaidItems": [],
						"Victims": [],
						"CarriedQuestItems": [],
						"DamageHistory": {
							"LethalDamagePart": "Head",
							"LethalDamage": null,
							"BodyParts": []
						},
						"LastPlayerState": null,
						"TotalInGameTime": 0,
						"SurvivorClass": "Unknown"
					},
					"Encyclopedia": {
						"56dfef82d2720bbd668b4567": true,
						"57dc324a24597759501edc20": true,
						"57dc334d245977597164366f": true,
						"59d36a0086f7747e673f3946": true,
						"58864a4f2459770fcc257101": true,
						"5448be9a4bdc2dfd2f8b456a": true,
						"544fb45d4bdc2dee738b4568": true,
						"545cdae64bdc2d39198b4568": true,
						"545cdb794bdc2d3a198b456a": true,
						"590c678286f77426c9660122": true,
						"5645bc214bdc2d363b8b4571": true,
						"584984812459776a704a82a6": true,
						"59ccfdba86f7747f2109a587": true,
						"544fb3f34bdc2d03748b456a": true,
						"590c657e86f77412b013051d": true,
						"592c2d1a86f7746dbe2af32a": true,
						"567143bf4bdc2d1a0f8b4567": true,
						"59bffbb386f77435b379b9c2": true,
						"59bffc1f86f77435b128b872": true,
						"595cf16b86f77427440c32e2": true,
						"5644bd2b4bdc2d3b4c8b4572": true,
						"59c6633186f7740cf0493bb9": true,
						"5649b0544bdc2d1b2b8b458a": true,
						"576a581d2459771e7b1bc4f1": true,
						"576a7c512459771e796e0e17": true,
						"59984ab886f7743e98271174": true,
						"59985a8086f77414ec448d1a": true,
						"599860e986f7743bb57573a6": true,
						"59ccd11386f77428f24a488f": true,
						"55801eed4bdc2d89578b4588": true,
						"559ba5b34bdc2d1f1a8b4582": true,
						"5887431f2459777e1612938f": true,
						"56083e1b4bdc2dc8488b4572": true,
						"56083eab4bdc2d26448b456a": true,
						"560e620e4bdc2d724b8b456b": true,
						"56ea8222d2720b69698b4567": true,
						"58948c8e86f77409493f7266": true,
						"5894a51286f77426d13baf02": true,
						"5894a5b586f77426d2590767": true,
						"5894a2c386f77427140b8342": true,
						"58949dea86f77409483e16a8": true,
						"5894a42086f77426d2590762": true,
						"5894a73486f77426d259076c": true,
						"5894a81786f77427140b8347": true,
						"5894a13e86f7742405482982": true,
						"58949edd86f77409483e16a9": true,
						"55d7217a4bdc2d86028b456d": true,
						"557ffd194bdc2d28148b457f": true,
						"544a5cde4bdc2d39388b456b": true,
						"5857a8bc2459772bad15db29": true,
						"5ca20abf86f77418567a43f2": true,
						"564ca99c4bdc2d16268b4589": true,
						"57cd379a24597778e7682ecf": true,
						"57dc2fa62459775949412633": true,
						"57dc32dc245977596d4ef3d3": true,
						"57dc347d245977596754e7a1": true,
						"5649ad3f4bdc2df8348b4585": true,
						"5811ce772459770e9e5f9532": true,
						"5894a05586f774094708ef75": true,
						"5648b1504bdc2d9d488b4584": true,
						"5998597786f77414ea6da093": true,
						"599860ac86f77436b225ed1a": true,
						"599851db86f77467372f0a18": true,
						"5998517986f7746017232f7e": true,
						"576a63cd2459771e796e0e11": true,
						"576a5ed62459771e9c2096cb": true,
						"56d59d3ad2720bdb418b4577": true,
						"5448bd6b4bdc2dfc2f8b4569": true,
						"5448c12b4bdc2d02308b456f": true,
						"573718ba2459775a75491131": true,
						"5649b1c04bdc2d16268b457c": true,
						"5649af094bdc2df8348b4586": true,
						"5649aa744bdc2ded0b8b457e": true,
						"5648b0744bdc2d363b8b4578": true,
						"5696686a4bdc2da3298b456a": true,
						"5449016a4bdc2d6f028b456f": true,
						"57347d7224597744596b4e72": true,
						"544fb25a4bdc2dfb738b4567": true,
						"5448fee04bdc2dbc018b4567": true,
						"544fb3364bdc2d34748b456a": true,
						"5755356824597772cb798962": true,
						"5645bcc04bdc2d363b8b4572": true,
						"5751a25924597722c463c472": true,
						"544fb37f4bdc2dee738b4567": true,
						"5e831507ea0a7c419c2f9bd9": true,
						"5648a7494bdc2d9d488b4583": true,
						"544a11ac4bdc2d470e8b456a": true,
						"55d480c04bdc2d1d4e8b456a": true,
						"56dff3afd2720bba668b4567": true,
						"5aa2b87de5b5b00016327c25": true,
						"5bffdc370db834001d23eca8": true,
						"5ac4cd105acfc40016339859": true,
						"5ac50c185acfc400163398d4": true,
						"5ac72e475acfc400180ae6fe": true,
						"5ac50da15acfc4001718d287": true,
						"5649ade84bdc2d1b2b8b4587": true,
						"5ac7655e5acfc40016339a19": true,
						"5af0454c86f7746bf20992e8": true,
						"569668774bdc2da2298b4568": true,
						"5ab8f39486f7745cd93a1cca": true,
						"5aa7cfc0e5b5b00015693143": true,
						"5d02778e86f774203e7dedbe": true,
						"557ff21e4bdc2d89578b4586": true,
						"5710c24ad2720bc3458b45a3": true,
						"5d0a29fed7ad1a002769ad08": true,
						"5d0a3e8cd7ad1a6f6a3d35bd": true,
						"5d1b371186f774253763a656": true,
						"5ca20d5986f774331e7c9602": true,
						"590c5d4b86f774784e1b9c45": true,
						"5c0e53c886f7747fa54205c7": true,
						"5e870397991fd70db46995c8": true,
						"560d5e524bdc2d25448b4571": true,
						"5e87114fe2db31558c75a120": true,
						"5e87116b81c4ed43e83cefdd": true,
						"5e87080c81c4ed43e83cefda": true,
						"5e87076ce2db31558c75a11d": true,
						"5e87071478f43e51ca2de5e1": true,
						"5e8708d4ae379e67d22e0102": true,
						"590c695186f7741e566b64a2": true,
						"57347da92459774491567cf5": true,
						"5a0c27731526d80618476ac4": true,
						"5755383e24597772cb798966": true,
						"590c661e86f7741e566b646a": true,
						"5b432b965acfc47a8774094e": true,
						"5d40407c86f774318526545a": true,
						"56e294cdd2720b603a8b4575": true,
						"5c488a752e221602b412af63": true,
						"5c48a2852e221602b21d5923": true,
						"5c48a2a42e221602b66d1e07": true,
						"5c48a14f2e2216152006edd7": true,
						"55802d5f4bdc2dac148b458e": true,
						"5c48a2c22e221602b313fb6c": true,
						"55d4887d4bdc2d962f8b4570": true,
						"570fd6c2d2720bc6458b457f": true,
						"54527a984bdc2d4e668b4567": true,
						"5e8488fa988a8701445df1e4": true,
						"5c0e530286f7747fa1419862": true,
						"5f4f9eb969cdc30ff33f09db": true,
						"59e770b986f7742cbd762754": true,
						"5d02797c86f774203f38e30a": true,
						"5d5e9c74a4b9364855191c40": true,
						"5aafbde786f774389d0cbc0f": true,
						"544a5caa4bdc2d1a388b4568": true,
						"5d5d85c586f774279a21cbdb": true,
						"5d5d940f86f7742797262046": true,
						"5beed0f50db834001c062b12": true,
						"5beec1bd0db834001e6006f3": true,
						"5beec3420db834001b095429": true,
						"5beec3e30db8340019619424": true,
						"5beecbb80db834001d2c465e": true,
						"5beec8b20db834001961942a": true,
						"5beec8c20db834001d2c465c": true,
						"5bed625c0db834001c062946": true,
						"5beec91a0db834001961942d": true,
						"5beec9450db83400970084fd": true,
						"5bf3f59f0db834001a6fa060": true,
						"5beec8ea0db834001a6f9dbf": true,
						"5c0505e00db834001b735073": true,
						"5b432d215acfc4771e1c6624": true,
						"5c0e722886f7740458316a57": true,
						"5e2af4a786f7746d3f3c3400": true,
						"5e2af47786f7746d404f3aaa": true,
						"5b40e5e25acfc4001a599bea": true,
						"5d1b36a186f7742523398433": true
					},
					"ConditionCounters": {
						"Counters": []
					},
					"BackendCounters": {},
					"InsuredItems": [],
					"Hideout": {
						"Production": {},
						"Areas": [{
								"type": 3,
								"level": 4,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 0,
								"level": 3,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 1,
								"level": 3,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 2,
								"level": 3,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 4,
								"level": 3,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 5,
								"level": 3,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 6,
								"level": 3,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 7,
								"level": 3,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 8,
								"level": 3,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 9,
								"level": 3,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 10,
								"level": 3,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 11,
								"level": 3,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 12,
								"level": 1,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 13,
								"level": 1,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 14,
								"level": 1,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 15,
								"level": 3,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 16,
								"level": 1,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 17,
								"level": 1,
								"active": true,
								"passiveBonusesEnabled": false,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 18,
								"level": 1,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 19,
								"level": 1,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 20,
								"level": 3,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}, {
								"type": 21,
								"level": 0,
								"active": true,
								"passiveBonusesEnabled": true,
								"completeTime": 0,
								"constructing": false,
								"slots": [],
								"lastRecipe": ""
							}
						]
					},
					"Bonuses": [{
							"type": "StashSize",
							"templateId": "566abbc34bdc2d92178b4576"
						}, {
							"type": "StashSize",
							"templateId": "5811ce572459770cba1a34ea"
						}, {
							"type": "StashSize",
							"templateId": "5811ce662459770f6f490f32"
						}, {
							"type": "StashSize",
							"templateId": "5811ce772459770e9e5f9532"
						}
					],
					"Notes": {
						"Notes": []
					},
					"Quests": [],
					"TradersInfo": {},
					"RagfairInfo": {
						"rating": 2.0,
						"isRatingGrowing": true,
						"offers": []
					},
					"WishList": []
				},
				"suits": ["5cde9ec17d6c8b04723cf479", "5cde9e957d6c8b0474535da7"],
				"dialogues": {},
				"weaponbuilds": {
					"SA58": {
						"id": "3b3df48a5189033240cbc490",
						"name": "SA58",
						"root": "268a56c49239447e1ceaf2f0",
						"items": [
							{
								"_id": "268a56c49239447e1ceaf2f0",
								"_tpl": "5b0bbe4e5acfc40dc528a72d",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "14e6c51cadf00ff41da0d5e4",
								"_tpl": "5b7d679f5acfc4001a5c4024",
								"parentId": "268a56c49239447e1ceaf2f0",
								"slotId": "mod_pistol_grip"
							},
							{
								"_id": "a0bf32a90791e34cf55c8889",
								"_tpl": "5b7d37845acfc400170e2f87",
								"parentId": "268a56c49239447e1ceaf2f0",
								"slotId": "mod_magazine"
							},
							{
								"_id": "f9f958bc2a535f5a2a5994c4",
								"_tpl": "5b7bedd75acfc43d825283f9",
								"parentId": "268a56c49239447e1ceaf2f0",
								"slotId": "mod_handguard"
							},
							{
								"_id": "2ca0e76f55698024d1608210",
								"_tpl": "5b7be1265acfc400161d0798",
								"parentId": "268a56c49239447e1ceaf2f0",
								"slotId": "mod_barrel"
							},
							{
								"_id": "49593fe441ed1bb418a23d70",
								"_tpl": "5b099bb25acfc400186331e8",
								"parentId": "268a56c49239447e1ceaf2f0",
								"slotId": "mod_reciever"
							},
							{
								"_id": "122f645f02ac5070d40ec012",
								"_tpl": "5b099bf25acfc4001637e683",
								"parentId": "268a56c49239447e1ceaf2f0",
								"slotId": "mod_stock"
							},
							{
								"_id": "0018dc299ec4e233f1111802",
								"_tpl": "58dd3ad986f77403051cba8f",
								"parentId": "268a56c49239447e1ceaf2f0",
								"slotId": "patron_in_weapon"
							},
							{
								"_id": "329780b1a5b0191b5493ab71",
								"_tpl": "58dd3ad986f77403051cba8f",
								"parentId": "a0bf32a90791e34cf55c8889",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 29
								}
							},
							{
								"_id": "d772eac3df81c4173afd95a0",
								"_tpl": "5b7be46e5acfc400170e2dcf",
								"parentId": "f9f958bc2a535f5a2a5994c4",
								"slotId": "mod_mount_000"
							},
							{
								"_id": "c27a2b62eb2f6e3d56f1ea5e",
								"_tpl": "5b7be4575acfc400161d0832",
								"parentId": "f9f958bc2a535f5a2a5994c4",
								"slotId": "mod_mount_001"
							},
							{
								"_id": "44a111b0eb1c5088212616d9",
								"_tpl": "5cf78496d7f00c065703d6ca",
								"parentId": "2ca0e76f55698024d1608210",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "e636adccbab8d85117da2291",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "49593fe441ed1bb418a23d70",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "a0d5cfad2d04e990c35cab5e",
								"_tpl": "5c793fb92e221644f31bfb64",
								"parentId": "122f645f02ac5070d40ec012",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "5bc87d6ae3ebd09560912f67",
								"_tpl": "5c1cd46f2e22164bef5cfedb",
								"parentId": "d772eac3df81c4173afd95a0",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "317417c865aaab8c69f76cdb",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "c27a2b62eb2f6e3d56f1ea5e",
								"slotId": "mod_tactical",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "64d2d540509a3d24c4595371",
								"_tpl": "5c878e9d2e2216000f201903",
								"parentId": "44a111b0eb1c5088212616d9",
								"slotId": "mod_muzzle_000"
							},
							{
								"_id": "450d68919c5ed85dc1d54db8",
								"_tpl": "5cf78720d7f00c06595bc93e",
								"parentId": "44a111b0eb1c5088212616d9",
								"slotId": "mod_muzzle_001"
							},
							{
								"_id": "4e55d882dada542c26d2f75c",
								"_tpl": "58d2947e86f77447aa070d53",
								"parentId": "a0d5cfad2d04e990c35cab5e",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "5f7bac2b1e9b653ee1f74e61",
								"_tpl": "58d2912286f7744e27117493",
								"parentId": "4e55d882dada542c26d2f75c",
								"slotId": "mod_stock"
							}
						],
						"Parent": "5447b5f14bdc2d61278b4567"
					},
					"G28": {
						"id": "562ebd1be9d329672e3618a0",
						"name": "G28",
						"root": "d81fce1f645deecd57ad52c6",
						"items": [
							{
								"_id": "d81fce1f645deecd57ad52c6",
								"_tpl": "6176aca650224f204c1da3fb",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "11655d5299e66de5d8cd0047",
								"_tpl": "5d025cc1d7ad1a53845279ef",
								"parentId": "d81fce1f645deecd57ad52c6",
								"slotId": "mod_pistol_grip"
							},
							{
								"_id": "47d753f952516b52152a5bec",
								"_tpl": "617131a4568c120fdd29482d",
								"parentId": "d81fce1f645deecd57ad52c6",
								"slotId": "mod_magazine"
							},
							{
								"_id": "d62d733470663b8eb70a281f",
								"_tpl": "617153016c780c1e710c9a2f",
								"parentId": "d81fce1f645deecd57ad52c6",
								"slotId": "mod_stock"
							},
							{
								"_id": "b60a02a394910dcd0b4bf3e1",
								"_tpl": "61713a8fd92c473c770214a4",
								"parentId": "d81fce1f645deecd57ad52c6",
								"slotId": "mod_reciever"
							},
							{
								"_id": "3f9a13303a52a4eeaeb3b3ca",
								"_tpl": "61702d8a67085e45ef140b24",
								"parentId": "d81fce1f645deecd57ad52c6",
								"slotId": "mod_charge"
							},
							{
								"_id": "d59692183de00bcd9e6e638c",
								"_tpl": "58dd3ad986f77403051cba8f",
								"parentId": "47d753f952516b52152a5bec",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "521f5023b7318a4d5f40ea69",
								"_tpl": "617155ee50224f204c1da3cd",
								"parentId": "d62d733470663b8eb70a281f",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "09d27aa2822322aa602e92a0",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "b60a02a394910dcd0b4bf3e1",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "cd3c784f37487a915c0a642f",
								"_tpl": "61702be9faa1272e431522c3",
								"parentId": "b60a02a394910dcd0b4bf3e1",
								"slotId": "mod_barrel"
							},
							{
								"_id": "89cff2adb72d2e19710be96d",
								"_tpl": "61703001d92c473c77021497",
								"parentId": "b60a02a394910dcd0b4bf3e1",
								"slotId": "mod_handguard"
							},
							{
								"_id": "58863afa5ed39c7dcf3a4491",
								"_tpl": "61715e7e67085e45ef140b33",
								"parentId": "521f5023b7318a4d5f40ea69",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "03f3887a0b0917503585f376",
								"_tpl": "5dfa3cd1b33c0951220c079b",
								"parentId": "cd3c784f37487a915c0a642f",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "8e4f4f6e5760b3162633c045",
								"_tpl": "61702f1b67085e45ef140b26",
								"parentId": "cd3c784f37487a915c0a642f",
								"slotId": "mod_gas_block"
							},
							{
								"_id": "ee6982f8894d41d2fdab6c59",
								"_tpl": "5a7dbfc1159bd40016548fde",
								"parentId": "89cff2adb72d2e19710be96d",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "f18c528e2ec002eebd066a24",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "89cff2adb72d2e19710be96d",
								"slotId": "mod_tactical_002",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "1329ef0df744ea775dde3f57",
								"_tpl": "5dfa3d2b0dee1b22f862eade",
								"parentId": "03f3887a0b0917503585f376",
								"slotId": "mod_muzzle"
							}
						],
						"Parent": "5447b6194bdc2d67278b4567"
					},
					"UMP45": {
						"id": "f0f1c4f6ad973e4cdd31b3cc",
						"name": "UMP45",
						"root": "56b49630d8e5ae8fedb77c5d",
						"items": [
							{
								"_id": "56b49630d8e5ae8fedb77c5d",
								"_tpl": "5fc3e272f8b6a877a729eac5",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "7d0032474bbf714d1239d64f",
								"_tpl": "5fc3e466187fea44d52eda90",
								"parentId": "56b49630d8e5ae8fedb77c5d",
								"slotId": "mod_magazine"
							},
							{
								"_id": "72ea143157ef48971bf4227d",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "56b49630d8e5ae8fedb77c5d",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "c7119bf70d33862058766b91",
								"_tpl": "5fc3e4ee7283c4046c5814af",
								"parentId": "56b49630d8e5ae8fedb77c5d",
								"slotId": "mod_stock"
							},
							{
								"_id": "b5dddb73fb25280c4cd51bd9",
								"_tpl": "5fc3e4a27283c4046c5814ab",
								"parentId": "56b49630d8e5ae8fedb77c5d",
								"slotId": "mod_barrel"
							},
							{
								"_id": "dc6c6ec13c454eb4ecc36413",
								"_tpl": "5fc53954f8b6a877a729eaeb",
								"parentId": "56b49630d8e5ae8fedb77c5d",
								"slotId": "mod_mount_000"
							},
							{
								"_id": "ba308a3ba9dccf96b8a71923",
								"_tpl": "5fc5396e900b1d5091531e72",
								"parentId": "56b49630d8e5ae8fedb77c5d",
								"slotId": "mod_mount_001"
							},
							{
								"_id": "5272b636536f56867b7bf5bd",
								"_tpl": "5fc5396e900b1d5091531e72",
								"parentId": "56b49630d8e5ae8fedb77c5d",
								"slotId": "mod_mount_002"
							},
							{
								"_id": "640711061389e5c422dceac4",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "7d0032474bbf714d1239d64f",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "d99e728e7ba0fcaa16facda7",
								"_tpl": "6130c4d51cb55961fa0fd49f",
								"parentId": "b5dddb73fb25280c4cd51bd9",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "292112a8a313f2c2bc8f6198",
								"_tpl": "59fc48e086f77463b1118392",
								"parentId": "dc6c6ec13c454eb4ecc36413",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "a1697b641d14d98854e2fbfc",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "5272b636536f56867b7bf5bd",
								"slotId": "mod_tactical",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							}
						],
						"Parent": "5447b5e04bdc2d62278b4567"
					},
					"Ash12": {
						"id": "07d3fa2df5541b17d8b3746d",
						"name": "Ash12",
						"root": "b0492383acd5a4b53301f849",
						"items": [
							{
								"_id": "b0492383acd5a4b53301f849",
								"_tpl": "5cadfbf7ae92152ac412eeef",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "06f729e3ec2cc7c2e007cf34",
								"_tpl": "5caf187cae92157c28402e43",
								"parentId": "b0492383acd5a4b53301f849",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "4a80df247da70a49478eddcd",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "b0492383acd5a4b53301f849",
								"slotId": "mod_magazine"
							},
							{
								"_id": "644659c1d1c295468af6fe8d",
								"_tpl": "5cdaa99dd7f00c002412d0b2",
								"parentId": "b0492383acd5a4b53301f849",
								"slotId": "mod_handguard"
							},
							{
								"_id": "e40feedc3242e1eb1f4b339c",
								"_tpl": "6171407e50224f204c1da3c5",
								"parentId": "b0492383acd5a4b53301f849",
								"slotId": "mod_scope"
							},
							{
								"_id": "2a41911ee1c30cc5ce2aac69",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "b0492383acd5a4b53301f849",
								"slotId": "mod_tactical_002",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "ef23097795755cbfed95e6f4",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "4a80df247da70a49478eddcd",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "f55f09db6d5707cb79e981e0",
								"_tpl": "5a7dbfc1159bd40016548fde",
								"parentId": "644659c1d1c295468af6fe8d",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "2661b729eaef9f43453b04b5",
								"_tpl": "5b3b99475acfc432ff4dcbee",
								"parentId": "e40feedc3242e1eb1f4b339c",
								"slotId": "mod_scope_000",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "a7e59cd2bf174ac63bfd3acc",
								"_tpl": "577d128124597739d65d0e56",
								"parentId": "e40feedc3242e1eb1f4b339c",
								"slotId": "mod_scope_001"
							},
							{
								"_id": "41517e6587a5a32db092babd",
								"_tpl": "577d141e24597739c5255e01",
								"parentId": "a7e59cd2bf174ac63bfd3acc",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							}
						],
						"Parent": "5447b5f14bdc2d61278b4567"
					},
					"P90": {
						"id": "34efc571d0cec8ccf403549d",
						"name": "P90",
						"root": "dd843713676f27335a2e1cf2",
						"items": [
							{
								"_id": "dd843713676f27335a2e1cf2",
								"_tpl": "5cc82d76e24e8d00134b4b83",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "3176bde7a4b120c881e8548f",
								"_tpl": "5cc70093e4a949033c734312",
								"parentId": "dd843713676f27335a2e1cf2",
								"slotId": "mod_magazine"
							},
							{
								"_id": "fe8c9fbfba45b0c6cdff5c5a",
								"_tpl": "5cc700b9e4a949000f0f0f25",
								"parentId": "dd843713676f27335a2e1cf2",
								"slotId": "mod_stock"
							},
							{
								"_id": "ba4fd3a338a84993ae240496",
								"_tpl": "5cc700ede4a949033c734315",
								"parentId": "dd843713676f27335a2e1cf2",
								"slotId": "mod_reciever"
							},
							{
								"_id": "bf6e9893ab3007b659dc4b82",
								"_tpl": "5cc701aae4a949000e1ea45c",
								"parentId": "dd843713676f27335a2e1cf2",
								"slotId": "mod_barrel"
							},
							{
								"_id": "b42303c6a17eacea5ec94840",
								"_tpl": "5cc6ea85e4a949000e1ea3c3",
								"parentId": "dd843713676f27335a2e1cf2",
								"slotId": "mod_charge"
							},
							{
								"_id": "019781e3a852d7c1b317ced9",
								"_tpl": "5cc700cae4a949035e43ba72",
								"parentId": "fe8c9fbfba45b0c6cdff5c5a",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "a9bc42064c0a3fade8bfc145",
								"_tpl": "5cc7012ae4a949001252b43e",
								"parentId": "ba4fd3a338a84993ae240496",
								"slotId": "mod_mount_001"
							},
							{
								"_id": "1005b7f0273f44c276ab6e33",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "ba4fd3a338a84993ae240496",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "630bc500ddeb1d8696b8f869",
								"_tpl": "5cc82796e24e8d000f5859a8",
								"parentId": "bf6e9893ab3007b659dc4b82",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "1bcab9783bcfcbafc084afd7",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "a9bc42064c0a3fade8bfc145",
								"slotId": "mod_tactical",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "776dab288b2f085945d070df",
								"_tpl": "5cebec00d7f00c065c53522a",
								"parentId": "630bc500ddeb1d8696b8f869",
								"slotId": "mod_muzzle"
							}
						],
						"Parent": "5447b5e04bdc2d62278b4567"
					},
					"Vector45": {
						"id": "7f23489af05b4840f3fb9f3a",
						"name": "Vector45",
						"root": "ee55b56a73c2c664ef3c70f1",
						"items": [
							{
								"_id": "ee55b56a73c2c664ef3c70f1",
								"_tpl": "5fb64bc92b1b027b1f50bcf2",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "23d55299ee384a653e76bcc3",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"parentId": "ee55b56a73c2c664ef3c70f1",
								"slotId": "mod_magazine"
							},
							{
								"_id": "ea34495c42869be39a9e703b",
								"_tpl": "5fb6567747ce63734e3fa1dc",
								"parentId": "ee55b56a73c2c664ef3c70f1",
								"slotId": "mod_sight_front",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "c73c714b24f597298304c6ae",
								"_tpl": "5fb6564947ce63734e3fa1da",
								"parentId": "ee55b56a73c2c664ef3c70f1",
								"slotId": "mod_sight_rear",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "5ddf0a2cbe6136ba90115046",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "ee55b56a73c2c664ef3c70f1",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "a937fddce820f072049dcfa0",
								"_tpl": "5fb655b748c711690e3a8d5a",
								"parentId": "ee55b56a73c2c664ef3c70f1",
								"slotId": "mod_stock"
							},
							{
								"_id": "939f445c327cf8e61e19d8ab",
								"_tpl": "5fb65363d1409e5ca04b54f5",
								"parentId": "ee55b56a73c2c664ef3c70f1",
								"slotId": "mod_barrel"
							},
							{
								"_id": "bcd026f643914c6ae8c99670",
								"_tpl": "5fbb976df9986c4cff3fe5f2",
								"parentId": "ee55b56a73c2c664ef3c70f1",
								"slotId": "mod_mount"
							},
							{
								"_id": "1e937b23ef67265a4d334be0",
								"_tpl": "5fce0f9b55375d18a253eff2",
								"parentId": "ee55b56a73c2c664ef3c70f1",
								"slotId": "mod_mount_001"
							},
							{
								"_id": "3ee1559ebae1365fbb2ec723",
								"_tpl": "5fce0f9b55375d18a253eff2",
								"parentId": "ee55b56a73c2c664ef3c70f1",
								"slotId": "mod_mount_002"
							},
							{
								"_id": "aab0b288f526f173ff41733f",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "23d55299ee384a653e76bcc3",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "09243bb027055ed7a9ed9efb",
								"_tpl": "5c793fb92e221644f31bfb64",
								"parentId": "a937fddce820f072049dcfa0",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "26bbb6be4454334beffc5c09",
								"_tpl": "5fc4b992187fea44d52edaa9",
								"parentId": "939f445c327cf8e61e19d8ab",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "4bda6f829f0eb4e7334c0435",
								"_tpl": "5b057b4f5acfc4771e1bd3e9",
								"parentId": "bcd026f643914c6ae8c99670",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "d0c0c653d66374773df79818",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "3ee1559ebae1365fbb2ec723",
								"slotId": "mod_tactical",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "521b09ae4e2cf9535d0d892e",
								"_tpl": "58d2947e86f77447aa070d53",
								"parentId": "09243bb027055ed7a9ed9efb",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "9c3d84ea579b955b330a92cb",
								"_tpl": "58d2912286f7744e27117493",
								"parentId": "521b09ae4e2cf9535d0d892e",
								"slotId": "mod_stock"
							},
							{
								"_id": "36f02a4e6c1572d218497142",
								"_tpl": "5fc4b9b17283c4046c5814d7",
								"parentId": "26bbb6be4454334beffc5c09",
								"slotId": "mod_muzzle"
							}
						],
						"Parent": "5447b5e04bdc2d62278b4567"
					},
					"AK101": {
						"id": "4ff8c007e93f82b11a9a5fa9",
						"name": "AK101",
						"root": "8894267b5447d86491e6b076",
						"items": [
							{
								"_id": "8894267b5447d86491e6b076",
								"_tpl": "5ac66cb05acfc40198510a10",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "19dcb0cfd6c6da0d1fb4cb8b",
								"_tpl": "5b237e425acfc4771e1be0b6",
								"parentId": "8894267b5447d86491e6b076",
								"slotId": "mod_gas_block"
							},
							{
								"_id": "2c28dd603993e80e2d6c6bec",
								"_tpl": "5e21ca18e4d47f0da15e77dd",
								"parentId": "8894267b5447d86491e6b076",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "0533700f94cf6b7b314ddca7",
								"_tpl": "6087e663132d4d12c81fd96b",
								"parentId": "8894267b5447d86491e6b076",
								"slotId": "mod_pistol_grip"
							},
							{
								"_id": "6f85ed916c5bdf457ed62d80",
								"_tpl": "5d2c76ed48f03532f2136169",
								"parentId": "8894267b5447d86491e6b076",
								"slotId": "mod_reciever"
							},
							{
								"_id": "21094b0bd304cc739f39cf59",
								"_tpl": "5ac78eaf5acfc4001926317a",
								"parentId": "8894267b5447d86491e6b076",
								"slotId": "mod_stock"
							},
							{
								"_id": "40bbd7458ba10589bb458737",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"parentId": "8894267b5447d86491e6b076",
								"slotId": "mod_magazine"
							},
							{
								"_id": "ab8def21f939c08cdc1bda02",
								"_tpl": "6130ca3fd92c473c77020dbd",
								"parentId": "8894267b5447d86491e6b076",
								"slotId": "mod_charge"
							},
							{
								"_id": "3f28ec4b3059d31ab70844b4",
								"_tpl": "5b4736a986f774040571e998",
								"parentId": "19dcb0cfd6c6da0d1fb4cb8b",
								"slotId": "mod_mount_000"
							},
							{
								"_id": "55a83285019e7405a9978701",
								"_tpl": "5b4736b986f77405cb415c10",
								"parentId": "19dcb0cfd6c6da0d1fb4cb8b",
								"slotId": "mod_mount_002"
							},
							{
								"_id": "626400a160d3c33527c3ddd8",
								"_tpl": "609269c3b0e443224b421cc1",
								"parentId": "2c28dd603993e80e2d6c6bec",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "814df26855e7ca7a943ead17",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "6f85ed916c5bdf457ed62d80",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "51df4e5c437ee573050cd322",
								"_tpl": "59ecc3dd86f7746dc827481c",
								"parentId": "21094b0bd304cc739f39cf59",
								"slotId": "mod_stock"
							},
							{
								"_id": "6e8d128e68946dbf26ae6ad3",
								"_tpl": "54527ac44bdc2d36668b4567",
								"parentId": "40bbd7458ba10589bb458737",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "2b078e87b6314b6c5608d67d",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "3f28ec4b3059d31ab70844b4",
								"slotId": "mod_tactical",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "e5ca59760ba4d61f6c383b13",
								"_tpl": "5c1bc5af2e221602b412949b",
								"parentId": "55a83285019e7405a9978701",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "b9b422525155e731567bb439",
								"_tpl": "60926df0132d4d12c81fd9df",
								"parentId": "626400a160d3c33527c3ddd8",
								"slotId": "mod_muzzle"
							}
						],
						"Parent": "5447b5f14bdc2d61278b4567"
					},
					"Mk47": {
						"id": "11c87363cd19eceabe638159",
						"name": "Mk47",
						"root": "bf8980bc113ec4791a7578ec",
						"items": [
							{
								"_id": "bf8980bc113ec4791a7578ec",
								"_tpl": "606587252535c57a13424cfd",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "800c1dd42086186db9b27e47",
								"_tpl": "59db3a1d86f77429e05b4e92",
								"parentId": "bf8980bc113ec4791a7578ec",
								"slotId": "mod_pistol_grip"
							},
							{
								"_id": "30009c25831bf560ba42e264",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"parentId": "bf8980bc113ec4791a7578ec",
								"slotId": "mod_magazine"
							},
							{
								"_id": "ed6f89a2665a153c678da0df",
								"_tpl": "606587a88900dc2d9a55b659",
								"parentId": "bf8980bc113ec4791a7578ec",
								"slotId": "mod_reciever"
							},
							{
								"_id": "7f9e10a098e98c2dafdb2755",
								"_tpl": "5c793fb92e221644f31bfb64",
								"parentId": "bf8980bc113ec4791a7578ec",
								"slotId": "mod_stock_001"
							},
							{
								"_id": "f02b0ec14947868d59cace71",
								"_tpl": "606587bd6d0bd7580617bacc",
								"parentId": "bf8980bc113ec4791a7578ec",
								"slotId": "mod_charge"
							},
							{
								"_id": "8a07795bcdcc997ea6db46aa",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "30009c25831bf560ba42e264",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "baaa1a1146ca63822a626fb3",
								"_tpl": "5b3b99265acfc4704b4a1afb",
								"parentId": "ed6f89a2665a153c678da0df",
								"slotId": "mod_scope"
							},
							{
								"_id": "ad94ba4220d7d98465df6a11",
								"_tpl": "6065878ac9cf8012264142fd",
								"parentId": "ed6f89a2665a153c678da0df",
								"slotId": "mod_barrel"
							},
							{
								"_id": "625a15f090de1fff4967a8a4",
								"_tpl": "5a329052c4a28200741e22d3",
								"parentId": "ed6f89a2665a153c678da0df",
								"slotId": "mod_handguard"
							},
							{
								"_id": "0c6fe1ea8b7794378d198839",
								"_tpl": "58d2946386f774496974c37e",
								"parentId": "7f9e10a098e98c2dafdb2755",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "45fba130ee5eb063bb60e62f",
								"_tpl": "5b3b99475acfc432ff4dcbee",
								"parentId": "baaa1a1146ca63822a626fb3",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "95ba5b45b2570067817da764",
								"_tpl": "5d443f8fa4b93678dd4a01aa",
								"parentId": "ad94ba4220d7d98465df6a11",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "1be56cb228a9f44041570ef5",
								"_tpl": "6065dc8a132d4d12c81fd8e3",
								"parentId": "ad94ba4220d7d98465df6a11",
								"slotId": "mod_gas_block"
							},
							{
								"_id": "e997b199a647951099030c27",
								"_tpl": "5c0102b20db834001d23eebc",
								"parentId": "625a15f090de1fff4967a8a4",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "3727df95f0a0c38c6c50c6ff",
								"_tpl": "5c0102aa0db834001b734ba1",
								"parentId": "625a15f090de1fff4967a8a4",
								"slotId": "mod_mount_004"
							},
							{
								"_id": "4919c86d0fc5d7e30fb1c28a",
								"_tpl": "5d44064fa4b9361e4f6eb8b5",
								"parentId": "95ba5b45b2570067817da764",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "9a70db3a18a4723d6ff6cea6",
								"_tpl": "5c1cd46f2e22164bef5cfedb",
								"parentId": "e997b199a647951099030c27",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "977d9b9caddfe67418330481",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "3727df95f0a0c38c6c50c6ff",
								"slotId": "mod_tactical",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "25fdeeec5ab96a7be5598b02",
								"_tpl": "58d2912286f7744e27117493",
								"parentId": "0c6fe1ea8b7794378d198839",
								"slotId": "mod_stock"
							}
						],
						"Parent": "5447b5f14bdc2d61278b4567"
					},
					"MP155": {
						"id": "29ab50dd9de4109922143b4d",
						"name": "MP155",
						"root": "09c8416ab3b626d0bb9c4203",
						"items": [
							{
								"_id": "09c8416ab3b626d0bb9c4203",
								"_tpl": "606dae0ab0e443224b421bb7",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "0c3aa16f7d7826260f2dea1b",
								"_tpl": "6076c1b9f2cb2e02a42acedc",
								"parentId": "09c8416ab3b626d0bb9c4203",
								"slotId": "mod_barrel"
							},
							{
								"_id": "6c77ab9eac7260b91e5e4dd6",
								"_tpl": "606ee5c81246154cad35d65e",
								"parentId": "09c8416ab3b626d0bb9c4203",
								"slotId": "mod_handguard"
							},
							{
								"_id": "5cddb46707a40f7d55a2b246",
								"_tpl": "6076c87f232e5a31c233d50e",
								"parentId": "09c8416ab3b626d0bb9c4203",
								"slotId": "mod_magazine"
							},
							{
								"_id": "b7548e57ce7aeb68a05567b2",
								"_tpl": "606eef46232e5a31c233d500",
								"parentId": "09c8416ab3b626d0bb9c4203",
								"slotId": "mod_stock"
							},
							{
								"_id": "e31af76495fac565713a7eb7",
								"_tpl": "60785ce5132d4d12c81fd918",
								"parentId": "09c8416ab3b626d0bb9c4203",
								"slotId": "mod_mount"
							},
							{
								"_id": "93d4c7c2bca28b15fae6ddc7",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "09c8416ab3b626d0bb9c4203",
								"slotId": "patron_in_weapon"
							},
							{
								"_id": "d33a81fee5d1c8ec8c3a295f",
								"_tpl": "5c0111ab0db834001966914d",
								"parentId": "0c3aa16f7d7826260f2dea1b",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "3a61ccabd0bf24e2a7aca587",
								"_tpl": "607ea812232e5a31c233d53c",
								"parentId": "6c77ab9eac7260b91e5e4dd6",
								"slotId": "mod_mount_000"
							},
							{
								"_id": "aa742043879d660821d21e69",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "5cddb46707a40f7d55a2b246",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "5a66fce868a726cb6f6b2533",
								"_tpl": "606eef756d0bd7580617baf8",
								"parentId": "b7548e57ce7aeb68a05567b2",
								"slotId": "mod_stock"
							},
							{
								"_id": "9e29e86421bb8d7cecea9347",
								"_tpl": "570fd6c2d2720bc6458b457f",
								"parentId": "e31af76495fac565713a7eb7",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "05ef173908038174012f7723",
								"_tpl": "59c0ec5b86f77435b128bfca",
								"parentId": "d33a81fee5d1c8ec8c3a295f",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "0a8cd85c07d8b5b1da1f93fa",
								"_tpl": "56def37dd2720bec348b456a",
								"parentId": "3a61ccabd0bf24e2a7aca587",
								"slotId": "mod_tactical",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "3072a88ea2d551681b4585f3",
								"_tpl": "606f262c6d0bd7580617bafa",
								"parentId": "5a66fce868a726cb6f6b2533",
								"slotId": "mod_stock"
							},
							{
								"_id": "fe3b24c20ddebf7fcbaaabe3",
								"_tpl": "606f2696f2cb2e02a42aceb1",
								"parentId": "5a66fce868a726cb6f6b2533",
								"slotId": "mod_tactical",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							}
						],
						"Parent": "5447b6094bdc2dc3278b4567"
					},
					"M4A1": {
						"id": "e7936630a2c0d64112788602",
						"name": "M4A1",
						"root": "a480cb04e8a1b3c03862fe07",
						"items": [
							{
								"_id": "a480cb04e8a1b3c03862fe07",
								"_tpl": "5447a9cd4bdc2dbd208b4567",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "96527a4d089c2c18dceb3f0c",
								"_tpl": "59db3a1d86f77429e05b4e92",
								"parentId": "a480cb04e8a1b3c03862fe07",
								"slotId": "mod_pistol_grip"
							},
							{
								"_id": "4e51c8127df4928348601c51",
								"_tpl": "59bfe68886f7746004266202",
								"parentId": "a480cb04e8a1b3c03862fe07",
								"slotId": "mod_reciever"
							},
							{
								"_id": "495e0c756611d7f78c09316f",
								"_tpl": "5c793fb92e221644f31bfb64",
								"parentId": "a480cb04e8a1b3c03862fe07",
								"slotId": "mod_stock"
							},
							{
								"_id": "7d4c825194094be438766b93",
								"_tpl": "5b2240bf5acfc40dc528af69",
								"parentId": "a480cb04e8a1b3c03862fe07",
								"slotId": "mod_charge"
							},
							{
								"_id": "bb24af9074b5381f25076b61",
								"_tpl": "5b3b99265acfc4704b4a1afb",
								"parentId": "4e51c8127df4928348601c51",
								"slotId": "mod_scope"
							},
							{
								"_id": "146ff2e06ae76487ee013faf",
								"_tpl": "55d3632e4bdc2d972f8b4569",
								"parentId": "4e51c8127df4928348601c51",
								"slotId": "mod_barrel"
							},
							{
								"_id": "9980bcc79fc7ed2c77c17fa3",
								"_tpl": "5c78f2492e221600114c9f04",
								"parentId": "4e51c8127df4928348601c51",
								"slotId": "mod_handguard"
							},
							{
								"_id": "f355f3cd68c31215acf4deda",
								"_tpl": "58d2947e86f77447aa070d53",
								"parentId": "495e0c756611d7f78c09316f",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "4713eb2e0312ec140cb5a229",
								"_tpl": "618ba27d9008e4636a67f61d",
								"parentId": "bb24af9074b5381f25076b61",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "39cc988aa9e78e471813ef3f",
								"_tpl": "609269c3b0e443224b421cc1",
								"parentId": "146ff2e06ae76487ee013faf",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "1dea65169749146969e81937",
								"_tpl": "5d00ec68d7ad1a04a067e5be",
								"parentId": "146ff2e06ae76487ee013faf",
								"slotId": "mod_gas_block"
							},
							{
								"_id": "1da200de64995349172abf37",
								"_tpl": "5b7be4895acfc400170e2dd5",
								"parentId": "9980bcc79fc7ed2c77c17fa3",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "be720edc664af932932f3788",
								"_tpl": "56def37dd2720bec348b456a",
								"parentId": "9980bcc79fc7ed2c77c17fa3",
								"slotId": "mod_tactical_003",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "f1f3f0f0cab7992d9bf29d7a",
								"_tpl": "60926df0132d4d12c81fd9df",
								"parentId": "39cc988aa9e78e471813ef3f",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "2747648813a2ecae05b81a42",
								"_tpl": "58d2912286f7744e27117493",
								"parentId": "f355f3cd68c31215acf4deda",
								"slotId": "mod_stock"
							}
						],
						"Parent": "5447b5f14bdc2d61278b4567"
					},
					"RD704": {
						"id": "efa26b788869e44e1aba2b26",
						"name": "RD704",
						"root": "44e5329adcc29bd81bff85fc",
						"items": [
							{
								"_id": "44e5329adcc29bd81bff85fc",
								"_tpl": "628a60ae6b1d481ff772e9c8",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "2dc061942241070991bfab9b",
								"_tpl": "628a83c29179c324ed269508",
								"parentId": "44e5329adcc29bd81bff85fc",
								"slotId": "mod_gas_block"
							},
							{
								"_id": "d51608fb1de72820d5f10c97",
								"_tpl": "6130c43c67085e45ef1405a1",
								"parentId": "44e5329adcc29bd81bff85fc",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "a96c305883f093ae74bd5424",
								"_tpl": "628c9ab845c59e5b80768a81",
								"parentId": "44e5329adcc29bd81bff85fc",
								"slotId": "mod_pistol_grip"
							},
							{
								"_id": "64bc890dbd65cafbe592218f",
								"_tpl": "5d2c772c48f0355d95672c25",
								"parentId": "44e5329adcc29bd81bff85fc",
								"slotId": "mod_reciever"
							},
							{
								"_id": "7e8845a9b18030a1c0de32be",
								"_tpl": "5b0e794b5acfc47a877359b2",
								"parentId": "44e5329adcc29bd81bff85fc",
								"slotId": "mod_stock_000"
							},
							{
								"_id": "763f09c02bffc9aca1a8f4de",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"parentId": "44e5329adcc29bd81bff85fc",
								"slotId": "mod_magazine"
							},
							{
								"_id": "5449e333954dbdfd9f958c66",
								"_tpl": "6130ca3fd92c473c77020dbd",
								"parentId": "44e5329adcc29bd81bff85fc",
								"slotId": "mod_charge"
							},
							{
								"_id": "c37c96576051f4d23e4ea2db",
								"_tpl": "5b7be47f5acfc400170e2dd2",
								"parentId": "2dc061942241070991bfab9b",
								"slotId": "mod_mount_001"
							},
							{
								"_id": "c9e15cddb62d39dc65b50734",
								"_tpl": "5b7be4895acfc400170e2dd5",
								"parentId": "2dc061942241070991bfab9b",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "7d11292f9e8628dc4c59ed7d",
								"_tpl": "5dfa3d2b0dee1b22f862eade",
								"parentId": "d51608fb1de72820d5f10c97",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "1265b311600dd9dca3899141",
								"_tpl": "5b3b99265acfc4704b4a1afb",
								"parentId": "64bc890dbd65cafbe592218f",
								"slotId": "mod_scope"
							},
							{
								"_id": "f73ae9db60fca0dcfa6bd0eb",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"parentId": "763f09c02bffc9aca1a8f4de",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 50
								}
							},
							{
								"_id": "147ebcb14d43d9b3441de5aa",
								"_tpl": "56def37dd2720bec348b456a",
								"parentId": "c37c96576051f4d23e4ea2db",
								"slotId": "mod_tactical",
								"upd": {
									"Light": {
										"IsActive": true,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "30191c0ea06acb1487748514",
								"_tpl": "5b057b4f5acfc4771e1bd3e9",
								"parentId": "c9e15cddb62d39dc65b50734",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "94808546f03f64c618ffb670",
								"_tpl": "618ba27d9008e4636a67f61d",
								"parentId": "1265b311600dd9dca3899141",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							}
						]
					}
				},
				"trader": {
					"initialLoyaltyLevel": 4,
					"initialStanding": 6.5,
					"initialSalesSum": 10000000,
					"jaegerUnlocked": true
				}
			}
		}
    }

}
    
module.exports = { mod: new GigaChad() }